@@ -1,8 +1,9 @@
 """
 Constants for csle-common
 """
-
+from typing import Union
 import re
+from csle_common.dao.emulation_config.config import Config
 
 
 class GENERAL:
@@ -29,6 +30,8 @@ class GRPC_SERVERS:
     OSSEC_IDS_MANAGER_PORT = 50047
     SNORT_IDS_MANAGER_PORT = 50048
     HOST_MANAGER_PORT = 50049
+    GRPC_OPTIONS = [('grpc.max_message_length', 100000000), ('grpc.max_send_message_length', 100000000),
+                    ('grpc.max_receive_message_length', 100000000)]
 
 
 class CONFIG_FILE:
@@ -37,7 +40,7 @@ class CONFIG_FILE:
     """
     CSLE_HOME_ENV_PARAM = "CSLE_HOME"
     CONFIG_FILE_NAME = "config.json"
-    PARSED_CONFIG = None
+    PARSED_CONFIG: Union[None, Config] = None
 
 
 class CONTAINER_IMAGES:
@@ -45,7 +48,11 @@ class CONTAINER_IMAGES:
     String constants representing container images names
     """
     CSLE_PREFIX = "csle_"
+    BASE = "base"
+    DERIVED = "derived"
     DOCKERHUB_USERNAME = "kimham"
+    BLANK = "csle_blank"
+    BLANK_1 = "csle_blank_1"
     SSH_1 = "csle_ssh_1"
     ROUTER_2 = "csle_router_2"
     SAMBA_2 = "csle_samba_2"
@@ -570,6 +577,7 @@ class HTTPS:
     CONFLICT_STATUS_CODE = 409
     NOT_FOUND_STATUS_CODE = 404
     INTERNAL_SERVER_ERROR_STATUS_CODE = 500
+    METHOD_NOT_ALLOWED_CODE = 405
 
 
 class RETHINKDB:
@@ -913,7 +921,8 @@ class COMMANDS:
     POSTGRESQL_LOG_DIR = "/var/log/postgresql/"
     NGINX_LOG_DIR = "/var/log/nginx/"
     PROMETHEUS_PORT = 9090
-    START_PROMETHEUS = f"nohup prometheus --config.file={PROMETHEUS_CONFIG_FILE} " \
+    START_PROMETHEUS = f"nohup $CSLE_HOME/management-system/prometheus/prometheus " \
+                       f"--config.file={PROMETHEUS_CONFIG_FILE} " \
                        "--storage.tsdb.retention.size=10GB " \
                        f"--storage.tsdb.retention.time=5d & > {PROMETHEUS_LOG_FILE} " \
                        f"&& echo $! > {PROMETHEUS_PID_FILE}"
@@ -942,13 +951,14 @@ class COMMANDS:
     CADVISOR_LOGS = "docker logs cadvisor"
     PGADMIN_LOGS = "docker logs pgadmin"
     GRAFANA_LOGS = "docker logs grafana"
-    DOCKER_ENGINE_LOGS = "sudo /usr/bin/journalctl -u docker.service -n 100 --no-pager -e"
-    DOCKER_ENGINE_LOGS_ALTERNATIVE = "sudo /bin/journalctl -u docker.service -n 100 --no-pager -e"
+    DOCKER_ENGINE_LOGS = "sudo -n /usr/bin/journalctl -u docker.service -n 100 --no-pager -e"
+    DOCKER_ENGINE_LOGS_ALTERNATIVE = "sudo -n /bin/journalctl -u docker.service -n 100 --no-pager -e"
     NODE_EXPORTER_PID_FILE = "/var/log/csle/node_exporter.pid"
     CSLE_MGMT_WEBAPP_PID_FILE = "/var/log/csle/csle_mgmt_webapp.pid"
     NODE_EXPORTER_LOG_FILE = "/var/log/csle/node_exporter.log"
     FLASK_LOG_FILE = "/var/log/csle/flask.log"
-    START_NODE_EXPORTER = f"nohup node_exporter & > {NODE_EXPORTER_LOG_FILE} && echo $! " \
+    START_NODE_EXPORTER = f"nohup $CSLE_HOME/management-system/node_exporter/node_exporter " \
+                          f"& > {NODE_EXPORTER_LOG_FILE} && echo $! " \
                           f"> {NODE_EXPORTER_PID_FILE}"
     BUILD_CSLE_MGMT_WEBAPP = f"cd ${CONFIG_FILE.CSLE_HOME_ENV_PARAM}/management-system/csle-mgmt-webapp && npm run " \
                              f"build"
@@ -963,13 +973,14 @@ class COMMANDS:
     PING = "ping"
     NGINX_STATUS = "service nginx status"
     POSTGRESQL_STATUS = "service postgresql status"
+    POSTGRESQL_STATUS_VERSION = "service postgresql@15-main status"
     DOCKER_ENGINE_STATUS = "service docker status"
-    POSTGRESQL_START = "sudo service postgresql start"
-    POSTGRESQL_STOP = "sudo service postgresql stop"
-    NGINX_START = "sudo service nginx start"
-    NGINX_STOP = "sudo service nginx stop"
-    DOCKER_ENGINE_START = "sudo service docker start"
-    DOCKER_ENGINE_STOP = "sudo service docker stop"
+    POSTGRESQL_START = "sudo -n service postgresql start"
+    POSTGRESQL_STOP = "sudo -n service postgresql stop"
+    NGINX_START = "sudo -n service nginx start"
+    NGINX_STOP = "sudo -n service nginx stop"
+    DOCKER_ENGINE_START = "sudo -n service docker start"
+    DOCKER_ENGINE_STOP = "sudo -n service docker stop"
 
 
 class OVS:
@@ -1001,7 +1012,7 @@ class ETC_HOSTS:
     DEFAULT_HOST_LINE_4 = "'ff00::0 ip6-mcastprefix'"
     DEFAULT_HOST_LINE_5 = "'ff02::1 ip6-allnodes'"
     DEFAULT_HOST_LINE_6 = "''ff02::2 ip6-allrouters''"
-    APPEND_TO_ETC_HOSTS = "sudo tee -a /etc/hosts"
+    APPEND_TO_ETC_HOSTS = "sudo -n tee -a /etc/hosts"
 
 
 class FILE_PATTERNS:
@@ -1263,15 +1274,24 @@ class TRAFFIC_COMMANDS:
 
 
 class AGENT:
+    """
+    String constants related to the agent
+    """
     USER = "agent"
     PW = "agent"
 
 
 class CITUS:
+    """
+    Constants related to CITUS
+    """
     COORDINATOR_PORT = 5432
 
 
 class CLUSTER_CONFIG:
+    """
+    Constants related to the cluster configuration
+    """
     LEADER = False
     IP = "127.0.0.1"
 
@@ -1410,11 +1430,15 @@ class INFO_DICT:
 
 
 class DOCKER:
+    """
+    Constants related to Docker
+    """
     CONTAINER_EXIT_STATUS = "exited"
     CONTAINER_CREATED_STATUS = "created"
     IMAGE_CREATED = "Created"
     IMAGE_OS = "Os"
     IMAGE_SIZE = "Size"
+    IMAGE = "Image"
     IMAGE_ARCHITECTURE = "Architecture"
     REPO_TAGS = "RepoTags"
     ENTRYPOINT = "Entrypoint"
@@ -1491,6 +1515,9 @@ class DOCKER:
 
 
 class CSLE:
+    """
+    Constants related to general CSLE
+    """
     NAME = "csle"
     LEVEL = "level"
     BRIDGE = "br"
@@ -1507,6 +1534,9 @@ class CSLE:
 
 
 class MANAGEMENT:
+    """
+    Constants related to the management system
+    """
     LIST_STOPPED = "list_stopped"
     LIST_RUNNING = "list_running"
     LIST_IMAGES = "list_images"
@@ -1534,6 +1564,9 @@ class MANAGEMENT:
 
 
 class MAKEFILE:
+    """
+    Constants related to Makefiles
+    """
     PROJECT = "PROJECT"
     INTERNAL_NETWORK = "INTERNAL_NETWORK"
     EXTERNAL_NETWORK = "EXTERNAL_NETWORK"
@@ -1554,12 +1587,18 @@ class MAKEFILE:
 
 
 class VULNERABILITY_GENERATOR:
+    """
+    Constants related to the vulnerability generator
+    """
     NAMES_SHORTLIST = ["admin", "test", "guest", "info", "adm", "mysql", "user", "administrator",
                        "oracle", "ftp", "pi", "puppet", "ansible", "ec2-user", "vagrant", "azureuser",
                        "donald", "alan"]
 
 
 class EXPERIMENT:
+    """
+    Constants related to experiments folder structure
+    """
     RESULTS_DIR = "results"
     DATA_DIR = "data"
     VIDEOS_DIR = "videos"
@@ -1579,7 +1618,7 @@ class METADATA_STORE:
     DBNAME = "csle"
     USER = "csle"
     PASSWORD = "csle"
-    HOST = "127.0.0.1"
+    HOST = "172.31.212.92"
     TRACES_PROPERTY = "traces"
     DB_NAME_PROPERTY = "dbname"
     PW_PROPERTY = "password"
@@ -1608,15 +1647,20 @@ class METADATA_STORE:
     VECTOR_POLICIES_TABLE = "vector_policies"
     EMULATION_EXECUTIONS_TABLE = "emulation_executions"
     EMPIRICAL_SYSTEM_MODELS_TABLE = "empirical_system_models"
+    MCMC_SYSTEM_MODELS_TABLE = "mcmc_system_models"
     GP_SYSTEM_MODELS_TABLE = "gp_system_models"
     CONFIG_TABLE = "config"
     MANAGEMENT_USERS_TABLE = "management_users"
     SESSION_TOKENS_TABLE = "session_tokens"
     TRACES_DATASETS_TABLE = "traces_datasets"
     STATISTICS_DATASETS_TABLE = "statistics_datasets"
+    NUM_RETRIES_UPDATE_TRAINING_JOB = 5
 
 
 class CONTAINER_POOLS:
+    """
+    Constants related to container pools
+    """
     CONTAINER_POOL = [(f"{CONTAINER_IMAGES.FTP_1}", "0.0.1"),
                       (f"{CONTAINER_IMAGES.FTP_2}", "0.0.1"),
                       (f"{CONTAINER_IMAGES.HONEYPOT_1}", "0.0.1"),
@@ -1748,6 +1792,9 @@ class OPENFLOW:
 
 
 class DATASETS:
+    """
+    Constants related to datasets
+    """
     METADATA_FILE_NAME = "readme.json"
     JSON_FILE_FORMAT = "json"
     FILE_FORMAT_PROPERTY = "file_format"
@@ -1772,10 +1819,12 @@ class T_SPSA:
     c = "c"
     LAMBDA = "lambda"
     POLICY_TYPE = "policy_type"
+    OBJECTIVE_TYPE = "objective_type"
     A = "A"
     EPSILON = "epsilon"
     N = "N"
     L = "L"
+    IMPROVE_BREAK = "improve_break"
     THETA1 = "theta1"
     THETAS = "thetas"
     THRESHOLDS = "thresholds"
@@ -1792,3 +1841,10 @@ class NEURAL_NETWORKS:
     NUM_HIDDEN_LAYERS = "num_hidden_layers"
     ACTIVATION_FUNCTION = "activation_function"
     DEVICE = "device"
+
+
+class CUDA:
+    """
+    String constants related to cuda
+    """
+    CUDA_VISIBLE_DEVICES = "CUDA_VISIBLE_DEVICES"
