@@ -1,5 +1,5 @@
+from typing import List, Tuple, Union
 import logging
-from typing import List, Tuple
 import subprocess
 import time
 import docker
@@ -41,7 +41,7 @@ class ContainerController:
         containers = client_1.containers.list()
         containers = list(filter(lambda x: constants.CSLE.NAME in x.name, containers))
         for c in containers:
-            Logger.__call__().get_logger().info("Stopping container: {}".format(c.name))
+            Logger.__call__().get_logger().info(f"Stopping container: {c.name}")
             c.stop()
 
     @staticmethod
@@ -147,22 +147,22 @@ class ContainerController:
             filter(lambda x: (constants.OS.UBUNTU in ",".join(x.attrs[constants.DOCKER.REPO_TAGS]) or constants.OS.KALI
                               in ",".join(x.attrs[constants.DOCKER.REPO_TAGS])), base_images))
         for img in non_base_images:
-            if img == name:
+            if img.attrs[constants.DOCKER.REPO_TAGS][0] == name:
                 client_1.images.remove(image=img.attrs[constants.DOCKER.REPO_TAGS][0], force=True)
                 return True
         for img in non_os_base_images:
-            if img == name:
+            if img.attrs[constants.DOCKER.REPO_TAGS][0] == name:
                 client_1.images.remove(image=img.attrs[constants.DOCKER.REPO_TAGS][0], force=True)
                 return True
         for img in os_base_images:
-            if img == name:
+            if img.attrs[constants.DOCKER.REPO_TAGS][0] == name:
                 client_1.images.remove(image=img.attrs[constants.DOCKER.REPO_TAGS][0], force=True)
                 return True
 
         return False
 
     @staticmethod
-    def list_all_images() -> List[Tuple[str, str, str, str, str]]:
+    def list_all_images() -> List[Tuple[str, str, str, str, int]]:
         """
         A utility function for listing all csle images
 
@@ -186,15 +186,18 @@ class ContainerController:
         """
         cmd = constants.DOCKER.LIST_NETWORKS_CMD
         stream = os.popen(cmd)
-        networks = stream.read()
-        networks = networks.split("\n")
-        networks = list(map(lambda x: x.split(), networks))
-        networks = list(filter(lambda x: len(x) > 1, networks))
-        networks = list(map(lambda x: x[1], networks))
-        networks = list(filter(lambda x: re.match(r"{}\d".format(constants.CSLE.CSLE_NETWORK_PREFIX), x), networks))
-        network_ids = list(map(lambda x: int(x.replace(constants.CSLE.CSLE_NETWORK_PREFIX, "")),
-                               networks))
-        return networks, network_ids
+        networks_str: str = stream.read()
+        networks: List[str] = networks_str.split("\n")
+
+        networks_list: List[List[str]] = list(map(lambda x: x.split(), networks))
+        networks_list = list(filter(lambda x: len(x) > 1, networks_list))
+        networks_ids_str: List[str] = list(map(lambda x: x[1], networks_list))
+
+        networks_ids_str = list(filter(lambda x: re.match(
+            r"{}\d".format(constants.CSLE.CSLE_NETWORK_PREFIX), x), networks_ids_str))
+        network_ids: List[int] = list(map(lambda x: int(x.replace(constants.CSLE.CSLE_NETWORK_PREFIX, "")),
+                                          networks_ids_str))
+        return networks_ids_str, network_ids
 
     @staticmethod
     def list_all_networks() -> List[str]:
@@ -249,7 +252,7 @@ class ContainerController:
         :return: a list of the names of the running containers
         """
         parsed_envs = DockerUtil.parse_runnning_emulation_infos()
-        container_name_image_ip = []
+        container_name_image_ip: List[Tuple[str, str, str]] = []
         for env in parsed_envs:
             container_name_image_ip = (container_name_image_ip +
                                        list(map(lambda x: (x.name, x.image_name, x.ip), env.containers)))
@@ -277,12 +280,15 @@ class ContainerController:
             running_emulation_containers.append(emulation_env_config.kafka_config.container)
         else:
             stopped_emulation_containers.append(emulation_env_config.kafka_config.container)
+
         if emulation_env_config.elk_config.container.full_name_str in running_containers_names:
             running_emulation_containers.append(emulation_env_config.elk_config.container)
         else:
             stopped_emulation_containers.append(emulation_env_config.elk_config.container)
+
         if emulation_env_config.sdn_controller_config is not None:
             if emulation_env_config.sdn_controller_config.container.full_name_str in running_containers_names:
+
                 running_emulation_containers.append(emulation_env_config.sdn_controller_config.container)
             else:
                 stopped_emulation_containers.append(emulation_env_config.sdn_controller_config.container)
@@ -405,6 +411,8 @@ class ContainerController:
                     time.sleep(2)
                     # Extract the docker bridge gateway IP
                     container_id = DockerUtil.get_container_hex_id(name=container_name)
+                    if container_id is None:
+                        raise ValueError(f"Could not parse the container id with container name: {container_name}")
                     docker_gw_bridge_ip = DockerUtil.get_docker_gw_bridge_ip(container_id=container_id)
                     c.docker_gw_bridge_ip = docker_gw_bridge_ip
 
@@ -422,6 +430,8 @@ class ContainerController:
             # Update IPs of OVS switches
             for ovs_sw in emulation_env_config.ovs_config.switch_configs:
                 node_container_config = emulation_env_config.containers_config.get_container_from_ip(ovs_sw.ip)
+                if node_container_config is None:
+                    raise ValueError(f"Could not find node container config for IP: {ovs_sw.ip}")
                 ovs_sw.docker_gw_bridge_ip = node_container_config.docker_gw_bridge_ip
 
     @staticmethod
@@ -453,6 +463,8 @@ class ContainerController:
                 time.sleep(2)
                 # Extract the docker bridge gateway IP
                 container_id = DockerUtil.get_container_hex_id(name=container_name)
+                if container_id is None:
+                    raise ValueError(f"Could not parse the container id for container name: {container_name}")
                 docker_gw_bridge_ip = DockerUtil.get_docker_gw_bridge_ip(container_id=container_id)
                 container.docker_gw_bridge_ip = docker_gw_bridge_ip
 
@@ -468,7 +480,7 @@ class ContainerController:
         :return: None
         """
         if not ManagementSystemController.is_statsmanager_running():
-            ManagementSystemController.start_docker_stats_manager(
+            ManagementSystemController.start_docker_statsmanager(
                 logger=logger,
                 port=execution.emulation_env_config.docker_stats_manager_config.docker_stats_manager_port,
                 log_dir=execution.emulation_env_config.docker_stats_manager_config.docker_stats_manager_log_dir,
@@ -482,7 +494,8 @@ class ContainerController:
             f"{execution.emulation_env_config.docker_stats_manager_config.docker_stats_manager_port}")
         with grpc.insecure_channel(
                 f'{ip}:'
-                f'{execution.emulation_env_config.docker_stats_manager_config.docker_stats_manager_port}') as channel:
+                f'{execution.emulation_env_config.docker_stats_manager_config.docker_stats_manager_port}',
+                options=constants.GRPC_SERVERS.GRPC_OPTIONS) as channel:
             stub = csle_collector.docker_stats_manager.docker_stats_manager_pb2_grpc.DockerStatsManagerStub(channel)
             container_ip_dtos = []
             for c in execution.emulation_env_config.containers_config.containers:
@@ -513,19 +526,13 @@ class ContainerController:
         :return: None
         """
         if not ManagementSystemController.is_statsmanager_running():
-            ManagementSystemController.start_docker_stats_manager(
-                logger=logger,
-                port=execution.emulation_env_config.docker_stats_manager_config.docker_stats_manager_port,
-                log_file=execution.emulation_env_config.docker_stats_manager_config.docker_stats_manager_log_file,
-                log_dir=execution.emulation_env_config.docker_stats_manager_config.docker_stats_manager_log_dir,
-                max_workers=execution.emulation_env_config.docker_stats_manager_config.docker_stats_manager_max_workers
-            )
+            ManagementSystemController.stop_docker_statsmanager(logger=logger)
             time.sleep(5)
         ip = physical_server_ip
         with grpc.insecure_channel(
                 f'{ip}:'
-                f'{execution.emulation_env_config.docker_stats_manager_config.docker_stats_manager_port}') \
-                as channel:
+                f'{execution.emulation_env_config.docker_stats_manager_config.docker_stats_manager_port}',
+                options=constants.GRPC_SERVERS.GRPC_OPTIONS) as channel:
             stub = csle_collector.docker_stats_manager.docker_stats_manager_pb2_grpc.DockerStatsManagerStub(channel)
             csle_collector.docker_stats_manager.query_docker_stats_manager.stop_docker_stats_monitor(
                 stub=stub, emulation=execution.emulation_name, execution_first_ip_octet=execution.ip_first_octet)
@@ -555,8 +562,9 @@ class ContainerController:
         :return: None
         """
         try:
-            with grpc.insecure_channel(f'{ip}:{port}') as channel:
+            with grpc.insecure_channel(f'{ip}:{port}', options=constants.GRPC_SERVERS.GRPC_OPTIONS) as channel:
                 stub = csle_collector.docker_stats_manager.docker_stats_manager_pb2_grpc.DockerStatsManagerStub(channel)
+
                 docker_stats_monitor_dto = \
                     csle_collector.docker_stats_manager.query_docker_stats_manager.get_docker_stats_manager_status(
                         stub=stub)
@@ -576,6 +584,8 @@ class ContainerController:
         :return: None
         """
         config = Config.get_current_config()
+        if config is None:
+            raise ValueError("Could not parse the CSLE config")
         driver = constants.DOCKER.BRIDGE_NETWORK_DRIVER
         if len(config.cluster_config.cluster_nodes) > 0:
             driver = constants.DOCKER.OVERLAY_NETWORK_DRIVER
@@ -585,7 +595,7 @@ class ContainerController:
 
     @staticmethod
     def create_network(name: str, subnetmask: str, logger: logging.Logger,
-                       driver: str = "bridge", existing_network_names: List = None) -> None:
+                       driver: str = "bridge", existing_network_names: Union[None, List[str]] = None) -> None:
         """
         Creates a network
 
@@ -597,12 +607,8 @@ class ContainerController:
         :return: None
         """
         client_1 = docker.from_env()
-        ipam_pool = docker.types.IPAMPool(
-            subnet=subnetmask
-        )
-        ipam_config = docker.types.IPAMConfig(
-            pool_configs=[ipam_pool],
-        )
+        ipam_pool = docker.types.IPAMPool(subnet=subnetmask)
+        ipam_config = docker.types.IPAMConfig(pool_configs=[ipam_pool])
         network_names = []
         if existing_network_names is not None:
             network_names = existing_network_names
@@ -682,9 +688,14 @@ class ContainerController:
         """
         client_1 = docker.from_env()
         networks = client_1.networks.list()
-        networks = list(filter(lambda x: constants.CSLE.NAME in x.name, networks))
+        networks_names = []
         for net in networks:
-            if net == name:
+            if constants.CSLE.NAME in net.name:
+                net.name = constants.CSLE.NAME
+                networks_names.append(net)
+        networks = list(filter(lambda x: constants.CSLE.NAME in x.name, networks))
+        for net in networks_names:
+            if net.name == name:
                 ContainerController.remove_network(name=net.name, logger=logger)
                 return True
         return False
@@ -698,14 +709,14 @@ class ContainerController:
         :return: None
         """
         if cmd == constants.MANAGEMENT.LIST_STOPPED:
-            names = ContainerController.list_all_stopped_containers()
-            Logger.__call__().get_logger().info(names)
+            stopped_container_names = ContainerController.list_all_stopped_containers()
+            Logger.__call__().get_logger().info(stopped_container_names)
         elif cmd == constants.MANAGEMENT.LIST_RUNNING:
-            names = ContainerController.list_all_running_containers()
-            Logger.__call__().get_logger().info(names)
+            running_container_names = ContainerController.list_all_running_containers()
+            Logger.__call__().get_logger().info(running_container_names)
         elif cmd == constants.MANAGEMENT.LIST_IMAGES:
-            names = ContainerController.list_all_images()
-            Logger.__call__().get_logger().info(names)
+            images_names = ContainerController.list_all_images()
+            Logger.__call__().get_logger().info(images_names)
         elif cmd == constants.MANAGEMENT.STOP_RUNNING:
             ContainerController.stop_all_running_containers()
         elif cmd == constants.MANAGEMENT.RM_STOPPED:
