@@ -7,7 +7,7 @@ from csle_common.dao.emulation_config.elk_managers_info import ELKManagersInfo
 import csle_common.constants.constants as constants
 import csle_collector.elk_manager.elk_manager_pb2_grpc
 import csle_collector.elk_manager.elk_manager_pb2
-import csle_collector.elk_manager.query_elk_server
+import csle_collector.elk_manager.query_elk_manager
 import csle_collector.elk_manager.elk_manager_util
 from csle_common.util.emulation_util import EmulationUtil
 
@@ -115,11 +115,9 @@ class ELKController:
         :return: an ELKDTO with the status of the server
         """
         # Open a gRPC session
-        with grpc.insecure_channel(
-                f'{ip}:'
-                f'{port}') as channel:
+        with grpc.insecure_channel(f'{ip}:{port}', options=constants.GRPC_SERVERS.GRPC_OPTIONS) as channel:
             stub = csle_collector.elk_manager.elk_manager_pb2_grpc.ElkManagerStub(channel)
-            elk_dto = csle_collector.elk_manager.query_elk_server.get_elk_status(stub)
+            elk_dto = csle_collector.elk_manager.query_elk_manager.get_elk_status(stub)
             return elk_dto
 
     @staticmethod
@@ -138,9 +136,10 @@ class ELKController:
         # Open a gRPC session
         with grpc.insecure_channel(
                 f'{emulation_env_config.elk_config.container.docker_gw_bridge_ip}:'
-                f'{emulation_env_config.elk_config.elk_manager_port}') as channel:
+                f'{emulation_env_config.elk_config.elk_manager_port}',
+                options=constants.GRPC_SERVERS.GRPC_OPTIONS) as channel:
             stub = csle_collector.elk_manager.elk_manager_pb2_grpc.ElkManagerStub(channel)
-            elk_dto = csle_collector.elk_manager.query_elk_server.stop_elk(stub)
+            elk_dto = csle_collector.elk_manager.query_elk_manager.stop_elk(stub)
             return elk_dto
 
     @staticmethod
@@ -162,9 +161,10 @@ class ELKController:
         # Open a gRPC session
         with grpc.insecure_channel(
                 f'{emulation_env_config.elk_config.container.docker_gw_bridge_ip}:'
-                f'{emulation_env_config.elk_config.elk_manager_port}') as channel:
+                f'{emulation_env_config.elk_config.elk_manager_port}',
+                options=constants.GRPC_SERVERS.GRPC_OPTIONS) as channel:
             stub = csle_collector.elk_manager.elk_manager_pb2_grpc.ElkManagerStub(channel)
-            elk_dto = csle_collector.elk_manager.query_elk_server.start_elk(stub)
+            elk_dto = csle_collector.elk_manager.query_elk_manager.start_elk(stub)
             return elk_dto
 
     @staticmethod
@@ -184,9 +184,10 @@ class ELKController:
         # Open a gRPC session
         with grpc.insecure_channel(
                 f'{emulation_env_config.elk_config.container.docker_gw_bridge_ip}:'
-                f'{emulation_env_config.elk_config.elk_manager_port}') as channel:
+                f'{emulation_env_config.elk_config.elk_manager_port}',
+                options=constants.GRPC_SERVERS.GRPC_OPTIONS) as channel:
             stub = csle_collector.elk_manager.elk_manager_pb2_grpc.ElkManagerStub(channel)
-            elk_dto = csle_collector.elk_manager.query_elk_server.start_elastic(stub)
+            elk_dto = csle_collector.elk_manager.query_elk_manager.start_elastic(stub)
             return elk_dto
 
     @staticmethod
@@ -206,9 +207,10 @@ class ELKController:
         # Open a gRPC session
         with grpc.insecure_channel(
                 f'{emulation_env_config.elk_config.container.docker_gw_bridge_ip}:'
-                f'{emulation_env_config.elk_config.elk_manager_port}') as channel:
+                f'{emulation_env_config.elk_config.elk_manager_port}',
+                options=constants.GRPC_SERVERS.GRPC_OPTIONS) as channel:
             stub = csle_collector.elk_manager.elk_manager_pb2_grpc.ElkManagerStub(channel)
-            elk_dto = csle_collector.elk_manager.query_elk_server.start_kibana(stub)
+            elk_dto = csle_collector.elk_manager.query_elk_manager.start_kibana(stub)
             return elk_dto
 
     @staticmethod
@@ -228,9 +230,10 @@ class ELKController:
         # Open a gRPC session
         with grpc.insecure_channel(
                 f'{emulation_env_config.elk_config.container.docker_gw_bridge_ip}:'
-                f'{emulation_env_config.elk_config.elk_manager_port}') as channel:
+                f'{emulation_env_config.elk_config.elk_manager_port}',
+                options=constants.GRPC_SERVERS.GRPC_OPTIONS) as channel:
             stub = csle_collector.elk_manager.elk_manager_pb2_grpc.ElkManagerStub(channel)
-            elk_dto = csle_collector.elk_manager.query_elk_server.start_logstash(stub)
+            elk_dto = csle_collector.elk_manager.query_elk_manager.start_logstash(stub)
             return elk_dto
 
     @staticmethod
@@ -250,9 +253,10 @@ class ELKController:
         # Open a gRPC session
         with grpc.insecure_channel(
                 f'{emulation_env_config.elk_config.container.docker_gw_bridge_ip}:'
-                f'{emulation_env_config.elk_config.elk_manager_port}') as channel:
+                f'{emulation_env_config.elk_config.elk_manager_port}',
+                options=constants.GRPC_SERVERS.GRPC_OPTIONS) as channel:
             stub = csle_collector.elk_manager.elk_manager_pb2_grpc.ElkManagerStub(channel)
-            elk_dto = csle_collector.elk_manager.query_elk_server.stop_elastic(stub)
+            elk_dto = csle_collector.elk_manager.query_elk_manager.stop_elastic(stub)
             return elk_dto
 
     @staticmethod
@@ -272,9 +276,10 @@ class ELKController:
         # Open a gRPC session
         with grpc.insecure_channel(
                 f'{emulation_env_config.elk_config.container.docker_gw_bridge_ip}:'
-                f'{emulation_env_config.elk_config.elk_manager_port}') as channel:
+                f'{emulation_env_config.elk_config.elk_manager_port}',
+                options=constants.GRPC_SERVERS.GRPC_OPTIONS) as channel:
             stub = csle_collector.elk_manager.elk_manager_pb2_grpc.ElkManagerStub(channel)
-            elk_dto = csle_collector.elk_manager.query_elk_server.stop_kibana(stub)
+            elk_dto = csle_collector.elk_manager.query_elk_manager.stop_kibana(stub)
             return elk_dto
 
     @staticmethod
@@ -294,9 +299,10 @@ class ELKController:
         # Open a gRPC session
         with grpc.insecure_channel(
                 f'{emulation_env_config.elk_config.container.docker_gw_bridge_ip}:'
-                f'{emulation_env_config.elk_config.elk_manager_port}') as channel:
+                f'{emulation_env_config.elk_config.elk_manager_port}',
+                options=constants.GRPC_SERVERS.GRPC_OPTIONS) as channel:
             stub = csle_collector.elk_manager.elk_manager_pb2_grpc.ElkManagerStub(channel)
-            elk_dto = csle_collector.elk_manager.query_elk_server.stop_logstash(stub)
+            elk_dto = csle_collector.elk_manager.query_elk_manager.stop_logstash(stub)
             return elk_dto
 
     @staticmethod
