@@ -89,6 +89,9 @@ class HostController:
             o, e, _ = EmulationUtil.execute_ssh_cmd(cmd=cmd,
                                                     conn=emulation_env_config.get_connection(ip=ip))
             time.sleep(5)
+        else:
+            logger.info(f"Host manager is already running on: {ip}. Output of {cmd} was: {str(o)}, "
+                        f"err output was: {str(e)}")
 
     @staticmethod
     def stop_host_managers(emulation_env_config: EmulationEnvConfig, physical_host_ip: str) -> None:
@@ -676,7 +679,8 @@ class HostController:
             logger.info(f"Host monitor thread is not running on {ip}, starting it.")
             # Open a gRPC session
             with grpc.insecure_channel(
-                    f'{ip}:{emulation_env_config.host_manager_config.host_manager_port}') as channel:
+                    f'{ip}:{emulation_env_config.host_manager_config.host_manager_port}',
+                    options=constants.GRPC_SERVERS.GRPC_OPTIONS) as channel:
                 stub = csle_collector.host_manager.host_manager_pb2_grpc.HostManagerStub(channel)
                 csle_collector.host_manager.query_host_manager.start_host_monitor(
                     stub=stub, kafka_ip=emulation_env_config.kafka_config.container.get_ips()[0],
@@ -707,7 +711,8 @@ class HostController:
             logger.info(f"Filebeat is not running on {ips[0]}, starting it.")
             # Open a gRPC session
             with grpc.insecure_channel(
-                    f'{ips[0]}:{emulation_env_config.host_manager_config.host_manager_port}') as channel:
+                    f'{ips[0]}:{emulation_env_config.host_manager_config.host_manager_port}',
+                    options=constants.GRPC_SERVERS.GRPC_OPTIONS) as channel:
                 stub = csle_collector.host_manager.host_manager_pb2_grpc.HostManagerStub(channel)
                 csle_collector.host_manager.query_host_manager.start_filebeat(stub=stub)
 
@@ -736,7 +741,8 @@ class HostController:
                 f"Packetbeat is not running on {ips[0]}, starting it.")
             # Open a gRPC session
             with grpc.insecure_channel(
-                    f'{ips[0]}:{emulation_env_config.host_manager_config.host_manager_port}') as channel:
+                    f'{ips[0]}:{emulation_env_config.host_manager_config.host_manager_port}',
+                    options=constants.GRPC_SERVERS.GRPC_OPTIONS) as channel:
                 stub = csle_collector.host_manager.host_manager_pb2_grpc.HostManagerStub(channel)
                 csle_collector.host_manager.query_host_manager.start_packetbeat(stub=stub)
 
@@ -765,7 +771,8 @@ class HostController:
                 f"Metricbeat is not running on {ips[0]}, starting it.")
             # Open a gRPC session
             with grpc.insecure_channel(
-                    f'{ips[0]}:{emulation_env_config.host_manager_config.host_manager_port}') as channel:
+                    f'{ips[0]}:{emulation_env_config.host_manager_config.host_manager_port}',
+                    options=constants.GRPC_SERVERS.GRPC_OPTIONS) as channel:
                 stub = csle_collector.host_manager.host_manager_pb2_grpc.HostManagerStub(channel)
                 csle_collector.host_manager.query_host_manager.start_metricbeat(stub=stub)
 
@@ -795,7 +802,8 @@ class HostController:
                 f"Heartbeat is not running on {ips[0]}, starting it.")
             # Open a gRPC session
             with grpc.insecure_channel(
-                    f'{ips[0]}:{emulation_env_config.host_manager_config.host_manager_port}') as channel:
+                    f'{ips[0]}:{emulation_env_config.host_manager_config.host_manager_port}',
+                    options=constants.GRPC_SERVERS.GRPC_OPTIONS) as channel:
                 stub = csle_collector.host_manager.host_manager_pb2_grpc.HostManagerStub(channel)
                 csle_collector.host_manager.query_host_manager.start_heartbeat(stub=stub)
 
@@ -851,7 +859,8 @@ class HostController:
         HostController.start_host_manager(emulation_env_config=emulation_env_config, ip=ips[0], logger=logger)
         # Open a gRPC session
         with grpc.insecure_channel(
-                f'{ips[0]}:{emulation_env_config.host_manager_config.host_manager_port}') as channel:
+                f'{ips[0]}:{emulation_env_config.host_manager_config.host_manager_port}',
+                options=constants.GRPC_SERVERS.GRPC_OPTIONS) as channel:
             stub = csle_collector.host_manager.host_manager_pb2_grpc.HostManagerStub(channel)
             csle_collector.host_manager.query_host_manager.start_spark(stub=stub)
 
@@ -869,7 +878,8 @@ class HostController:
         HostController.start_host_manager(emulation_env_config=emulation_env_config, ip=ips[0], logger=logger)
         # Open a gRPC session
         with grpc.insecure_channel(
-                f'{ips[0]}:{emulation_env_config.host_manager_config.host_manager_port}') as channel:
+                f'{ips[0]}:{emulation_env_config.host_manager_config.host_manager_port}',
+                options=constants.GRPC_SERVERS.GRPC_OPTIONS) as channel:
             stub = csle_collector.host_manager.host_manager_pb2_grpc.HostManagerStub(channel)
             csle_collector.host_manager.query_host_manager.stop_spark(stub=stub)
 
@@ -895,7 +905,8 @@ class HostController:
         # Open a gRPC session
         with grpc.insecure_channel(
                 f'{container.docker_gw_bridge_ip}:'
-                f'{emulation_env_config.host_manager_config.host_manager_port}') as channel:
+                f'{emulation_env_config.host_manager_config.host_manager_port}',
+                options=constants.GRPC_SERVERS.GRPC_OPTIONS) as channel:
             stub = csle_collector.host_manager.host_manager_pb2_grpc.HostManagerStub(channel)
             logger.info(f"Configuring filebeat on {container.docker_gw_bridge_ip}, {container.get_full_name()}, "
                         f"ips: {container.get_ips()}")
@@ -930,7 +941,8 @@ class HostController:
         # Open a gRPC session
         with grpc.insecure_channel(
                 f'{container.docker_gw_bridge_ip}:'
-                f'{emulation_env_config.host_manager_config.host_manager_port}') as channel:
+                f'{emulation_env_config.host_manager_config.host_manager_port}',
+                options=constants.GRPC_SERVERS.GRPC_OPTIONS) as channel:
             stub = csle_collector.host_manager.host_manager_pb2_grpc.HostManagerStub(channel)
             logger.info(f"Configuring packetbeat on {container.docker_gw_bridge_ip}, {container.get_full_name()}, "
                         f"ips: {container.get_ips()}")
@@ -962,7 +974,8 @@ class HostController:
         # Open a gRPC session
         with grpc.insecure_channel(
                 f'{container.docker_gw_bridge_ip}:'
-                f'{emulation_env_config.host_manager_config.host_manager_port}') as channel:
+                f'{emulation_env_config.host_manager_config.host_manager_port}',
+                options=constants.GRPC_SERVERS.GRPC_OPTIONS) as channel:
             stub = csle_collector.host_manager.host_manager_pb2_grpc.HostManagerStub(channel)
             logger.info(f"Configuring metricbeat on {container.docker_gw_bridge_ip}, {container.get_full_name()}, "
                         f"ips: {container.get_ips()}")
@@ -998,7 +1011,8 @@ class HostController:
         # Open a gRPC session
         with grpc.insecure_channel(
                 f'{container.docker_gw_bridge_ip}:'
-                f'{emulation_env_config.host_manager_config.host_manager_port}') as channel:
+                f'{emulation_env_config.host_manager_config.host_manager_port}',
+                options=constants.GRPC_SERVERS.GRPC_OPTIONS) as channel:
             stub = csle_collector.host_manager.host_manager_pb2_grpc.HostManagerStub(channel)
             logger.info(f"Configuring heartbeat on {container.docker_gw_bridge_ip}, {container.get_full_name()}, "
                         f"ips: {container.get_ips()}")
@@ -1060,7 +1074,8 @@ class HostController:
         # Open a gRPC session
         with grpc.insecure_channel(
                 f'{ip}:'
-                f'{emulation_env_config.host_manager_config.host_manager_port}') as channel:
+                f'{emulation_env_config.host_manager_config.host_manager_port}',
+                options=constants.GRPC_SERVERS.GRPC_OPTIONS) as channel:
             stub = csle_collector.host_manager.host_manager_pb2_grpc.HostManagerStub(channel)
             logger.info(f"Stopping the Host monitor thread on {ip}.")
             csle_collector.host_manager.query_host_manager.stop_host_monitor(stub=stub)
@@ -1080,7 +1095,8 @@ class HostController:
         # Open a gRPC session
         with grpc.insecure_channel(
                 f'{ip}:'
-                f'{emulation_env_config.host_manager_config.host_manager_port}') as channel:
+                f'{emulation_env_config.host_manager_config.host_manager_port}',
+                options=constants.GRPC_SERVERS.GRPC_OPTIONS) as channel:
             stub = csle_collector.host_manager.host_manager_pb2_grpc.HostManagerStub(channel)
             logger.info(f"Stopping filebeat on {ip}.")
             csle_collector.host_manager.query_host_manager.stop_filebeat(stub=stub)
@@ -1100,7 +1116,8 @@ class HostController:
         # Open a gRPC session
         with grpc.insecure_channel(
                 f'{ip}:'
-                f'{emulation_env_config.host_manager_config.host_manager_port}') as channel:
+                f'{emulation_env_config.host_manager_config.host_manager_port}',
+                options=constants.GRPC_SERVERS.GRPC_OPTIONS) as channel:
             stub = csle_collector.host_manager.host_manager_pb2_grpc.HostManagerStub(channel)
             logger.info(f"Stopping packetbeat on {ip}.")
             csle_collector.host_manager.query_host_manager.stop_packetbeat(stub=stub)
@@ -1120,7 +1137,8 @@ class HostController:
         # Open a gRPC session
         with grpc.insecure_channel(
                 f'{ip}:'
-                f'{emulation_env_config.host_manager_config.host_manager_port}') as channel:
+                f'{emulation_env_config.host_manager_config.host_manager_port}',
+                options=constants.GRPC_SERVERS.GRPC_OPTIONS) as channel:
             stub = csle_collector.host_manager.host_manager_pb2_grpc.HostManagerStub(channel)
             logger.info(f"Stopping metricbeat on {ip}.")
             csle_collector.host_manager.query_host_manager.stop_metricbeat(stub=stub)
@@ -1140,7 +1158,8 @@ class HostController:
         # Open a gRPC session
         with grpc.insecure_channel(
                 f'{ip}:'
-                f'{emulation_env_config.host_manager_config.host_manager_port}') as channel:
+                f'{emulation_env_config.host_manager_config.host_manager_port}',
+                options=constants.GRPC_SERVERS.GRPC_OPTIONS) as channel:
             stub = csle_collector.host_manager.host_manager_pb2_grpc.HostManagerStub(channel)
             logger.info(f"Stopping heartbeat on {ip}.")
             csle_collector.host_manager.query_host_manager.stop_heartbeat(stub=stub)
@@ -1203,7 +1222,7 @@ class HostController:
         :return: the status of the host manager
         """
         # Open a gRPC session
-        with grpc.insecure_channel(f'{ip}:{port}') as channel:
+        with grpc.insecure_channel(f'{ip}:{port}', options=constants.GRPC_SERVERS.GRPC_OPTIONS) as channel:
             stub = csle_collector.host_manager.host_manager_pb2_grpc.HostManagerStub(channel)
             status = csle_collector.host_manager.query_host_manager.get_host_status(stub=stub)
             return status
@@ -1287,12 +1306,12 @@ class HostController:
                     port=emulation_env_config.host_manager_config.host_manager_port, ip=ip)
                 running = True
             except Exception as e:
-                logger.debug(f"Could not fetch Host manager status on IP:{ip}, error: {str(e)}, {repr(e)}")
+                logger.info(f"Could not fetch Host manager status on IP:{ip}, error: {str(e)}, {repr(e)}")
             if status is not None:
                 host_managers_statuses.append((status, ip))
             else:
                 host_managers_statuses.append(
-                    csle_collector.host_manager.host_manager_util.HostManagerUtil.host_monitor_dto_empty())
+                    (csle_collector.host_manager.host_manager_util.HostManagerUtil.host_monitor_dto_empty(), ip))
             host_managers_running.append(running)
         execution_id = emulation_env_config.execution_id
         emulation_name = emulation_env_config.name
