@@ -1,5 +1,5 @@
 import logging
-from typing import Any
+from typing import Any, Tuple
 import subprocess
 import docker
 import psutil
@@ -42,8 +42,8 @@ class ManagementSystemController:
                + constants.COMMANDS.SPACE_DELIM + "prometheus")
         p = subprocess.Popen(cmd, stdout=subprocess.PIPE, shell=True)
         (output, err) = p.communicate()
-        output = str(output)
-        return constants.COMMANDS.SEARCH_PROMETHEUS in str(output) and str(pid) in output
+        output_1 = str(output)
+        return constants.COMMANDS.SEARCH_PROMETHEUS in output_1 and str(pid) in output_1
 
     @staticmethod
     def is_node_exporter_running() -> bool:
@@ -60,8 +60,8 @@ class ManagementSystemController:
                constants.COMMANDS.SEARCH_NODE_EXPORTER)
         p = subprocess.Popen(cmd, stdout=subprocess.PIPE, shell=True)
         (output, err) = p.communicate()
-        output = str(output)
-        return constants.COMMANDS.SEARCH_NODE_EXPORTER in output and str(pid) in output
+        output_1 = str(output)
+        return constants.COMMANDS.SEARCH_NODE_EXPORTER in output_1 and str(pid) in output_1
 
     @staticmethod
     def is_nginx_running() -> bool:
@@ -70,8 +70,12 @@ class ManagementSystemController:
 
         :return: True if nginx is running, false otherwise
         """
-        output = subprocess.run(constants.COMMANDS.NGINX_STATUS.split(" "), capture_output=True, text=True)
-        nginx_running = "active (running)" in output.stdout or "active (exited)" in output.stdout
+        output = ""
+        try:
+            output = subprocess.run(constants.COMMANDS.NGINX_STATUS.split(" "), capture_output=True, text=True).stdout
+        except Exception:
+            pass
+        nginx_running = "active (running)" in output or "active (exited)" in output
         return nginx_running
 
     @staticmethod
@@ -81,8 +85,22 @@ class ManagementSystemController:
 
         :return: True if PostgreSQL is running, false otherwise
         """
-        output = subprocess.run(constants.COMMANDS.POSTGRESQL_STATUS.split(" "), capture_output=True, text=True)
-        postgresql_running = "active (running)" in output.stdout or "active (exited)" in output.stdout
+        output = ""
+        try:
+            output = subprocess.run(constants.COMMANDS.POSTGRESQL_STATUS.split(" "), capture_output=True,
+                                    text=True).stdout
+        except Exception:
+            pass
+        postgresql_running = "active (running)" in output or "active (exited)" in output
+        if postgresql_running:
+            return postgresql_running
+        output = ""
+        try:
+            output = subprocess.run(constants.COMMANDS.POSTGRESQL_STATUS_VERSION.split(" "), capture_output=True,
+                                    text=True).stdout
+        except Exception:
+            pass
+        postgresql_running = "active (running)" in output or "active (exited)" in output
         return postgresql_running
 
     @staticmethod
@@ -92,8 +110,13 @@ class ManagementSystemController:
 
         :return: True if Docker engine is running, false otherwise
         """
-        output = subprocess.run(constants.COMMANDS.DOCKER_ENGINE_STATUS.split(" "), capture_output=True, text=True)
-        docker_engine_running = "active (running)" in output.stdout or "active (exited)" in output.stdout
+        output = ""
+        try:
+            output = subprocess.run(constants.COMMANDS.DOCKER_ENGINE_STATUS.split(" "), capture_output=True,
+                                    text=True).stdout
+        except Exception:
+            pass
+        docker_engine_running = "active (running)" in output or "active (exited)" in output
         return docker_engine_running
 
     @staticmethod
@@ -111,8 +134,8 @@ class ManagementSystemController:
                constants.COMMANDS.SEARCH_MONITOR)
         p = subprocess.Popen(cmd, stdout=subprocess.PIPE, shell=True)
         (output, err) = p.communicate()
-        output = str(output)
-        return constants.COMMANDS.SEARCH_MONITOR in output and str(pid) in output
+        output_1 = str(output)
+        return constants.COMMANDS.SEARCH_MONITOR in output_1 and str(pid) in output_1
 
     @staticmethod
     def start_node_exporter(logger: logging.Logger) -> bool:
@@ -147,17 +170,19 @@ class ManagementSystemController:
         logger.info(f"Building the web app with the command: {cmd}")
         p = subprocess.Popen(cmd, stdout=subprocess.PIPE, shell=True)
         while True:
+            if p.stdout is None:
+                raise ValueError("Cannot read due to NoneType")
             out = p.stdout.read(1)
             if p.poll() is not None:
                 break
-            if out != '':
+            if str(out) != '':
                 try:
                     sys.stdout.write(out.decode("utf-8"))
                 except Exception:
                     pass
                 sys.stdout.flush()
         cmd = constants.COMMANDS.START_CSLE_MGMT_WEBAPP
-        cmd = cmd.replace("python", shutil.which("python"))
+        cmd = cmd.replace("python", str(shutil.which("python")))
         cmd = cmd.replace(f"${constants.CONFIG_FILE.CSLE_HOME_ENV_PARAM}",
                           os.environ[constants.CONFIG_FILE.CSLE_HOME_ENV_PARAM])
         logger.info(f"Starting flask with the command: {cmd}")
@@ -223,7 +248,7 @@ class ManagementSystemController:
         return True
 
     @staticmethod
-    def stop_prometheus(logger: logging.getLogger()) -> bool:
+    def stop_prometheus(logger: logging.RootLogger) -> bool:
         """
         Stops Prometheus
 
@@ -317,7 +342,7 @@ class ManagementSystemController:
         return True
 
     @staticmethod
-    def start_postgresql(logger: logging.Logger) -> (bool, Any, Any):
+    def start_postgresql(logger: logging.RootLogger) -> Tuple[bool, Any, Any]:
         """
         Starts PostgreSQL
 
@@ -333,7 +358,7 @@ class ManagementSystemController:
         return True, output.stdout, output.stderr
 
     @staticmethod
-    def stop_postgresql(logger: logging.Logger) -> (bool, Any, Any):
+    def stop_postgresql(logger: logging.RootLogger) -> Tuple[bool, Any, Any]:
         """
         Stops PostgreSQL
 
@@ -349,7 +374,7 @@ class ManagementSystemController:
         return True, output.stdout, output.stderr
 
     @staticmethod
-    def start_nginx(logger: logging.Logger) -> (bool, Any, Any):
+    def start_nginx(logger: logging.RootLogger) -> Tuple[bool, Any, Any]:
         """
         Starts Nginx
 
@@ -365,7 +390,7 @@ class ManagementSystemController:
         return True, output.stdout, output.stderr
 
     @staticmethod
-    def stop_nginx(logger: logging.Logger) -> (bool, Any, Any):
+    def stop_nginx(logger: logging.RootLogger) -> Tuple[bool, Any, Any]:
         """
         Stops Nginx
 
@@ -381,7 +406,7 @@ class ManagementSystemController:
         return True, output.stdout, output.stderr
 
     @staticmethod
-    def start_docker_engine(logger: logging.Logger) -> (bool, Any, Any):
+    def start_docker_engine(logger: logging.RootLogger) -> Tuple[bool, Any, Any]:
         """
         Starts the Docker engine
 
@@ -397,7 +422,7 @@ class ManagementSystemController:
         return True, output.stdout, output.stderr
 
     @staticmethod
-    def stop_docker_engine(logger: logging.Logger) -> (bool, Any, Any):
+    def stop_docker_engine(logger: logging.RootLogger) -> Tuple[bool, Any, Any]:
         """
         Stops the Docker engine
 
@@ -413,7 +438,7 @@ class ManagementSystemController:
         return True, output.stdout, output.stderr
 
     @staticmethod
-    def start_pgadmin(logger: logging.Logger) -> bool:
+    def start_pgadmin(logger: logging.RootLogger) -> bool:
         """
         Starts pgAdmin
 
@@ -454,7 +479,7 @@ class ManagementSystemController:
         return False
 
     @staticmethod
-    def start_grafana(logger: logging.Logger) -> bool:
+    def start_grafana(logger: logging.RootLogger) -> bool:
         """
         Starts Grafana
 
@@ -462,7 +487,7 @@ class ManagementSystemController:
         :return: True if grafana was started, otherwise False
         """
         if ManagementSystemController.is_grafana_running():
-            logger.info("Grafana is already runnign")
+            logger.info("Grafana is already running")
             return False
         client_1 = docker.from_env()
         containers = client_1.containers.list(all=True)
@@ -501,18 +526,19 @@ class ManagementSystemController:
         pid = ManagementSystemController.read_pid_file(constants.COMMANDS.DOCKER_STATS_MANAGER_PIDFILE)
         if pid == -1:
             return False
+        logging.getLogger().info(pid)
         cmd = (constants.COMMANDS.PS_AUX + constants.COMMANDS.SPACE_DELIM + constants.COMMANDS.PIPE_DELIM +
                constants.COMMANDS.SPACE_DELIM + constants.COMMANDS.GREP + constants.COMMANDS.SPACE_DELIM +
                constants.COMMANDS.SEARCH_DOCKER_STATS_MANAGER)
         p = subprocess.Popen(cmd, stdout=subprocess.PIPE, shell=True)
         (output, err) = p.communicate()
-        output = str(output)
-        return constants.COMMANDS.SEARCH_DOCKER_STATS_MANAGER in output and str(pid) in output
+        output_1 = str(output)
+        return constants.COMMANDS.SEARCH_DOCKER_STATS_MANAGER in output_1 and str(pid) in output_1
 
     @staticmethod
-    def start_docker_stats_manager(logger: logging.Logger, log_file: str = "docker_stats_manager.log",
-                                   log_dir: str = "/var/log/csle", max_workers: int = 10,
-                                   port: int = 50046) -> bool:
+    def start_docker_statsmanager(logger: logging.Logger, log_file: str = "docker_stats_manager.log",
+                                  log_dir: str = "/var/log/csle", max_workers: int = 10,
+                                  port: int = 50046) -> bool:
         """
         Starts the docker stats manager on the docker host if it is not already started
 
@@ -533,7 +559,7 @@ class ManagementSystemController:
         return True
 
     @staticmethod
-    def stop_docker_stats_manager(logger: logging.Logger) -> bool:
+    def stop_docker_statsmanager(logger: logging.Logger) -> bool:
         """
         Stops the statsmanager
 
@@ -573,7 +599,7 @@ class ManagementSystemController:
         :return: True if it is running, false otherwise
         """
         logger.info(f"Checking if PID: {pid} is running")
-        return psutil.pid_exists(pid)
+        return bool(psutil.pid_exists(pid))
 
     @staticmethod
     def stop_pid(pid, logger: logging.Logger) -> bool:
