@@ -4,7 +4,7 @@ import grpc
 import time
 import csle_collector.ryu_manager.ryu_manager_pb2_grpc
 import csle_collector.ryu_manager.ryu_manager_pb2
-import csle_collector.ryu_manager.query_ryu_server
+import csle_collector.ryu_manager.query_ryu_manager
 import csle_collector.ryu_manager.ryu_manager_util
 import csle_common.constants.constants as constants
 from csle_common.dao.emulation_config.emulation_env_config import EmulationEnvConfig
@@ -26,6 +26,9 @@ class SDNControllerManager:
         :param logger: the logger to use for logging
         :return: None
         """
+        if emulation_env_config.sdn_controller_config is None:
+            raise ValueError(f"Cannot start ryu manager for emulation without an SDN config. "
+                             f"Emulation: {emulation_env_config.name}")
         # Connect
         EmulationUtil.connect_admin(emulation_env_config=emulation_env_config,
                                     ip=emulation_env_config.sdn_controller_config.container.docker_gw_bridge_ip,
@@ -75,6 +78,9 @@ class SDNControllerManager:
         :param logger: the logger to use for logging
         :return: None
         """
+        if emulation_env_config.sdn_controller_config is None:
+            raise ValueError(f"Cannot stop ryu manager for emulation without an SDN config. "
+                             f"Emulation: {emulation_env_config.name}")
         # Connect
         EmulationUtil.connect_admin(emulation_env_config=emulation_env_config,
                                     ip=emulation_env_config.sdn_controller_config.container.docker_gw_bridge_ip,
@@ -104,6 +110,9 @@ class SDNControllerManager:
         :param logger: the logger to use for logging
         :return: a RyuDTO with the status
         """
+        if emulation_env_config.sdn_controller_config is None:
+            raise ValueError(f"Cannot get ryu status for emulation without an SDN config. "
+                             f"Emulation: {emulation_env_config.name}")
         SDNControllerManager.start_ryu_manager(emulation_env_config=emulation_env_config, logger=logger)
         ryu_dto = SDNControllerManager.get_ryu_status_by_port_and_ip(
             ip=emulation_env_config.sdn_controller_config.container.docker_gw_bridge_ip,
@@ -111,8 +120,7 @@ class SDNControllerManager:
         return ryu_dto
 
     @staticmethod
-    def get_ryu_status_by_port_and_ip(ip: str, port: int) -> \
-            csle_collector.ryu_manager.ryu_manager_pb2.RyuDTO:
+    def get_ryu_status_by_port_and_ip(ip: str, port: int) -> csle_collector.ryu_manager.ryu_manager_pb2.RyuDTO:
         """
         Method for querying the RyuManager about the status of the Ryu SDN controller
 
@@ -121,11 +129,9 @@ class SDNControllerManager:
         :return: an RyuDTO with the status
         """
         # Open a gRPC session
-        with grpc.insecure_channel(
-                f'{ip}:'
-                f'{port}') as channel:
+        with grpc.insecure_channel(f'{ip}:{port}', options=constants.GRPC_SERVERS.GRPC_OPTIONS) as channel:
             stub = csle_collector.ryu_manager.ryu_manager_pb2_grpc.RyuManagerStub(channel)
-            ryu_dto = csle_collector.ryu_manager.query_ryu_server.get_ryu_status(stub)
+            ryu_dto = csle_collector.ryu_manager.query_ryu_manager.get_ryu_status(stub)
             return ryu_dto
 
     @staticmethod
@@ -137,6 +143,9 @@ class SDNControllerManager:
         :param emulation_env_config: the emulation env config
         :return: a RyuDTO with the status of the server
         """
+        if emulation_env_config.sdn_controller_config is None:
+            raise ValueError(f"Cannot stop Ryu for emulation without an SDN config. "
+                             f"Emulation: {emulation_env_config.name}")
         logger.info(
             f"Stopping RYU SDN controller on container: "
             f"{emulation_env_config.sdn_controller_config.container.docker_gw_bridge_ip}")
@@ -145,9 +154,10 @@ class SDNControllerManager:
         # Open a gRPC session
         with grpc.insecure_channel(
                 f'{emulation_env_config.sdn_controller_config.container.docker_gw_bridge_ip}:'
-                f'{emulation_env_config.sdn_controller_config.manager_port}') as channel:
+                f'{emulation_env_config.sdn_controller_config.manager_port}',
+                options=constants.GRPC_SERVERS.GRPC_OPTIONS) as channel:
             stub = csle_collector.ryu_manager.ryu_manager_pb2_grpc.RyuManagerStub(channel)
-            ryu_dto = csle_collector.ryu_manager.query_ryu_server.stop_ryu(stub)
+            ryu_dto = csle_collector.ryu_manager.query_ryu_manager.stop_ryu(stub)
             return ryu_dto
 
     @staticmethod
@@ -161,6 +171,9 @@ class SDNControllerManager:
         :param logger: the logger to use for logging
         :return: an RyuDTO with the status of the server
         """
+        if emulation_env_config.sdn_controller_config is None:
+            raise ValueError(f"Cannot start Ryu for emulation without an SDN config. "
+                             f"Emulation: {emulation_env_config.name}")
         if emulation_env_config.sdn_controller_config.container.physical_host_ip != physical_server_ip:
             return
         logger.info(
@@ -171,13 +184,14 @@ class SDNControllerManager:
         # Open a gRPC session
         with grpc.insecure_channel(
                 f'{emulation_env_config.sdn_controller_config.container.docker_gw_bridge_ip}:'
-                f'{emulation_env_config.sdn_controller_config.manager_port}') as channel:
+                f'{emulation_env_config.sdn_controller_config.manager_port}',
+                options=constants.GRPC_SERVERS.GRPC_OPTIONS) as channel:
             stub = csle_collector.ryu_manager.ryu_manager_pb2_grpc.RyuManagerStub(channel)
             logger.info(
                 f"Starting RYU, port: {emulation_env_config.sdn_controller_config.controller_port}, "
                 f"web_port: {emulation_env_config.sdn_controller_config.controller_web_api_port}, "
                 f"controller: {emulation_env_config.sdn_controller_config.controller_module_name}")
-            ryu_dto = csle_collector.ryu_manager.query_ryu_server.start_ryu(
+            ryu_dto = csle_collector.ryu_manager.query_ryu_manager.start_ryu(
                 stub, port=emulation_env_config.sdn_controller_config.controller_port,
                 web_port=emulation_env_config.sdn_controller_config.controller_web_api_port,
                 controller=emulation_env_config.sdn_controller_config.controller_module_name)
@@ -194,6 +208,9 @@ class SDNControllerManager:
         :param logger: the logger to use for logging
         :return: an RyuDTO with the status
         """
+        if emulation_env_config.sdn_controller_config is None:
+            raise ValueError(f"Cannot start Ryu monitor for emulation without an SDN config. "
+                             f"Emulation: {emulation_env_config.name}")
         if emulation_env_config.sdn_controller_config.container.physical_host_ip != physical_server_ip:
             return
         logger.info(
@@ -204,9 +221,10 @@ class SDNControllerManager:
         # Open a gRPC session
         with grpc.insecure_channel(
                 f'{emulation_env_config.sdn_controller_config.container.docker_gw_bridge_ip}:'
-                f'{emulation_env_config.sdn_controller_config.manager_port}') as channel:
+                f'{emulation_env_config.sdn_controller_config.manager_port}',
+                options=constants.GRPC_SERVERS.GRPC_OPTIONS) as channel:
             stub = csle_collector.ryu_manager.ryu_manager_pb2_grpc.RyuManagerStub(channel)
-            ryu_dto = csle_collector.ryu_manager.query_ryu_server.start_ryu_monitor(
+            ryu_dto = csle_collector.ryu_manager.query_ryu_manager.start_ryu_monitor(
                 stub, kafka_ip=emulation_env_config.kafka_config.container.get_ips()[0],
                 kafka_port=emulation_env_config.kafka_config.kafka_port,
                 time_step_len=emulation_env_config.sdn_controller_config.time_step_len_seconds)
@@ -222,6 +240,9 @@ class SDNControllerManager:
         :param logger: the logger to use for logging
         :return: an RyuDTO with the status of the server
         """
+        if emulation_env_config.sdn_controller_config is None:
+            raise ValueError(f"Cannot stop Ryu monitor for emulation without an SDN config. "
+                             f"Emulation: {emulation_env_config.name}")
         logger.info(
             f"Stopping Ryu monitor on container: "
             f"{emulation_env_config.sdn_controller_config.container.docker_gw_bridge_ip}")
@@ -230,9 +251,10 @@ class SDNControllerManager:
         # Open a gRPC session
         with grpc.insecure_channel(
                 f'{emulation_env_config.sdn_controller_config.container.docker_gw_bridge_ip}:'
-                f'{emulation_env_config.sdn_controller_config.manager_port}') as channel:
+                f'{emulation_env_config.sdn_controller_config.manager_port}',
+                options=constants.GRPC_SERVERS.GRPC_OPTIONS) as channel:
             stub = csle_collector.ryu_manager.ryu_manager_pb2_grpc.RyuManagerStub(channel)
-            ryu_dto = csle_collector.ryu_manager.query_ryu_server.stop_ryu_monitor(stub)
+            ryu_dto = csle_collector.ryu_manager.query_ryu_manager.stop_ryu_monitor(stub)
             return ryu_dto
 
     @staticmethod
@@ -243,6 +265,9 @@ class SDNControllerManager:
         :param emulation_env_config: the emulation env config
         :return: the list of IP addresses
         """
+        if emulation_env_config.sdn_controller_config is None:
+            raise ValueError(f"Cannot get Ryu managers IPs for emulation without an SDN config. "
+                             f"Emulation: {emulation_env_config.name}")
         return [emulation_env_config.sdn_controller_config.container.docker_gw_bridge_ip]
 
     @staticmethod
@@ -253,6 +278,9 @@ class SDNControllerManager:
         :param emulation_env_config: the emulation env config
         :return: the list of IP addresses
         """
+        if emulation_env_config.sdn_controller_config is None:
+            raise ValueError(f"Cannot get Ryu managers ports for emulation without an SDN config. "
+                             f"Emulation: {emulation_env_config.name}")
         return [emulation_env_config.sdn_controller_config.manager_port]
 
     @staticmethod
@@ -267,6 +295,9 @@ class SDNControllerManager:
         :param physical_server_ip: the ip of the physical server
         :return: a DTO with the status of the Ryu managers
         """
+        if emulation_env_config.sdn_controller_config is None:
+            raise ValueError(f"Cannot get ryu managers info for emulation without an SDN config. "
+                             f"Emulation: {emulation_env_config.name}")
         ryu_managers_ips = SDNControllerManager.get_ryu_managers_ips(emulation_env_config=emulation_env_config)
         ryu_managers_ports = SDNControllerManager.get_ryu_managers_ports(emulation_env_config=emulation_env_config)
         ryu_managers_statuses = []
