@@ -1,12 +1,13 @@
 from typing import Dict, Any
+from csle_base.json_serializable import JSONSerializable
 
 
-class StatisticsDataset:
+class StatisticsDataset(JSONSerializable):
     """
     DTO representing a dataset of statistics
     """
 
-    def __init__(self, name: str, description: str, download_count: int, file_path: str, url: str, date_added,
+    def __init__(self, name: str, description: str, download_count: int, file_path: str, url: str, date_added: float,
                  num_measurements: int, num_metrics: int, size_in_gb: float, compressed_size_in_gb: float,
                  citation: str, num_files: int, file_format: str, added_by: str, conditions: str, metrics: str,
                  num_conditions: int):
@@ -51,9 +52,11 @@ class StatisticsDataset:
 
     def to_dict(self) -> Dict[str, Any]:
         """
+        Converts the object to a dict representation
+        
         :return: a dict representation of the object
         """
-        d = {}
+        d: Dict[str, Any] = {}
         d["id"] = self.id
         d["name"] = self.name
         d["description"] = self.description
@@ -106,28 +109,6 @@ class StatisticsDataset:
                f"file_format: {self.file_format}, added_by: {self.added_by}, metrics: {self.metrics}, " \
                f"conditions: {self.conditions}, num_conditions: {self.num_conditions}"
 
-    def to_json_str(self) -> str:
-        """
-        Converts the DTO into a json string
-
-        :return: the json string representation of the DTO
-        """
-        import json
-        json_str = json.dumps(self.to_dict(), indent=4, sort_keys=True)
-        return json_str
-
-    def to_json_file(self, json_file_path: str) -> None:
-        """
-        Saves the DTO to a json file
-
-        :param json_file_path: the json file path to save  the DTO to
-        :return: None
-        """
-        import io
-        json_str = self.to_json_str()
-        with io.open(json_file_path, 'w', encoding='utf-8') as f:
-            f.write(json_str)
-
     @staticmethod
     def from_json_file(json_file_path: str) -> "StatisticsDataset":
         """
