@@ -1,4 +1,4 @@
-from typing import List
+from typing import Optional, List, Dict, Any
 import gymnasium as gym
 from csle_common.dao.emulation_action.attacker.emulation_attacker_action import EmulationAttackerAction
 from csle_common.dao.emulation_action.attacker.emulation_attacker_action_id import EmulationAttackerActionId
@@ -11,20 +11,21 @@ from csle_common.dao.emulation_action.attacker.emulation_attacker_network_servic
 from csle_common.dao.emulation_action.attacker.emulation_attacker_shell_actions import EmulationAttackerShellActions
 from csle_common.dao.emulation_action.attacker.emulation_attacker_stopping_actions \
     import EmulationAttackerStoppingActions
+from csle_base.json_serializable import JSONSerializable
 
 
-class EmulationAttackerActionConfig:
+class EmulationAttackerActionConfig(JSONSerializable):
     """
     Configuration of the action space for the attacker in the emulation
     """
 
-    def __init__(self, num_indices: int, actions: List[EmulationAttackerAction] = None,
-                 nmap_action_ids: List[EmulationAttackerActionId] = None,
-                 network_service_action_ids: List[EmulationAttackerActionId] = None,
-                 shell_action_ids: List[EmulationAttackerActionId] = None,
-                 nikto_action_ids: List[EmulationAttackerActionId] = None,
-                 masscan_action_ids: List[EmulationAttackerActionId] = None,
-                 stopping_action_ids: List[EmulationAttackerActionId] = None):
+    def __init__(self, num_indices: int, actions: Optional[List[EmulationAttackerAction]] = None,
+                 nmap_action_ids: Optional[List[EmulationAttackerActionId]] = None,
+                 network_service_action_ids: Optional[List[EmulationAttackerActionId]] = None,
+                 shell_action_ids: Optional[List[EmulationAttackerActionId]] = None,
+                 nikto_action_ids: Optional[List[EmulationAttackerActionId]] = None,
+                 masscan_action_ids: Optional[List[EmulationAttackerActionId]] = None,
+                 stopping_action_ids: Optional[List[EmulationAttackerActionId]] = None):
         """
         Class constructor
 
@@ -37,6 +38,8 @@ class EmulationAttackerActionConfig:
         :param masscan_action_ids: list of ids of the actions that are Masscan actions
         :param stopping_action_ids: List of ids of the actions that are actions related to optimal stopping
         """
+        if actions is None:
+            raise ValueError("self.num_actions can not be defined")
         self.num_actions = len(actions)
         self.actions = actions
         self.num_indices = num_indices
@@ -53,6 +56,10 @@ class EmulationAttackerActionConfig:
         self.nikto_action_ids = nikto_action_ids
         self.masscan_action_ids = masscan_action_ids
         self.stopping_action_ids = stopping_action_ids
+        if self.nmap_action_ids is None or self.network_service_action_ids is None or \
+            self.shell_action_ids is None or self.nikto_action_ids is None or \
+                self.masscan_action_ids is None or self.stopping_action_ids is None:
+            raise ValueError("At least one of the actions is None")
         self.action_ids = (self.nmap_action_ids + self.network_service_action_ids + self.shell_action_ids
                            + self.nikto_action_ids + self.masscan_action_ids + self.stopping_action_ids)
         self.num_node_specific_actions = len(self.action_ids)
@@ -189,7 +196,7 @@ class EmulationAttackerActionConfig:
             attacker_actions.append(EmulationAttackerNMAPActions.HTTP_ENUM(index=idx))
             attacker_actions.append(EmulationAttackerNMAPActions.HTTP_GREP(index=idx))
             attacker_actions.append(EmulationAttackerNMAPActions.VULSCAN(index=idx))
-            attacker_actions.append(EmulationAttackerNMAPActions.FINGER(index=idx)),
+            attacker_actions.append(EmulationAttackerNMAPActions.FINGER(index=idx))
             attacker_actions.append(EmulationAttackerShellActions.SAMBACRY_EXPLOIT(index=idx))
             attacker_actions.append(EmulationAttackerShellActions.SHELLSHOCK_EXPLOIT(index=idx))
             attacker_actions.append(EmulationAttackerShellActions.DVWA_SQL_INJECTION(index=idx))
@@ -312,3 +319,59 @@ class EmulationAttackerActionConfig:
                                                                masscan_action_ids=masscan_action_ids,
                                                                stopping_action_ids=stopping_action_ids)
         return attacker_action_config
+
+    def __str__(self) -> str:
+        """
+        :return: a string representation of the object
+        """
+        return f"num_indices: {self.num_indices}, actions: {self.actions}, nmap_action_ids: {self.nmap_action_ids}, " \
+               f"network_service_action_ids: {self.network_service_action_ids}, " \
+               f"shell_action_ids: {self.shell_action_ids}, nikto_action_ids: {self.nikto_action_ids}, " \
+               f"masscan_action_ids: {self.masscan_action_ids}, stopping_action_ids: {self.stopping_action_ids}"
+
+    def to_dict(self) -> Dict[str, Any]:
+        """
+        Converts the object to a dict representation
+
+        :return: a dict representation of the object
+        """
+        d: Dict[str, Any] = {}
+        d["num_indices"] = self.num_indices
+        d["actions"] = self.actions
+        d["nmap_action_ids"] = self.nmap_action_ids
+        d["network_service_action_ids"] = self.network_service_action_ids
+        d["shell_action_ids"] = self.shell_action_ids
+        d["nikto_action_ids"] = self.nikto_action_ids
+        d["masscan_action_ids"] = self.masscan_action_ids
+        d["stopping_action_ids"] = self.stopping_action_ids
+        return d
+
+    @staticmethod
+    def from_dict(d: Dict[str, Any]) -> "EmulationAttackerActionConfig":
+        """
+        Converts a dict representation to an instance
+
+        :param d: the dict to convert
+        :return: the created instance
+        """
+        obj = EmulationAttackerActionConfig(
+            num_indices=d["num_indices"], actions=d["actions"], nmap_action_ids=d["nmap_action_ids"],
+            network_service_action_ids=d["network_service_action_ids"], shell_action_ids=d["shell_action_ids"],
+            nikto_action_ids=d["nikto_action_ids"], masscan_action_ids=d["masscan_action_ids"],
+            stopping_action_ids=d["stopping_action_ids"]
+        )
+        return obj
+
+    @staticmethod
+    def from_json_file(json_file_path: str) -> "EmulationAttackerActionConfig":
+        """
+        Reads a json file and converts it to a DTO
+
+        :param json_file_path: the json file path
+        :return: the converted DTO
+        """
+        import io
+        import json
+        with io.open(json_file_path, 'r') as f:
+            json_str = f.read()
+        return EmulationAttackerActionConfig.from_dict(json.loads(json_str))
