@@ -1,11 +1,12 @@
-from typing import List, Dict, Any
+from typing import Optional, List, Dict, Any
 import time
 from csle_common.dao.emulation_action.defender.emulation_defender_action_type import EmulationDefenderActionType
 from csle_common.dao.emulation_action.defender.emulation_defender_action_id import EmulationDefenderActionId
 from csle_common.dao.emulation_action.defender.emulation_defender_action_outcome import EmulationDefenderActionOutcome
+from csle_base.json_serializable import JSONSerializable
 
 
-class EmulationDefenderAction:
+class EmulationDefenderAction(JSONSerializable):
     """
     Class representing an action of the defender in the environment
     """
@@ -14,7 +15,7 @@ class EmulationDefenderAction:
                  type: EmulationDefenderActionType, descr: str,
                  ips: List[str], index: int,
                  action_outcome: EmulationDefenderActionOutcome = EmulationDefenderActionOutcome.GAME_END,
-                 alt_cmds: List[str] = None, execution_time: float = 0.0, ts: float = 0.0):
+                 alt_cmds: Optional[List[str]] = None, execution_time: float = 0.0, ts: float = 0.0):
         """
         Class constructor
 
@@ -38,9 +39,11 @@ class EmulationDefenderAction:
         self.ips = ips
         self.action_outcome = action_outcome
         self.alt_cmds = alt_cmds
+        if self.alt_cmds is None:
+            self.alt_cmds = []
         self.index = index
         self.ts = ts
-        self.execution_time = execution_time
+        self.execution_time = round(execution_time, 3)
 
     def __str__(self) -> str:
         """
@@ -60,14 +63,14 @@ class EmulationDefenderAction:
             id=d["id"], name=d["name"], cmds=d["cmds"], type=d["type"], descr=d["descr"],
             ips=d["ips"],
             index=d["index"], action_outcome=d["action_outcome"], alt_cmds=d["alt_cmds"],
-            ts=d["ts"])
+            ts=d["ts"], execution_time=d["execution_time"])
         return obj
 
     def to_dict(self) -> Dict[str, Any]:
         """
         :return: a dicr representation of the object
         """
-        d = {}
+        d: Dict[str, Any] = {}
         d["id"] = self.id
         d["name"] = self.name
         d["cmds"] = list(self.cmds)
@@ -76,7 +79,7 @@ class EmulationDefenderAction:
         d["ips"] = list(self.ips)
         d["index"] = self.index
         d["action_outcome"] = self.action_outcome
-        d["alt_cmds"] = list(self.alt_cmds)
+        d["alt_cmds"] = list(self.alt_cmds) if self.alt_cmds is not None else []
         d["execution_time"] = self.execution_time
         d["ts"] = self.ts
         return d
@@ -103,7 +106,7 @@ class EmulationDefenderAction:
         ts = time.time()
         record = f"{ts},{self.id},{self.descr},{self.index},{self.name}," \
                  f"{self.execution_time},{'_'.join(self.ips)},{'_'.join(self.cmds)},{self.type}," \
-                 f"{self.action_outcome},{'_'.join(self.alt_cmds)}"
+                 f"{self.action_outcome},{'_'.join(self.alt_cmds) if self.alt_cmds is not None else []}"
         return record
 
     @staticmethod
@@ -125,28 +128,6 @@ class EmulationDefenderAction:
                                       alt_cmds=parts[10].split("_"))
         return obj
 
-    def to_json_str(self) -> str:
-        """
-        Converts the DTO into a json string
-
-        :return: the json string representation of the DTO
-        """
-        import json
-        json_str = json.dumps(self.to_dict(), indent=4, sort_keys=True)
-        return json_str
-
-    def to_json_file(self, json_file_path: str) -> None:
-        """
-        Saves the DTO to a json file
-
-        :param json_file_path: the json file path to save  the DTO to
-        :return: None
-        """
-        import io
-        json_str = self.to_json_str()
-        with io.open(json_file_path, 'w', encoding='utf-8') as f:
-            f.write(json_str)
-
     @staticmethod
     def from_json_file(json_file_path: str) -> "EmulationDefenderAction":
         """
