@@ -6,9 +6,10 @@ from csle_collector.client_manager.dao.workflow_service import WorkflowService
 from csle_collector.client_manager.dao.client import Client
 from csle_common.dao.emulation_config.container_network import ContainerNetwork
 from csle_common.util.general_util import GeneralUtil
+from csle_base.json_serializable import JSONSerializable
 
 
-class ClientPopulationConfig:
+class ClientPopulationConfig(JSONSerializable):
     """
     A DTO object representing the configuration of the client population of an emulation
     """
@@ -81,15 +82,17 @@ class ClientPopulationConfig:
                             workflow_distribution=[1])],
             workflows_config=WorkflowsConfig(
                 workflow_markov_chains=[WorkflowMarkovChain(
-                    initial_state=0, transition_matrix=[[0.8,0.2], [0,1]], id=0)],
+                    initial_state=0, transition_matrix=[[0.8, 0.2], [0, 1]], id=0)],
                 workflow_services=[WorkflowService(ips_and_commands=[('localhost', "echo ' '")], id=0)])
         )
 
     def to_dict(self) -> Dict[str, Any]:
         """
+        Converts the object to a dict representation
+        
         :return: a dict representation of the object
         """
-        d = {}
+        d: Dict[str, Any] = {}
         d["ip"] = self.ip
         d["networks"] = list(map(lambda x: x.to_dict(), self.networks))
         d["client_manager_port"] = self.client_manager_port
@@ -117,28 +120,6 @@ class ClientPopulationConfig:
                f"docker_gw_bridge_ip:{self.docker_gw_bridge_ip}, physical_host_ip: {self.physical_host_ip}," \
                f"clients:{list(map(lambda x: str(x), self.clients))}, workflows_config: {self.workflows_config}"
 
-    def to_json_str(self) -> str:
-        """
-        Converts the DTO into a json string
-
-        :return: the json string representation of the DTO
-        """
-        import json
-        json_str = json.dumps(self.to_dict(), indent=4, sort_keys=True)
-        return json_str
-
-    def to_json_file(self, json_file_path: str) -> None:
-        """
-        Saves the DTO to a json file
-
-        :param json_file_path: the json file path to save  the DTO to
-        :return: None
-        """
-        import io
-        json_str = self.to_json_str()
-        with io.open(json_file_path, 'w', encoding='utf-8') as f:
-            f.write(json_str)
-
     @staticmethod
     def from_json_file(json_file_path: str) -> "ClientPopulationConfig":
         """
