@@ -1,8 +1,9 @@
 from typing import Dict, Any, List
 from csle_common.dao.emulation_config.cluster_node import ClusterNode
+from csle_base.json_serializable import JSONSerializable
 
 
-class ClusterConfig:
+class ClusterConfig(JSONSerializable):
     """
     A DTO Class representing the config of a CSLE cluster
     """
@@ -17,6 +18,8 @@ class ClusterConfig:
 
     def to_dict(self) -> Dict[str, Any]:
         """
+        Converts the object to a dict representation
+
         :return: a dict representation of the object
         """
         d = {}
@@ -39,28 +42,6 @@ class ClusterConfig:
         """
         return f"cluster_nodes: {list(map(lambda x: str(x), self.cluster_nodes))}"
 
-    def to_json_str(self) -> str:
-        """
-        Converts the DTO into a json string
-
-        :return: the json string representation of the DTO
-        """
-        import json
-        json_str = json.dumps(self.to_dict(), indent=4, sort_keys=True)
-        return json_str
-
-    def to_json_file(self, json_file_path: str) -> None:
-        """
-        Saves the DTO to a json file
-
-        :param json_file_path: the json file path to save  the DTO to
-        :return: None
-        """
-        import io
-        json_str = self.to_json_str()
-        with io.open(json_file_path, 'w', encoding='utf-8') as f:
-            f.write(json_str)
-
     @staticmethod
     def from_json_file(json_file_path: str) -> "ClusterConfig":
         """
