@@ -1,7 +1,8 @@
 from typing import Dict, Any
+from csle_base.json_serializable import JSONSerializable
 
 
-class DockerStatsManagerConfig:
+class DockerStatsManagerConfig(JSONSerializable):
     """
     Represents the configuration of the docker stats managers in a CSLE emulation
     """
@@ -44,9 +45,11 @@ class DockerStatsManagerConfig:
 
     def to_dict(self) -> Dict[str, Any]:
         """
+        Converts the object to a dict representation
+        
         :return: a dict representation of the object
         """
-        d = {}
+        d: Dict[str, Any] = {}
         d["docker_stats_manager_port"] = self.docker_stats_manager_port
         d["time_step_len_seconds"] = self.time_step_len_seconds
         d["version"] = self.version
@@ -65,28 +68,6 @@ class DockerStatsManagerConfig:
                f"docker_stats_manager_log_file: {self.docker_stats_manager_log_file}, " \
                f"docker_stats_manager_max_workers: {self.docker_stats_manager_max_workers}"
 
-    def to_json_str(self) -> str:
-        """
-        Converts the DTO into a json string
-
-        :return: the json string representation of the DTO
-        """
-        import json
-        json_str = json.dumps(self.to_dict(), indent=4, sort_keys=True)
-        return json_str
-
-    def to_json_file(self, json_file_path: str) -> None:
-        """
-        Saves the DTO to a json file
-
-        :param json_file_path: the json file path to save  the DTO to
-        :return: None
-        """
-        import io
-        json_str = self.to_json_str()
-        with io.open(json_file_path, 'w', encoding='utf-8') as f:
-            f.write(json_str)
-
     @staticmethod
     def from_json_file(json_file_path: str) -> "DockerStatsManagerConfig":
         """
