@@ -10,9 +10,10 @@ from csle_common.dao.emulation_config.traffic_managers_info import TrafficManage
 from csle_common.dao.emulation_config.ryu_managers_info import RyuManagersInfo
 from csle_common.dao.emulation_config.node_container_config import NodeContainerConfig
 from csle_common.dao.emulation_config.container_network import ContainerNetwork
+from csle_base.json_serializable import JSONSerializable
 
 
-class EmulationExecutionInfo:
+class EmulationExecutionInfo(JSONSerializable):
     """
     DTO containing the runtime status of an emulation execution
     """
@@ -79,9 +80,11 @@ class EmulationExecutionInfo:
 
     def to_dict(self) -> Dict[str, Any]:
         """
+        Converts the object to a dictionary representation
+
         :return: a dict representation of the object
         """
-        d = {}
+        d: Dict[str, Any] = {}
         d["emulation_name"] = self.emulation_name
         d["execution_id"] = self.execution_id
         d["snort_ids_managers_info"] = self.snort_ids_managers_info.to_dict()
@@ -109,6 +112,7 @@ class EmulationExecutionInfo:
 
         :return: a dto representation of the object
         """
+    
         dto = EmulationExecutionInfo(
             emulation_name=d["emulation_name"], execution_id=d["execution_id"],
             snort_ids_managers_info=SnortIdsManagersInfo.from_dict(d["snort_ids_managers_info"]),
@@ -119,9 +123,23 @@ class EmulationExecutionInfo:
             host_managers_info=HostManagersInfo.from_dict(d["host_managers_info"]),
             client_managers_info=ClientManagersInfo.from_dict(d["client_managers_info"]),
             docker_stats_managers_info=DockerStatsManagersInfo.from_dict(d["docker_stats_managers_info"]),
-            running_containers=list(map(lambda x: x.from_dict(), d["running_containers"])),
-            stopped_containers=list(map(lambda x: x.from_dict(), d["stopped_containers"])),
-            active_networks=list(map(lambda x: x.from_dict(), d["active_networks"])),
-            inactive_networks=list(map(lambda x: x.from_dict(), d["inactive_networks"])),
-            ryu_managers_info=d["ryu_managers_info"])
+            running_containers=list(map(lambda x: NodeContainerConfig.from_dict(x), d["running_containers"])),
+            stopped_containers=list(map(lambda x: NodeContainerConfig.from_dict(x), d["stopped_containers"])),
+            active_networks=list(map(lambda x: ContainerNetwork.from_dict(x), d["active_networks"])),
+            inactive_networks=list(map(lambda x: ContainerNetwork.from_dict(x), d["inactive_networks"])),
+            ryu_managers_info=RyuManagersInfo.from_dict(d["ryu_managers_info"]))
         return dto
+
+    @staticmethod
+    def from_json_file(json_file_path: str) -> "EmulationExecutionInfo":
+        """
+        Reads a json file and converts it to a DTO
+
+        :param json_file_path: the json file path
+        :return: the converted DTO
+        """
+        import io
+        import json
+        with io.open(json_file_path, 'r') as f:
+            json_str = f.read()
+        return EmulationExecutionInfo.from_dict(json.loads(json_str))
