@@ -1,20 +1,21 @@
-from typing import List, Dict, Any, Tuple, Union
+from typing import Optional, List, Dict, Any, Tuple, Union
 import json
 import os
-import numpy as np
 from csle_common.logging.log import Logger
 import csle_common.constants.constants as constants
 import csle_collector.constants.constants as collector_constants
 from csle_common.dao.emulation_action.attacker.emulation_attacker_action import EmulationAttackerAction
 from csle_common.dao.emulation_action.attacker.emulation_attacker_action_id import EmulationAttackerActionId
 from csle_common.dao.emulation_action.defender.emulation_defender_action import EmulationDefenderAction
+from csle_common.dao.encoding.np_encoder import NpEncoder
 from csle_common.dao.emulation_observation.attacker.emulation_attacker_observation_state \
     import EmulationAttackerObservationState
 from csle_common.dao.emulation_observation.defender.emulation_defender_observation_state \
     import EmulationDefenderObservationState
+from csle_base.json_serializable import JSONSerializable
 
 
-class EmulationTrace:
+class EmulationTrace(JSONSerializable):
     """
     DTO class representing a trace in the emulation system
     """
@@ -41,14 +42,14 @@ class EmulationTrace:
         """
         :return: a string representation of the object
         """
-        print(f"initial_attacker_observation_state:{self.initial_attacker_observation_state}"
-              f"initial_defender_observation_state:{self.initial_defender_observation_state}"
-              f"attacker_observation_states:{self.attacker_observation_states}\n"
-              f"defender_observation_states:{self.defender_observation_states}\n"
-              f"attacker_actions:{self.attacker_actions}\n"
-              f"defender_actions:{self.defender_actions}\n"
-              f"emulation_name: {self.emulation_name},"
-              f"id:{self.id}")
+        return f"initial_attacker_observation_state:{self.initial_attacker_observation_state}" \
+               f"initial_defender_observation_state:{self.initial_defender_observation_state}" \
+               f"attacker_observation_states:{self.attacker_observation_states}\n" \
+               f"defender_observation_states:{self.defender_observation_states}\n" \
+               f"attacker_actions:{self.attacker_actions}\n" \
+               f"defender_actions:{self.defender_actions}\n" \
+               f"emulation_name: {self.emulation_name}," \
+               f"id:{self.id}"
 
     @staticmethod
     def from_dict(d: Dict[str, Any]) -> "EmulationTrace":
@@ -76,9 +77,11 @@ class EmulationTrace:
 
     def to_dict(self) -> Dict[str, Any]:
         """
+        Converts the object to a dict representation
+
         :return: a dict representation of the object
         """
-        d = {}
+        d: Dict[str, Any] = {}
         d["initial_attacker_observation_state"] = self.initial_attacker_observation_state.to_dict()
         d["initial_defender_observation_state"] = self.initial_defender_observation_state.to_dict()
         d["attacker_observation_states"] = list(map(lambda x: x.to_dict(), self.attacker_observation_states))
@@ -90,7 +93,7 @@ class EmulationTrace:
         return d
 
     @staticmethod
-    def save_traces_to_disk(traces_save_dir, traces: List["EmulationTrace"], traces_file: str = None) -> None:
+    def save_traces_to_disk(traces_save_dir, traces: List["EmulationTrace"], traces_file: Optional[str] = None) -> None:
         """
         Utility function for saving a list of traces to a json file
 
@@ -99,13 +102,13 @@ class EmulationTrace:
         :param traces_file: the filename of the traces file
         :return: None
         """
-        traces = list(map(lambda x: x.to_dict(), traces))
+        traces_1 = list(map(lambda x: x.to_dict(), traces))
         if traces_file is None:
             traces_file = constants.SYSTEM_IDENTIFICATION.EMULATION_TRACES_FILE
         if not os.path.exists(traces_save_dir):
             os.makedirs(traces_save_dir)
         with open(traces_save_dir + "/" + traces_file, 'w') as fp:
-            json.dump({"traces": traces}, fp, cls=NpEncoder)
+            json.dump({"traces": traces_1}, fp, cls=NpEncoder)
 
     @staticmethod
     def load_traces_from_disk(traces_file: str) -> List["EmulationTrace"]:
@@ -122,35 +125,13 @@ class EmulationTrace:
                     traces = d[constants.METADATA_STORE.TRACES_PROPERTY]
                 else:
                     traces = d["emulations"]
-                traces = list(map(lambda x: EmulationTrace.from_dict(x), traces))
-                return traces
+                traces_1 = list(map(lambda x: EmulationTrace.from_dict(x), traces))
+                return traces_1
         else:
             Logger.__call__().get_logger().info("Warning: Could not "
                                                 f"read traces file, path does not exist:{traces_file}")
             return []
 
-    def to_json_str(self) -> str:
-        """
-        Converts the DTO into a json string
-
-        :return: the json string representation of the DTO
-        """
-        import json
-        json_str = json.dumps(self.to_dict(), indent=4, sort_keys=True)
-        return json_str
-
-    def to_json_file(self, json_file_path: str) -> None:
-        """
-        Saves the DTO to a json file
-
-        :param json_file_path: the json file path to save  the DTO to
-        :return: None
-        """
-        import io
-        json_str = self.to_json_str()
-        with io.open(json_file_path, 'w', encoding='utf-8') as f:
-            f.write(json_str)
-
     @staticmethod
     def from_json_str(json_str: str) -> "EmulationTrace":
         """
@@ -181,7 +162,7 @@ class EmulationTrace:
         """
         :return: approximately the number of attributes recorded per time-step of the trace
         """
-        num_attributes = 2
+        num_attributes: int = 2
         num_attributes = (num_attributes + (1 + len(self.attacker_observation_states))
                           * self.initial_attacker_observation_state.num_attributes())
         num_attributes = (num_attributes + (1 + len(self.defender_observation_states))
@@ -207,7 +188,7 @@ class EmulationTrace:
         return dto
 
     def to_csv_record(self, max_time_steps: int, max_nodes: int, max_ports: int, max_vulns: int,
-                      null_value: int = -1) -> Tuple[List[str], List[Union[str, int, float]]]:
+                      null_value: int = -1) -> Tuple[List[Union[str, int, float]], List[str]]:
         """
         Converts the trace into a csv row
 
@@ -220,7 +201,7 @@ class EmulationTrace:
         """
         # lookup tables for vuln names, service names, protocol names
         labels = []
-        values = []
+        values: List[Union[str, float]] = []
         intrusion_started = False
         attacker_observations = [self.initial_attacker_observation_state] + self.attacker_observation_states
         defender_observations = [self.initial_defender_observation_state] + self.defender_observation_states
@@ -475,27 +456,27 @@ class EmulationTrace:
             else:
                 values.append(null_value)
             labels.append(f"{t}_defender_num_failed_login_attempts")
-            if len(defender_observations) > t:
+            if len(defender_observations) > t and defender_observations[t].avg_aggregated_host_metrics is not None:
                 values.append(defender_observations[t].avg_aggregated_host_metrics.num_failed_login_attempts)
             else:
                 values.append(null_value)
             labels.append(f"{t}_defender_num_open_connections")
-            if len(defender_observations) > t:
+            if len(defender_observations) > t and defender_observations[t].avg_aggregated_host_metrics is not None:
                 values.append(defender_observations[t].avg_aggregated_host_metrics.num_open_connections)
             else:
                 values.append(null_value)
             labels.append(f"{t}_defender_num_login_events")
-            if len(defender_observations) > t:
+            if len(defender_observations) > t and defender_observations[t].avg_aggregated_host_metrics is not None:
                 values.append(defender_observations[t].avg_aggregated_host_metrics.num_login_events)
             else:
                 values.append(null_value)
             labels.append(f"{t}_defender_num_processes")
-            if len(defender_observations) > t:
+            if len(defender_observations) > t and defender_observations[t].avg_aggregated_host_metrics is not None:
                 values.append(defender_observations[t].avg_aggregated_host_metrics.num_processes)
             else:
                 values.append(null_value)
             labels.append(f"{t}_defender_num_users")
-            if len(defender_observations) > t:
+            if len(defender_observations) > t and defender_observations[t].avg_aggregated_host_metrics is not None:
                 values.append(defender_observations[t].avg_aggregated_host_metrics.num_users)
             else:
                 values.append(null_value)
@@ -770,17 +751,3 @@ class EmulationTrace:
                     values.append(null_value)
         assert len(values) == len(labels)
         return values, labels
-
-
-class NpEncoder(json.JSONEncoder):
-    """
-    Encoder for Numpy arrays to JSON
-    """
-    def default(self, obj):
-        if isinstance(obj, np.integer):
-            return int(obj)
-        if isinstance(obj, np.floating):
-            return float(obj)
-        if isinstance(obj, np.ndarray):
-            return obj.tolist()
-        return super(NpEncoder, self).default(obj)
