@@ -1,9 +1,10 @@
 from typing import List, Dict, Any
 from csle_common.dao.emulation_config.node_flags_config import NodeFlagsConfig
 from csle_common.dao.emulation_config.flag import Flag
+from csle_base.json_serializable import JSONSerializable
 
 
-class FlagsConfig:
+class FlagsConfig(JSONSerializable):
     """
     A DTO representing the set of flags in an emulation environment
     """
@@ -31,6 +32,8 @@ class FlagsConfig:
 
     def to_dict(self) -> Dict[str, Any]:
         """
+        Converts the object to a dict representation
+        
         :return: a dict representation of the object
         """
         d = {}
@@ -50,34 +53,12 @@ class FlagsConfig:
         :param ips: the list of ip addresses to get flags for
         :return: the list of flags
         """
-        flags = []
+        flags: List[Flag] = []
         for node_flag_config in self.node_flag_configs:
             if node_flag_config.ip in ips:
                 flags = flags + node_flag_config.flags
         return flags
 
-    def to_json_str(self) -> str:
-        """
-        Converts the DTO into a json string
-
-        :return: the json string representation of the DTO
-        """
-        import json
-        json_str = json.dumps(self.to_dict(), indent=4, sort_keys=True)
-        return json_str
-
-    def to_json_file(self, json_file_path: str) -> None:
-        """
-        Saves the DTO to a json file
-
-        :param json_file_path: the json file path to save  the DTO to
-        :return: None
-        """
-        import io
-        json_str = self.to_json_str()
-        with io.open(json_file_path, 'w', encoding='utf-8') as f:
-            f.write(json_str)
-
     @staticmethod
     def from_json_file(json_file_path: str) -> "FlagsConfig":
         """
