@@ -2,9 +2,10 @@ from typing import List, Dict, Any
 import csle_collector.host_manager.host_manager_pb2_grpc
 import csle_collector.host_manager.host_manager_pb2
 import csle_collector.host_manager.host_manager_util as host_manager_util
+from csle_base.json_serializable import JSONSerializable
 
 
-class HostManagersInfo:
+class HostManagersInfo(JSONSerializable):
     """
     DTO containing the status of the Host managers for a given emulation execution
     """
@@ -43,9 +44,11 @@ class HostManagersInfo:
 
     def to_dict(self) -> Dict[str, Any]:
         """
+        Converts the object to a dict representation
+
         :return: a dict representation of the object
         """
-        d = {}
+        d: Dict[str, Any] = {}
         d["host_managers_running"] = self.host_managers_running
         d["ips"] = self.ips
         d["emulation_name"] = self.emulation_name
@@ -70,3 +73,17 @@ class HostManagersInfo:
                 map(lambda x: host_manager_util.HostManagerUtil.host_monitor_dto_from_dict(x),
                     d["host_managers_statuses"])))
         return dto
+
+    @staticmethod
+    def from_json_file(json_file_path: str) -> "HostManagersInfo":
+        """
+        Reads a json file and converts it to a DTO
+
+        :param json_file_path: the json file path
+        :return: the converted DTO
+        """
+        import io
+        import json
+        with io.open(json_file_path, 'r') as f:
+            json_str = f.read()
+        return HostManagersInfo.from_dict(json.loads(json_str))
