@@ -1,7 +1,8 @@
-from typing import List, Dict, Any
+from typing import List, Dict, Any, Union
+from csle_base.json_serializable import JSONSerializable
 
 
-class KafkaTopic:
+class KafkaTopic(JSONSerializable):
     """
     DTO representing a kafka topic (Records are assumed to be comma-separated strings) where attributes define
     the list of columns in the csv.
@@ -38,9 +39,11 @@ class KafkaTopic:
 
     def to_dict(self) -> Dict[str, Any]:
         """
+        Converts the object to a dict representation
+
         :return: a dict representation of the object
         """
-        d = {}
+        d: Dict[str, Union[str, int, List[str]]] = {}
         d["name"] = self.name
         d["num_partitions"] = self.num_partitions
         d["num_replicas"] = self.num_replicas
@@ -56,28 +59,6 @@ class KafkaTopic:
                f"num_replicas:{self.num_replicas}, attributes: {','.join(self.attributes)}, " \
                f"retention_time_hours:{self.retention_time_hours}"
 
-    def to_json_str(self) -> str:
-        """
-        Converts the DTO into a json string
-
-        :return: the json string representation of the DTO
-        """
-        import json
-        json_str = json.dumps(self.to_dict(), indent=4, sort_keys=True)
-        return json_str
-
-    def to_json_file(self, json_file_path: str) -> None:
-        """
-        Saves the DTO to a json file
-
-        :param json_file_path: the json file path to save  the DTO to
-        :return: None
-        """
-        import io
-        json_str = self.to_json_str()
-        with io.open(json_file_path, 'w', encoding='utf-8') as f:
-            f.write(json_str)
-
     @staticmethod
     def from_json_file(json_file_path: str) -> "KafkaTopic":
         """
