@@ -1,9 +1,10 @@
 from typing import List, Dict, Any
 from csle_common.dao.emulation_config.flag import Flag
 from csle_common.util.general_util import GeneralUtil
+from csle_base.json_serializable import JSONSerializable
 
 
-class NodeFlagsConfig:
+class NodeFlagsConfig(JSONSerializable):
     """
     A DTO object representing the set of flags at a specific container in an emulation environment
     """
@@ -24,9 +25,11 @@ class NodeFlagsConfig:
 
     def to_dict(self) -> Dict[str, Any]:
         """
+        Converts the object to a dict representation
+        
         :return: a dict representation of the object
         """
-        d = {}
+        d: Dict[str, Any] = {}
         d["ip"] = self.ip
         d["flags"] = list(map(lambda x: x.to_dict(), self.flags))
         d["docker_gw_bridge_ip"] = self.docker_gw_bridge_ip
@@ -51,28 +54,6 @@ class NodeFlagsConfig:
         return f"ip:{self.ip}, docker_gw_bridge_ip:{self.docker_gw_bridge_ip}, " \
                f"flags:{','.join(list(map(lambda x: str(x), self.flags)))}, physical_host_ip: {self.physical_host_ip}"
 
-    def to_json_str(self) -> str:
-        """
-        Converts the DTO into a json string
-
-        :return: the json string representation of the DTO
-        """
-        import json
-        json_str = json.dumps(self.to_dict(), indent=4, sort_keys=True)
-        return json_str
-
-    def to_json_file(self, json_file_path: str) -> None:
-        """
-        Saves the DTO to a json file
-
-        :param json_file_path: the json file path to save  the DTO to
-        :return: None
-        """
-        import io
-        json_str = self.to_json_str()
-        with io.open(json_file_path, 'w', encoding='utf-8') as f:
-            f.write(json_str)
-
     @staticmethod
     def from_json_file(json_file_path: str) -> "NodeFlagsConfig":
         """
