@@ -1,9 +1,10 @@
 from typing import List, Tuple, Dict, Any
 from csle_common.dao.emulation_config.node_network_config import NodeNetworkConfig
 from csle_common.util.general_util import GeneralUtil
+from csle_base.json_serializable import JSONSerializable
 
 
-class NodeResourcesConfig:
+class NodeResourcesConfig(JSONSerializable):
     """
     A DTO object representing the resources of a specific container in an emulation environment
     """
@@ -11,7 +12,8 @@ class NodeResourcesConfig:
     def __init__(self, container_name: str,
                  num_cpus: int, available_memory_gb: int,
                  ips_and_network_configs: List[Tuple[str, NodeNetworkConfig]],
-                 docker_gw_bridge_ip: str = "", physical_host_ip: str = ""):
+                 docker_gw_bridge_ip: str = "", physical_host_ip: str = "",
+                 disk_space_gb: int = 100):
         """
         Initializes the DTO
 
@@ -21,6 +23,7 @@ class NodeResourcesConfig:
         :param ips_and_network_configs: list of ip adresses and network configurations
         :param docker_gw_bridge_ip: IP to reach the container from the host network
         :param physical_host_ip: IP of the physical host where the container is running
+        :param disk_space_gb: the amount of disk space in GB available to the node
         """
         self.container_name = container_name
         self.num_cpus = num_cpus
@@ -28,6 +31,7 @@ class NodeResourcesConfig:
         self.ips_and_network_configs = ips_and_network_configs
         self.docker_gw_bridge_ip = docker_gw_bridge_ip
         self.physical_host_ip = physical_host_ip
+        self.disk_space_gb = disk_space_gb
 
     def get_ips(self) -> List[str]:
         """
@@ -43,20 +47,29 @@ class NodeResourcesConfig:
         :param d: the dict to convert
         :return: the created instance
         """
+        ips_and_network_configs = []
+        for ip, cfg in d["ips_and_network_configs"]:
+            if cfg is not None:
+                parsed_cfg = NodeNetworkConfig.from_dict(cfg)
+            else:
+                parsed_cfg = NodeNetworkConfig()
+            ips_and_network_configs.append((str(ip), parsed_cfg))
         obj = NodeResourcesConfig(
             container_name=d["container_name"],
-            ips_and_network_configs=list(map(lambda x: (x[0], NodeNetworkConfig.from_dict(x[1])),
-                                             d["ips_and_network_configs"])),
+            ips_and_network_configs=ips_and_network_configs,
             num_cpus=d["num_cpus"], available_memory_gb=d["available_memory_gb"],
-            docker_gw_bridge_ip=d["docker_gw_bridge_ip"], physical_host_ip=d["physical_host_ip"]
+            docker_gw_bridge_ip=d["docker_gw_bridge_ip"], physical_host_ip=d["physical_host_ip"],
+            disk_space_gb=d["disk_space_gb"]
         )
         return obj
 
     def to_dict(self) -> Dict[str, Any]:
         """
+        Converts the object to a dict representation
+
         :return: a dict representation of the object
         """
-        d = {}
+        d: Dict[str, Any] = {}
         d["container_name"] = self.container_name
         d["ips_and_network_configs"] = list(map(lambda x: (x[0], None if x[1] is None else x[1].to_dict()),
                                                 self.ips_and_network_configs))
@@ -64,6 +77,7 @@ class NodeResourcesConfig:
         d["available_memory_gb"] = self.available_memory_gb
         d["docker_gw_bridge_ip"] = self.docker_gw_bridge_ip
         d["physical_host_ip"] = self.physical_host_ip
+        d["disk_space_gb"] = self.disk_space_gb
         return d
 
     def __str__(self) -> str:
@@ -72,29 +86,8 @@ class NodeResourcesConfig:
         """
         return f"num_cpus: {self.num_cpus}, available_memory_gb:{self.available_memory_gb}, " \
                f"container_name:{self.container_name}, ips_and_network_configs: {self.ips_and_network_configs}," \
-               f"docker_gw_bridge_ip: {self.docker_gw_bridge_ip}, physical_host_ip: {self.physical_host_ip}"
-
-    def to_json_str(self) -> str:
-        """
-        Converts the DTO into a json string
-
-        :return: the json string representation of the DTO
-        """
-        import json
-        json_str = json.dumps(self.to_dict(), indent=4, sort_keys=True)
-        return json_str
-
-    def to_json_file(self, json_file_path: str) -> None:
-        """
-        Saves the DTO to a json file
-
-        :param json_file_path: the json file path to save  the DTO to
-        :return: None
-        """
-        import io
-        json_str = self.to_json_str()
-        with io.open(json_file_path, 'w', encoding='utf-8') as f:
-            f.write(json_str)
+               f"docker_gw_bridge_ip: {self.docker_gw_bridge_ip}, physical_host_ip: {self.physical_host_ip}," \
+               f"disk_space_gb: {self.disk_space_gb}"
 
     @staticmethod
     def from_json_file(json_file_path: str) -> "NodeResourcesConfig":
@@ -135,4 +128,4 @@ class NodeResourcesConfig:
         :return: get the schema of the DTO
         """
         return NodeResourcesConfig(container_name="", num_cpus=1, available_memory_gb=1,
-                                   ips_and_network_configs=[("", NodeNetworkConfig.schema())])
+                                   ips_and_network_configs=[("", NodeNetworkConfig.schema())], disk_space_gb=100)
