@@ -1,18 +1,19 @@
-from typing import List, Dict, Any, Union
+from typing import Optional, List, Dict, Any, Union
 from csle_common.dao.emulation_config.vulnerability_type import VulnType
 from csle_common.dao.emulation_config.transport_protocol import TransportProtocol
 from csle_common.dao.emulation_config.credential import Credential
 from csle_common.util.general_util import GeneralUtil
+from csle_base.json_serializable import JSONSerializable
 
 
-class NodeVulnerabilityConfig:
+class NodeVulnerabilityConfig(JSONSerializable):
     """
     A DTO object representing a vulnerability of a container in the emulation environment
     """
 
     def __init__(self, ip: str, vuln_type: VulnType, name: str, port: Union[int, None],
-                 protocol: TransportProtocol, credentials: List[Credential] = None,
-                 cvss: float = 2.0, cve: str = None, service: str = None, root: bool = False,
+                 protocol: TransportProtocol, credentials: Optional[List[Credential]] = None,
+                 cvss: float = 2.0, cve: Optional[str] = None, service: Optional[str] = None, root: bool = False,
                  docker_gw_bridge_ip: str = "", physical_host_ip: str = ""):
         """
         Initializes the DTO
@@ -45,15 +46,17 @@ class NodeVulnerabilityConfig:
 
     def to_dict(self) -> Dict[str, Any]:
         """
+        Converts the object to a dict representation
+
         :return: a dict representation of the object
         """
-        d = {}
+        d: Dict[str, Any] = {}
         d["ip"] = self.ip
         d["vuln_type"] = self.vuln_type
         d["name"] = self.name
         d["port"] = self.port
         d["protocol"] = self.protocol
-        d["credentials"] = list(map(lambda x: x.to_dict(), self.credentials))
+        d["credentials"] = list(map(lambda x: x.to_dict(), self.credentials)) if self.credentials is not None else []
         d["root"] = self.root
         d["cve"] = self.cve
         d["docker_gw_bridge_ip"] = self.docker_gw_bridge_ip
@@ -81,32 +84,12 @@ class NodeVulnerabilityConfig:
         :return: a string representation of the object
         """
         return f"node_internal_ip:{self.ip}, vuln_type:{self.vuln_type}, name:{self.name}, port:{self.port}, " \
-               f"protocol: {self.protocol}, credentials: {list(map(lambda x: str(x), self.credentials))}, " \
+               f"protocol: {self.protocol}, " \
+               f"credentials: {list(map(lambda x: str(x), self.credentials)) if self.credentials is not None else []}" \
+               f", " \
                f"cvss: {self.cvss}, cve: {self.cve}, service: {self.service}, root:{self.root}, " \
                f"docker_gw_bridge_ip: {self.docker_gw_bridge_ip}, physical_host_ip: {self.physical_host_ip}"
 
-    def to_json_str(self) -> str:
-        """
-        Converts the DTO into a json string
-
-        :return: the json string representation of the DTO
-        """
-        import json
-        json_str = json.dumps(self.to_dict(), indent=4, sort_keys=True)
-        return json_str
-
-    def to_json_file(self, json_file_path: str) -> None:
-        """
-        Saves the DTO to a json file
-
-        :param json_file_path: the json file path to save  the DTO to
-        :return: None
-        """
-        import io
-        json_str = self.to_json_str()
-        with io.open(json_file_path, 'w', encoding='utf-8') as f:
-            f.write(json_str)
-
     @staticmethod
     def from_json_file(json_file_path: str) -> "NodeVulnerabilityConfig":
         """
