@@ -1,7 +1,8 @@
-from typing import Dict, Any
+from typing import Dict, Any, Union
+from csle_base.json_serializable import JSONSerializable
 
 
-class OSSECIDSManagerConfig:
+class OSSECIDSManagerConfig(JSONSerializable):
     """
     Represents the configuration of the OSSEC IDS managers in a CSLE emulation
     """
@@ -42,11 +43,13 @@ class OSSECIDSManagerConfig:
                                     ossec_ids_manager_max_workers=d["ossec_ids_manager_max_workers"])
         return obj
 
-    def to_dict(self) -> Dict[str, Any]:
+    def to_dict(self) -> Dict[str, Union[str, int]]:
         """
+        Converts the object to a dict representation
+
         :return: a dict representation of the object
         """
-        d = {}
+        d: Dict[str, Union[str, int]] = {}
         d["ossec_ids_manager_port"] = self.ossec_ids_manager_port
         d["time_step_len_seconds"] = self.time_step_len_seconds
         d["version"] = self.version
@@ -65,28 +68,6 @@ class OSSECIDSManagerConfig:
                f"ossec_ids_manager_log_dir: {self.ossec_ids_manager_log_dir}, " \
                f"ossec_ids_manager_max_workers: {self.ossec_ids_manager_max_workers}"
 
-    def to_json_str(self) -> str:
-        """
-        Converts the DTO into a json string
-
-        :return: the json string representation of the DTO
-        """
-        import json
-        json_str = json.dumps(self.to_dict(), indent=4, sort_keys=True)
-        return json_str
-
-    def to_json_file(self, json_file_path: str) -> None:
-        """
-        Saves the DTO to a json file
-
-        :param json_file_path: the json file path to save  the DTO to
-        :return: None
-        """
-        import io
-        json_str = self.to_json_str()
-        with io.open(json_file_path, 'w', encoding='utf-8') as f:
-            f.write(json_str)
-
     @staticmethod
     def from_json_file(json_file_path: str) -> "OSSECIDSManagerConfig":
         """
