@@ -1,8 +1,9 @@
 from typing import List, Dict, Any
 from csle_common.dao.emulation_config.ovs_switch_config import OvsSwitchConfig
+from csle_base.json_serializable import JSONSerializable
 
 
-class OVSConfig:
+class OVSConfig(JSONSerializable):
     """
     DTO containing the configuration of OVS in an emulation
     """
@@ -28,6 +29,8 @@ class OVSConfig:
 
     def to_dict(self) -> Dict[str, Any]:
         """
+        Converts the object to a dict representation
+
         :return: a dict representation of the object
         """
         d = {}
@@ -40,28 +43,6 @@ class OVSConfig:
         """
         return f"switch_configs:{list(map(lambda x: str(x), self.switch_configs))}"
 
-    def to_json_str(self) -> str:
-        """
-        Converts the DTO into a json string
-
-        :return: the json string representation of the DTO
-        """
-        import json
-        json_str = json.dumps(self.to_dict(), indent=4, sort_keys=True)
-        return json_str
-
-    def to_json_file(self, json_file_path: str) -> None:
-        """
-        Saves the DTO to a json file
-
-        :param json_file_path: the json file path to save  the DTO to
-        :return: None
-        """
-        import io
-        json_str = self.to_json_str()
-        with io.open(json_file_path, 'w', encoding='utf-8') as f:
-            f.write(json_str)
-
     @staticmethod
     def from_json_file(json_file_path: str) -> "OVSConfig":
         """
