@@ -1,8 +1,9 @@
 from typing import List, Dict, Any
 from csle_common.dao.emulation_config.node_users_config import NodeUsersConfig
+from csle_base.json_serializable import JSONSerializable
 
 
-class UsersConfig:
+class UsersConfig(JSONSerializable):
     """
     A DTO object representing the users configuration of an emulation environment
     """
@@ -30,6 +31,8 @@ class UsersConfig:
 
     def to_dict(self) -> Dict[str, Any]:
         """
+        Converts the object to a dict representation
+        
         :return: a dict representation of the object
         """
         d = {}
@@ -49,34 +52,14 @@ class UsersConfig:
         :param ips: the list of ips to get the root usernames for
         :return: the list of root usernames
         """
-        root_usernames = []
+        root_usernames: List[str] = []
         for users_config in self.users_configs:
             if users_config.ip in ips:
-                root_usernames = root_usernames + users_config.users
+                for user in users_config.users:
+                    if user.root:
+                        root_usernames.append(user.username)
         return root_usernames
 
-    def to_json_str(self) -> str:
-        """
-        Converts the DTO into a json string
-
-        :return: the json string representation of the DTO
-        """
-        import json
-        json_str = json.dumps(self.to_dict(), indent=4, sort_keys=True)
-        return json_str
-
-    def to_json_file(self, json_file_path: str) -> None:
-        """
-        Saves the DTO to a json file
-
-        :param json_file_path: the json file path to save  the DTO to
-        :return: None
-        """
-        import io
-        json_str = self.to_json_str()
-        with io.open(json_file_path, 'w', encoding='utf-8') as f:
-            f.write(json_str)
-
     @staticmethod
     def from_json_file(json_file_path: str) -> "UsersConfig":
         """
