@@ -1,8 +1,9 @@
 from typing import List, Dict, Any
 from csle_common.dao.emulation_config.node_vulnerability_config import NodeVulnerabilityConfig
+from csle_base.json_serializable import JSONSerializable
 
 
-class VulnerabilitiesConfig:
+class VulnerabilitiesConfig(JSONSerializable):
     """
     A DTO class representing the vulnerabilities configuration of an emulation environment
     """
@@ -17,6 +18,8 @@ class VulnerabilitiesConfig:
 
     def to_dict(self) -> Dict[str, Any]:
         """
+        Converts the object to a dict representation
+        
         :return: a dict representation of the object
         """
         d = {}
@@ -53,28 +56,6 @@ class VulnerabilitiesConfig:
                 vulnerabilities.append(node_vuln_config)
         return vulnerabilities
 
-    def to_json_str(self) -> str:
-        """
-        Converts the DTO into a json string
-
-        :return: the json string representation of the DTO
-        """
-        import json
-        json_str = json.dumps(self.to_dict(), indent=4, sort_keys=True)
-        return json_str
-
-    def to_json_file(self, json_file_path: str) -> None:
-        """
-        Saves the DTO to a json file
-
-        :param json_file_path: the json file path to save  the DTO to
-        :return: None
-        """
-        import io
-        json_str = self.to_json_str()
-        with io.open(json_file_path, 'w', encoding='utf-8') as f:
-            f.write(json_str)
-
     @staticmethod
     def from_json_file(json_file_path: str) -> "VulnerabilitiesConfig":
         """
