@@ -1,5 +1,6 @@
-from typing import List, Set, Dict, Any
+from typing import List, Set, Dict, Any, Optional
 import copy
+from csle_common.dao.emulation_config.flag import Flag
 from csle_common.dao.emulation_config.credential import Credential
 from csle_common.dao.emulation_observation.common.emulation_port_observation_state import EmulationPortObservationState
 from csle_common.dao.emulation_observation.common.emulation_vulnerability_observation_state \
@@ -8,11 +9,12 @@ from csle_common.dao.emulation_observation.common.emulation_connection_observati
     import EmulationConnectionObservationState
 from csle_common.dao.emulation_action_result.nmap_host_result import NmapHostResult
 from csle_common.dao.emulation_action_result.nmap_trace import NmapTrace
+from csle_base.json_serializable import JSONSerializable
 
 
-class EmulationAttackerMachineObservationState:
+class EmulationAttackerMachineObservationState(JSONSerializable):
     """
-    Represent's the attacker's belief state of a component in the emulation
+    Represents the attacker's belief state of a component in the emulation
     """
 
     def __init__(self, ips: List[str]):
@@ -32,7 +34,7 @@ class EmulationAttackerMachineObservationState:
         self.backdoor_credentials: List[Credential] = []
         self.logged_in = False
         self.root = False
-        self.flags_found: Set[str] = set()
+        self.flags_found: Set[Flag] = set()
         self.filesystem_searched = False
         self.untried_credentials = False
         self.ssh_connections: List[EmulationConnectionObservationState] = []
@@ -41,7 +43,7 @@ class EmulationAttackerMachineObservationState:
         self.logged_in_services: List[str] = []
         self.root_services: List[str] = []
         self.hostnames: List[str] = []
-        self.trace: NmapTrace = None
+        self.trace: Optional[NmapTrace] = None
         self.telnet_brute_tried = False
         self.ssh_brute_tried = False
         self.ftp_brute_tried = False
@@ -124,7 +126,7 @@ class EmulationAttackerMachineObservationState:
             key=lambda x: service_lookup[x.service] if x.service is not None else x.username,
             reverse=False)
 
-    def _vuln_lookup(self, name, lookup_table) -> int:
+    def _vuln_lookup(self, name: str, lookup_table: Dict[str, int]) -> int:
         """
         Looks up the id of a vulnerability in a lookup table
 
@@ -214,6 +216,12 @@ class EmulationAttackerMachineObservationState:
 
         :return: the created AttackerMachineObservationState
         """
+        if nmap_host_result.ips is None or \
+                nmap_host_result.ports is None or \
+                nmap_host_result.vulnerabilities is None or \
+                nmap_host_result.credentials is None or \
+                nmap_host_result.hostnames is None:
+            raise ValueError("NMapHostResult is incomplete, at least one attribute is None")
         m_obs = EmulationAttackerMachineObservationState(ips=nmap_host_result.ips)
         ports = list(map(lambda x: x.to_obs(), nmap_host_result.ports))
         m_obs.ports = ports
@@ -295,9 +303,11 @@ class EmulationAttackerMachineObservationState:
 
     def to_dict(self) -> Dict[str, Any]:
         """
+        Converts the object to a dict representation
+
         :return: a dict representation of the object
         """
-        d = {}
+        d: Dict[str, Any] = {}
         d["ips"] = self.ips
         d["os"] = self.os
         d["ports"] = list(map(lambda x: x.to_dict(), self.ports))
@@ -342,28 +352,6 @@ class EmulationAttackerMachineObservationState:
         d["reachable"] = list(self.reachable)
         return d
 
-    def to_json_str(self) -> str:
-        """
-        Converts the DTO into a json string
-
-        :return: the json string representation of the DTO
-        """
-        import json
-        json_str = json.dumps(self.to_dict(), indent=4, sort_keys=True)
-        return json_str
-
-    def to_json_file(self, json_file_path: str) -> None:
-        """
-        Saves the DTO to a json file
-
-        :param json_file_path: the json file path to save  the DTO to
-        :return: None
-        """
-        import io
-        json_str = self.to_json_str()
-        with io.open(json_file_path, 'w', encoding='utf-8') as f:
-            f.write(json_str)
-
     @staticmethod
     def from_json_file(json_file_path: str) -> "EmulationAttackerMachineObservationState":
         """
@@ -423,7 +411,7 @@ class EmulationAttackerMachineObservationState:
         dto.osvdb_vulns = [EmulationVulnerabilityObservationState.schema()]
         dto.shell_access_credentials = [Credential.schema()]
         dto.backdoor_credentials = [Credential.schema()]
-        dto.flags_found.add("")
+        dto.flags_found.add(Flag.schema())
         dto.ssh_connections = [EmulationConnectionObservationState.schema()]
         dto.ftp_connections = [EmulationConnectionObservationState.schema()]
         dto.telnet_connections = [EmulationConnectionObservationState.schema()]
