@@ -1,15 +1,16 @@
-from typing import Dict, Any
+from typing import Optional, Dict, Any
 from csle_common.dao.emulation_config.credential import Credential
+from csle_base.json_serializable import JSONSerializable
 
 
-class EmulationConnectionObservationState:
+class EmulationConnectionObservationState(JSONSerializable):
     """
     A DTO representing a connection observation in the emulation
     """
 
     def __init__(self, conn, credential: Credential, root: bool, service: str, port: int, tunnel_thread=None,
-                 tunnel_port: int = None, interactive_shell=None,
-                 proxy: "EmulationConnectionObservationState" = None, ip: str = None):
+                 tunnel_port: Optional[int] = None, interactive_shell=None,
+                 proxy: Optional["EmulationConnectionObservationState"] = None, ip: Optional[str] = None):
         """
         Intializes the DTO
 
@@ -24,8 +25,6 @@ class EmulationConnectionObservationState:
         :param proxy: a proxy for the connection
         :param ip: the ip of the connection
         """
-        if proxy is not None:
-            assert ip != proxy.ip
         self.conn = conn
         self.credential = credential
         self.root = root
@@ -55,7 +54,7 @@ class EmulationConnectionObservationState:
         """
         :return: a dict represnetation of the object
         """
-        d = {}
+        d: Dict[str, Any] = {}
         d["credential"] = self.credential.to_dict()
         d["root"] = self.root
         d["port"] = self.port
@@ -123,28 +122,6 @@ class EmulationConnectionObservationState:
                 pass
             self.proxy = None
 
-    def to_json_str(self) -> str:
-        """
-        Converts the DTO into a json string
-
-        :return: the json string representation of the DTO
-        """
-        import json
-        json_str = json.dumps(self.to_dict(), indent=4, sort_keys=True)
-        return json_str
-
-    def to_json_file(self, json_file_path: str) -> None:
-        """
-        Saves the DTO to a json file
-
-        :param json_file_path: the json file path to save  the DTO to
-        :return: None
-        """
-        import io
-        json_str = self.to_json_str()
-        with io.open(json_file_path, 'w', encoding='utf-8') as f:
-            f.write(json_str)
-
     @staticmethod
     def from_json_file(json_file_path: str) -> "EmulationConnectionObservationState":
         """
