@@ -1,14 +1,15 @@
-from typing import Dict, Any, Union
+from typing import Dict, Any
 from csle_common.dao.emulation_config.transport_protocol import TransportProtocol
 from csle_common.dao.emulation_config.network_service import NetworkService
+from csle_base.json_serializable import JSONSerializable
 
 
-class EmulationPortObservationState:
+class EmulationPortObservationState(JSONSerializable):
     """
     DTO Representation a port observation in the emulation
     """
 
-    def __init__(self, port: int, open: bool, service: int, protocol: TransportProtocol, http_enum: str = "",
+    def __init__(self, port: int, open: bool, service: str, protocol: TransportProtocol, http_enum: str = "",
                  http_grep: str = "", vulscan: str = "", version: str = "", fingerprint: str = ""):
         """
         Initializes the DTO
@@ -35,9 +36,11 @@ class EmulationPortObservationState:
 
     def to_dict(self) -> Dict[str, Any]:
         """
+        Converts the object to a dict representation
+
         :return: a dict representation of the object
         """
-        d = {}
+        d: Dict[str, Any] = {}
         d["port"] = self.port
         d["open"] = self.open
         d["service"] = self.service
@@ -50,15 +53,13 @@ class EmulationPortObservationState:
         return d
 
     @staticmethod
-    def from_dict(d: Union[Dict[str, Any], None]) -> "EmulationPortObservationState":
+    def from_dict(d: Dict[str, Any]) -> "EmulationPortObservationState":
         """
         Converts a dict representation of the object to an instance
 
         :param d: the dict to convert
         :return: the created object instance
         """
-        if d is None:
-            return None
         obj = EmulationPortObservationState(
             port=d["port"],
             open=d["open"],
@@ -90,7 +91,8 @@ class EmulationPortObservationState:
         return service
 
     @staticmethod
-    def from_network_service(network_service: NetworkService, service_lookup: dict) -> "EmulationPortObservationState":
+    def from_network_service(network_service: NetworkService,
+                             service_lookup: Dict[str, str]) -> "EmulationPortObservationState":
         """
         Converts a network service into a port observation state
 
@@ -117,28 +119,6 @@ class EmulationPortObservationState:
         )
         return c
 
-    def to_json_str(self) -> str:
-        """
-        Converts the DTO into a json string
-
-        :return: the json string representation of the DTO
-        """
-        import json
-        json_str = json.dumps(self.to_dict(), indent=4, sort_keys=True)
-        return json_str
-
-    def to_json_file(self, json_file_path: str) -> None:
-        """
-        Saves the DTO to a json file
-
-        :param json_file_path: the json file path to save  the DTO to
-        :return: None
-        """
-        import io
-        json_str = self.to_json_str()
-        with io.open(json_file_path, 'w', encoding='utf-8') as f:
-            f.write(json_str)
-
     @staticmethod
     def from_json_file(json_file_path: str) -> "EmulationPortObservationState":
         """
@@ -164,5 +144,5 @@ class EmulationPortObservationState:
         """
         :return: get the schema of the DTO
         """
-        return EmulationPortObservationState(port=-1, open=True, service=-1, protocol=TransportProtocol.TCP,
+        return EmulationPortObservationState(port=-1, open=True, service="", protocol=TransportProtocol.TCP,
                                              http_enum="", http_grep="", vulscan="", version="", fingerprint="")
