@@ -1,4 +1,4 @@
-from typing import List, Dict, Any
+from typing import Optional, List, Dict, Any
 from csle_common.dao.emulation_observation.common.emulation_port_observation_state \
     import EmulationPortObservationState
 from csle_common.dao.emulation_observation.common.emulation_connection_observation_state \
@@ -9,21 +9,21 @@ from csle_common.consumer_threads.docker_host_stats_consumer_thread import Docke
 from csle_common.consumer_threads.snort_ids_log_consumer_thread import SnortIdsLogConsumerThread
 from csle_common.consumer_threads.ossec_ids_log_consumer_thread import OSSECIdsLogConsumerThread
 from csle_common.dao.emulation_config.kafka_config import KafkaConfig
-from csle_collector.host_manager.host_metrics import HostMetrics
-from csle_collector.docker_stats_manager.docker_stats import DockerStats
-from csle_collector.snort_ids_manager.snort_ids_ip_alert_counters import SnortIdsIPAlertCounters
-from csle_collector.ossec_ids_manager.ossec_ids_alert_counters import OSSECIdsAlertCounters
+from csle_collector.host_manager.dao.host_metrics import HostMetrics
+from csle_collector.docker_stats_manager.dao.docker_stats import DockerStats
+from csle_collector.snort_ids_manager.dao.snort_ids_ip_alert_counters import SnortIdsIPAlertCounters
+from csle_collector.ossec_ids_manager.dao.ossec_ids_alert_counters import OSSECIdsAlertCounters
+from csle_base.json_serializable import JSONSerializable
 
 
-class EmulationDefenderMachineObservationState:
+class EmulationDefenderMachineObservationState(JSONSerializable):
     """
     Represents the defender's belief state of a component in the emulation
     """
 
-    def __init__(self, ips: List[str], kafka_config: KafkaConfig,
-                 host_metrics: HostMetrics = None, docker_stats: DockerStats = None,
-                 snort_ids_ip_alert_counters: SnortIdsIPAlertCounters = None,
-                 ossec_ids_alert_counters: OSSECIdsAlertCounters = None):
+    def __init__(self, ips: List[str], kafka_config: Optional[KafkaConfig], host_metrics: HostMetrics,
+                 docker_stats: DockerStats, snort_ids_ip_alert_counters: SnortIdsIPAlertCounters,
+                 ossec_ids_alert_counters: OSSECIdsAlertCounters):
         """
         Initializes the DTO
 
@@ -40,21 +40,13 @@ class EmulationDefenderMachineObservationState:
         self.ssh_connections: List[EmulationConnectionObservationState] = []
         self.kafka_config = kafka_config
         self.host_metrics = host_metrics
-        if self.host_metrics is None:
-            self.host_metrics = HostMetrics()
         self.docker_stats = docker_stats
-        if self.docker_stats is None:
-            self.docker_stats = DockerStats()
         self.snort_ids_ip_alert_counters = snort_ids_ip_alert_counters
-        if self.snort_ids_ip_alert_counters is None:
-            self.snort_ids_ip_alert_counters = SnortIdsIPAlertCounters()
         self.ossec_ids_alert_counters = ossec_ids_alert_counters
-        if self.ossec_ids_alert_counters is None:
-            self.ossec_ids_alert_counters = OSSECIdsAlertCounters()
-        self.host_metrics_consumer_thread = None
-        self.docker_stats_consumer_thread = None
-        self.snort_ids_log_consumer_thread = None
-        self.ossec_ids_log_consumer_thread = None
+        self.host_metrics_consumer_thread: Optional[HostMetricsConsumerThread] = None
+        self.docker_stats_consumer_thread: Optional[DockerHostStatsConsumerThread] = None
+        self.snort_ids_log_consumer_thread: Optional[SnortIdsLogConsumerThread] = None
+        self.ossec_ids_log_consumer_thread: Optional[OSSECIdsLogConsumerThread] = None
 
     def start_monitor_threads(self) -> None:
         """
@@ -62,6 +54,8 @@ class EmulationDefenderMachineObservationState:
 
         :return: None
         """
+        if self.kafka_config is None:
+            raise ValueError("Cannot start monitoring threads since the kafka config is None.")
         self.host_metrics_consumer_thread = HostMetricsConsumerThread(
             host_ip=self.ips[0], kafka_server_ip=self.kafka_config.container.docker_gw_bridge_ip,
             kafka_port=self.kafka_config.kafka_port_external, host_metrics=self.host_metrics)
@@ -89,7 +83,9 @@ class EmulationDefenderMachineObservationState:
         :return: the created instance
         """
         obj = EmulationDefenderMachineObservationState(ips=container.get_ips(), kafka_config=kafka_config,
-                                                       host_metrics=None, docker_stats=None)
+                                                       host_metrics=HostMetrics(), docker_stats=DockerStats(),
+                                                       ossec_ids_alert_counters=OSSECIdsAlertCounters(),
+                                                       snort_ids_ip_alert_counters=SnortIdsIPAlertCounters())
         obj.os = container.os
         return obj
 
@@ -126,21 +122,22 @@ class EmulationDefenderMachineObservationState:
 
     def to_dict(self) -> Dict[str, Any]:
         """
+        Converts the object to a dict representation
+        
         :return: a dict representation of the object
         """
-        d = {}
+        d: Dict[str, Any] = {}
         d["ips"] = self.ips
         d["os"] = self.os
         d["ports"] = list(map(lambda x: x.to_dict(), self.ports))
         d["ssh_connections"] = list(map(lambda x: x.to_dict(), self.ssh_connections))
-        d["host_metrics"] = self.host_metrics.to_dict()
-        d["docker_stats"] = self.docker_stats.to_dict()
-        d["ossec_ids_alert_counters"] = self.ossec_ids_alert_counters.to_dict()
-        d["snort_ids_ip_alert_counters"] = self.snort_ids_ip_alert_counters.to_dict()
-        if self.kafka_config is not None:
-            d["kafka_config"] = self.kafka_config.to_dict()
-        else:
-            d["kafka_config"] = None
+        d["host_metrics"] = self.host_metrics.to_dict() if self.host_metrics is not None else None
+        d["docker_stats"] = self.docker_stats.to_dict() if self.docker_stats is not None else None
+        d["ossec_ids_alert_counters"] = self.ossec_ids_alert_counters.to_dict() \
+            if self.ossec_ids_alert_counters is not None else None
+        d["snort_ids_ip_alert_counters"] = self.snort_ids_ip_alert_counters.to_dict() \
+            if self.snort_ids_ip_alert_counters is not None else None
+        d["kafka_config"] = self.kafka_config.to_dict() if self.kafka_config is not None else None
         return d
 
     def __str__(self) -> str:
@@ -180,7 +177,7 @@ class EmulationDefenderMachineObservationState:
             self.snort_ids_log_consumer_thread.running = False
             self.snort_ids_log_consumer_thread.consumer.close()
         if self.ossec_ids_log_consumer_thread is not None:
-            self.ossec_ids_alert_counters.running = False
+            self.ossec_ids_log_consumer_thread.running = False
             self.ossec_ids_log_consumer_thread.consumer.close()
         for c in self.ssh_connections:
             c.cleanup()
@@ -190,39 +187,30 @@ class EmulationDefenderMachineObservationState:
         :return: a copy of the object
         """
         m_copy = EmulationDefenderMachineObservationState(
-            ips=self.ips, kafka_config=self.kafka_config, host_metrics=self.host_metrics.copy(),
-            docker_stats=self.docker_stats.copy())
+            ips=self.ips, kafka_config=self.kafka_config,
+            host_metrics=self.host_metrics.copy(),
+            docker_stats=self.docker_stats.copy(),
+            ossec_ids_alert_counters=self.ossec_ids_alert_counters.copy(),
+            snort_ids_ip_alert_counters=self.snort_ids_ip_alert_counters.copy())
         m_copy.os = self.os
-        m_copy.ports = list(map(lambda x: x.copy(), self.ports))
-        m_copy.ssh_connections = self.ssh_connections
-        m_copy.host_metrics = self.host_metrics.copy()
-        m_copy.docker_stats = self.docker_stats.copy()
-        m_copy.snort_ids_ip_alert_counters = self.snort_ids_ip_alert_counters.copy()
-        m_copy.ossec_ids_alert_counters = self.ossec_ids_alert_counters.copy()
+        if self.ports == []:
+            m_copy.ports = self.ports
+        else:
+            m_copy.ports = list(map(lambda x: x.copy(), self.ports))
+        if self.ssh_connections == []:
+            m_copy.ssh_connections = self.ssh_connections
+        else:
+            m_copy.ssh_connections = list(map(lambda x: x.copy(), self.ssh_connections))
+        if self.snort_ids_ip_alert_counters is None:
+            m_copy.snort_ids_ip_alert_counters = self.snort_ids_ip_alert_counters
+        else:
+            m_copy.snort_ids_ip_alert_counters = self.snort_ids_ip_alert_counters.copy()
+        if self.ossec_ids_alert_counters is None:
+            m_copy.ossec_ids_alert_counters = self.ossec_ids_alert_counters
+        else:
+            m_copy.ossec_ids_alert_counters = self.ossec_ids_alert_counters.copy()
         return m_copy
 
-    def to_json_str(self) -> str:
-        """
-        Converts the DTO into a json string
-
-        :return: the json string representation of the DTO
-        """
-        import json
-        json_str = json.dumps(self.to_dict(), indent=4, sort_keys=True)
-        return json_str
-
-    def to_json_file(self, json_file_path: str) -> None:
-        """
-        Saves the DTO to a json file
-
-        :param json_file_path: the json file path to save  the DTO to
-        :return: None
-        """
-        import io
-        json_str = self.to_json_str()
-        with io.open(json_file_path, 'w', encoding='utf-8') as f:
-            f.write(json_str)
-
     @staticmethod
     def from_json_file(json_file_path: str) -> "EmulationDefenderMachineObservationState":
         """
