@@ -1,4 +1,4 @@
-from typing import List, Dict, Any, Union
+from typing import Optional, List, Dict, Any, Union, Set, Tuple
 from csle_common.dao.emulation_config.emulation_env_config import EmulationEnvConfig
 from csle_common.dao.emulation_observation.defender.emulation_defender_machine_observation_state \
     import EmulationDefenderMachineObservationState
@@ -15,27 +15,24 @@ from csle_common.consumer_threads.attacker_actions_consumer_thread import Attack
 from csle_common.consumer_threads.defender_actions_consumer_thread import DefenderActionsConsumerThread
 from csle_common.consumer_threads.aggregated_host_metrics_thread import AggregatedHostMetricsThread
 from csle_collector.client_manager.client_population_metrics import ClientPopulationMetrics
-from csle_collector.docker_stats_manager.docker_stats import DockerStats
-from csle_collector.snort_ids_manager.snort_ids_alert_counters import SnortIdsAlertCounters
-from csle_collector.snort_ids_manager.snort_ids_rule_counters import SnortIdsRuleCounters
-from csle_collector.ossec_ids_manager.ossec_ids_alert_counters import OSSECIdsAlertCounters
-from csle_collector.host_manager.host_metrics import HostMetrics
+from csle_collector.docker_stats_manager.dao.docker_stats import DockerStats
+from csle_collector.snort_ids_manager.dao.snort_ids_alert_counters import SnortIdsAlertCounters
+from csle_collector.snort_ids_manager.dao.snort_ids_rule_counters import SnortIdsRuleCounters
+from csle_collector.ossec_ids_manager.dao.ossec_ids_alert_counters import OSSECIdsAlertCounters
+from csle_collector.host_manager.dao.host_metrics import HostMetrics
+from csle_base.json_serializable import JSONSerializable
 
 
-class EmulationDefenderObservationState:
+class EmulationDefenderObservationState(JSONSerializable):
     """
     Represents the defender's agent's current belief state of the emulation
     """
 
-    def __init__(self, kafka_config: Union[KafkaConfig, None],
-                 client_population_metrics: ClientPopulationMetrics = None, docker_stats: DockerStats = None,
-                 snort_ids_alert_counters: SnortIdsAlertCounters = None,
-                 ossec_ids_alert_counters: OSSECIdsAlertCounters = None,
-                 aggregated_host_metrics: HostMetrics = None,
-                 defender_actions: List[EmulationDefenderAction] = None,
-                 attacker_actions: List[EmulationAttackerAction] = None,
-                 snort_ids_rule_counters: SnortIdsRuleCounters = None
-                 ):
+    def __init__(self, kafka_config: Union[KafkaConfig, None], client_population_metrics: ClientPopulationMetrics,
+                 docker_stats: DockerStats, snort_ids_alert_counters: SnortIdsAlertCounters,
+                 ossec_ids_alert_counters: OSSECIdsAlertCounters, aggregated_host_metrics: HostMetrics,
+                 defender_actions: List[EmulationDefenderAction], attacker_actions: List[EmulationAttackerAction],
+                 snort_ids_rule_counters: SnortIdsRuleCounters):
         """
         Initializes the DTO
 
@@ -51,45 +48,29 @@ class EmulationDefenderObservationState:
         """
         self.kafka_config = kafka_config
         self.machines: List[EmulationDefenderMachineObservationState] = []
-        self.actions_tried = set()
+        self.actions_tried: Set[Tuple[int, int, str]] = set()
         self.client_population_metrics = client_population_metrics
-        if self.client_population_metrics is None:
-            self.client_population_metrics = ClientPopulationMetrics()
         self.avg_client_population_metrics = self.client_population_metrics.copy()
         self.docker_stats = docker_stats
-        if self.docker_stats is None:
-            self.docker_stats = DockerStats()
         self.avg_docker_stats = self.docker_stats.copy()
         self.snort_ids_alert_counters = snort_ids_alert_counters
-        if self.snort_ids_alert_counters is None:
-            self.snort_ids_alert_counters = SnortIdsAlertCounters()
         self.avg_snort_ids_alert_counters = self.snort_ids_alert_counters.copy()
         self.snort_ids_rule_counters = snort_ids_rule_counters
-        if self.snort_ids_rule_counters is None:
-            self.snort_ids_rule_counters = SnortIdsRuleCounters()
         self.avg_snort_ids_rule_counters = self.snort_ids_rule_counters.copy()
         self.ossec_ids_alert_counters = ossec_ids_alert_counters
-        if self.ossec_ids_alert_counters is None:
-            self.ossec_ids_alert_counters = OSSECIdsAlertCounters()
         self.avg_ossec_ids_alert_counters = self.ossec_ids_alert_counters.copy()
         self.attacker_actions = attacker_actions
-        if self.attacker_actions is None:
-            self.attacker_actions = []
         self.defender_actions = defender_actions
-        if self.defender_actions is None:
-            self.defender_actions = []
         self.aggregated_host_metrics = aggregated_host_metrics
-        if aggregated_host_metrics is None:
-            self.aggregated_host_metrics = HostMetrics()
-        self.avg_aggregated_host_metrics = self.aggregated_host_metrics.copy()
-        self.docker_stats_consumer_thread = None
-        self.client_population_consumer_thread = None
-        self.aggregated_snort_ids_log_consumer_thread = None
-        self.aggregated_snort_ids_rule_log_consumer_thread = None
-        self.aggregated_ossec_ids_log_consumer_thread = None
-        self.attacker_actions_consumer_thread = None
-        self.defender_actions_consumer_thread = None
-        self.aggregated_host_metrics_thread = None
+        self.avg_aggregated_host_metrics: HostMetrics = self.aggregated_host_metrics.copy()
+        self.docker_stats_consumer_thread: Optional[DockerStatsConsumerThread] = None
+        self.client_population_consumer_thread: Optional[ClientPopulationConsumerThread] = None
+        self.aggregated_snort_ids_log_consumer_thread: Optional[AggregatedSnortIdsLogConsumerThread] = None
+        self.aggregated_snort_ids_rule_log_consumer_thread: Optional[AggregatedSnortIdsRuleLogConsumerThread] = None
+        self.aggregated_ossec_ids_log_consumer_thread: Optional[AggregatedOSSECIdsLogConsumerThread] = None
+        self.attacker_actions_consumer_thread: Optional[AttackerActionsConsumerThread] = None
+        self.defender_actions_consumer_thread: Optional[DefenderActionsConsumerThread] = None
+        self.aggregated_host_metrics_thread: Optional[AggregatedHostMetricsThread] = None
 
     def start_monitoring_threads(self) -> None:
         """
@@ -97,6 +78,12 @@ class EmulationDefenderObservationState:
 
         :return: None
         """
+        if self.kafka_config is None:
+            raise ValueError("KafkaConfig is None")
+        if self.attacker_actions is None:
+            raise ValueError("EmulationAttackerAction is None")
+        if self.defender_actions is None:
+            raise ValueError("EmulationDefenderAction is None")
         self.aggregated_host_metrics_thread = AggregatedHostMetricsThread(
             host_metrics=self.aggregated_host_metrics,
             sleep_time=self.kafka_config.time_step_len_seconds,
@@ -155,35 +142,52 @@ class EmulationDefenderObservationState:
         :param d: the dict to convert
         :return: the created instance
         """
+        kafka_config: Union[None, KafkaConfig] = None
         try:
-            obj = EmulationDefenderObservationState(kafka_config=KafkaConfig.from_dict(d["kafka_config"]))
+            kafka_config = KafkaConfig.from_dict(d["kafka_config"])
         except Exception:
-            obj = EmulationDefenderObservationState(kafka_config=None)
+            pass
+        if "snort_ids_rule_counters" not in d:
+            snort_ids_rule_counters = SnortIdsRuleCounters()
+        else:
+            snort_ids_rule_counters = SnortIdsRuleCounters.from_dict(d["snort_ids_rule_counters"])
+        if "avg_snort_ids_rule_counters" not in d:
+            avg_snort_ids_rule_counters = SnortIdsRuleCounters()
+        else:
+            avg_snort_ids_rule_counters = SnortIdsRuleCounters.from_dict(d["avg_snort_ids_rule_counters"])
+        obj = EmulationDefenderObservationState(
+            kafka_config=kafka_config,
+            client_population_metrics=ClientPopulationMetrics.from_dict(d["client_population_metrics"]),
+            docker_stats=DockerStats.from_dict(d["docker_stats"]),
+            ossec_ids_alert_counters=OSSECIdsAlertCounters.from_dict(d["ossec_ids_alert_counters"]),
+            aggregated_host_metrics=HostMetrics.from_dict(d["aggregated_host_metrics"]),
+            defender_actions=list(map(lambda x: EmulationDefenderAction.from_dict(x), d["defender_actions"])),
+            attacker_actions=list(map(lambda x: EmulationAttackerAction.from_dict(x), d["attacker_actions"])),
+            snort_ids_rule_counters=snort_ids_rule_counters,
+            snort_ids_alert_counters=SnortIdsAlertCounters.from_dict(d["snort_ids_alert_counters"]))
         obj.machines = list(map(lambda x: EmulationDefenderMachineObservationState.from_dict(d=x), d["machines"]))
-        obj.actions_tried = set(list(map(lambda x: tuple(x), d["actions_tried"])))
-        obj.client_population_metrics = ClientPopulationMetrics.from_dict(d["client_population_metrics"])
-        obj.docker_stats = DockerStats.from_dict(d["docker_stats"])
-        obj.snort_ids_alert_counters = SnortIdsAlertCounters.from_dict(d["snort_ids_alert_counters"])
-        obj.snort_ids_rule_counters = SnortIdsRuleCounters.from_dict(d["snort_ids_rule_counters"])
-        obj.ossec_ids_alert_counters = OSSECIdsAlertCounters.from_dict(d["ossec_ids_alert_counters"])
-        obj.aggregated_host_metrics = HostMetrics.from_dict(d["aggregated_host_metrics"])
-        obj.attacker_actions = list(map(lambda x: EmulationAttackerAction.from_dict(x), d["attacker_actions"]))
-        obj.defender_actions = list(map(lambda x: EmulationDefenderAction.from_dict(x), d["defender_actions"]))
+        obj.actions_tried = set(list(map(lambda x: (int(x[0]), int(x[1]), str(x[2])), d["actions_tried"])))
         obj.avg_aggregated_host_metrics = HostMetrics.from_dict(d["avg_aggregated_host_metrics"])
         obj.avg_docker_stats = DockerStats.from_dict(d["avg_docker_stats"])
         obj.avg_client_population_metrics = ClientPopulationMetrics.from_dict(d["avg_client_population_metrics"])
         obj.avg_snort_ids_alert_counters = SnortIdsAlertCounters.from_dict(d["avg_snort_ids_alert_counters"])
-        obj.avg_snort_ids_rule_counters = SnortIdsRuleCounters.from_dict(d["avg_snort_ids_rule_counters"])
+        obj.avg_snort_ids_rule_counters = avg_snort_ids_rule_counters
         obj.avg_ossec_ids_alert_counters = OSSECIdsAlertCounters.from_dict(d["avg_ossec_ids_alert_counters"])
         return obj
 
     def to_dict(self) -> Dict[str, Any]:
         """
+        Converts the object to a dict representation
+
         :return: a dict representation of the object
         """
-        d = {}
+        d: Dict[str, Any] = {}
         d["machines"] = list(map(lambda x: x.to_dict(), self.machines))
         d["actions_tried"] = list(self.actions_tried)
+        if self.client_population_metrics is None or self.docker_stats is None \
+                or self.snort_ids_alert_counters is None or self.snort_ids_rule_counters is None or \
+                self.ossec_ids_alert_counters is None:
+            raise ValueError("ClientPopulationMetrics is None")
         d["client_population_metrics"] = self.client_population_metrics.to_dict()
         d["docker_stats"] = self.docker_stats.to_dict()
         d["snort_ids_alert_counters"] = self.snort_ids_alert_counters.to_dict()
@@ -193,6 +197,12 @@ class EmulationDefenderObservationState:
             d["kafka_config"] = self.kafka_config.to_dict()
         else:
             d["kafka_config"] = None
+        if self.attacker_actions is None:
+            raise ValueError("attacker_actions is None and thus has no to_dict attribute")
+        if self.defender_actions is None:
+            raise ValueError("attacker_actions is None and thus has no to_dict attribute")
+        if self.aggregated_host_metrics is None or self.avg_aggregated_host_metrics is None:
+            raise ValueError("aggregated_host_metrics is None and thus has no to_dict attribute")
         d["attacker_actions"] = list(map(lambda x: x.to_dict(), self.attacker_actions))
         d["defender_actions"] = list(map(lambda x: x.to_dict(), self.defender_actions))
         d["aggregated_host_metrics"] = self.aggregated_host_metrics.to_dict()
@@ -250,6 +260,14 @@ class EmulationDefenderObservationState:
 
         :return: None
         """
+        if self.aggregated_snort_ids_log_consumer_thread is None or \
+                self.aggregated_snort_ids_rule_log_consumer_thread is None or \
+                self.aggregated_ossec_ids_log_consumer_thread is None or \
+                self.docker_stats_consumer_thread is None or \
+                self.client_population_consumer_thread is None or \
+                self.aggregated_host_metrics_thread is None:
+            raise ValueError("At least one of the objects is None")
+
         self.aggregated_snort_ids_log_consumer_thread.snort_ids_alert_counters_list = []
         self.aggregated_snort_ids_rule_log_consumer_thread.snort_ids_rule_counters_list = []
         self.aggregated_ossec_ids_log_consumer_thread.ossec_ids_alert_counters_list = []
@@ -261,6 +279,13 @@ class EmulationDefenderObservationState:
         """
         :return: computes the averages of the metric lists
         """
+        if self.aggregated_snort_ids_log_consumer_thread is None or \
+                self.aggregated_snort_ids_rule_log_consumer_thread is None or \
+                self.aggregated_ossec_ids_log_consumer_thread is None or \
+                self.docker_stats_consumer_thread is None or \
+                self.client_population_consumer_thread is None or \
+                self.aggregated_host_metrics_thread is None:
+            raise ValueError("At least one of the objects is None")
         self.avg_snort_ids_alert_counters = \
             self.aggregated_snort_ids_log_consumer_thread.get_aggregated_ids_alert_counters()
         self.avg_snort_ids_rule_counters = \
@@ -290,6 +315,13 @@ class EmulationDefenderObservationState:
         """
         :return: a copy of the object
         """
+        if self.client_population_metrics is None or self.docker_stats is None or \
+                self.snort_ids_alert_counters is None or self.ossec_ids_alert_counters is None or \
+                self.attacker_actions is None or self.defender_actions is None or \
+                self.aggregated_host_metrics is None or \
+                self.snort_ids_rule_counters is None or \
+                self.avg_aggregated_host_metrics is None:
+            raise ValueError("At least of the objects is None")
         c = EmulationDefenderObservationState(
             kafka_config=self.kafka_config,
             client_population_metrics=self.client_population_metrics.copy(), docker_stats=self.docker_stats.copy(),
@@ -315,6 +347,10 @@ class EmulationDefenderObservationState:
         """
         :return: a string representation of the object
         """
+        if self.attacker_actions is None:
+            raise ValueError("attacker_Actions is not iterable")
+        if self.defender_actions is None:
+            raise ValueError("defender_actions is not iterable")
         return f"client_population_metrics: {self.client_population_metrics}," \
                f"docker_stats: {self.docker_stats}," \
                f"snort_ids_alert_counters: {self.snort_ids_alert_counters}," \
@@ -329,29 +365,7 @@ class EmulationDefenderObservationState:
                f"avg_docker_stats: {self.avg_docker_stats}," \
                f"avg_aggregated_host_metrics: {self.avg_aggregated_host_metrics}," \
                f"avg_client_population_metrics: {self.avg_client_population_metrics}" \
-               + "\n".join([str(i) + ":" + str(self.machines[i]) for i in range(len(self.machines))])
-
-    def to_json_str(self) -> str:
-        """
-        Converts the DTO into a json string
-
-        :return: the json string representation of the DTO
-        """
-        import json
-        json_str = json.dumps(self.to_dict(), indent=4, sort_keys=True)
-        return json_str
-
-    def to_json_file(self, json_file_path: str) -> None:
-        """
-        Saves the DTO to a json file
-
-        :param json_file_path: the json file path to save  the DTO to
-        :return: None
-        """
-        import io
-        json_str = self.to_json_str()
-        with io.open(json_file_path, 'w', encoding='utf-8') as f:
-            f.write(json_str)
+            + "\n".join([str(i) + ":" + str(self.machines[i]) for i in range(len(self.machines))])
 
     @staticmethod
     def from_json_file(json_file_path: str) -> "EmulationDefenderObservationState":
@@ -371,6 +385,10 @@ class EmulationDefenderObservationState:
         """
         :return: The number of attribute of the DTO
         """
+        if self.defender_actions is None:
+            raise ValueError("defender_action is None and thus has no size")
+        if self.attacker_actions is None:
+            raise ValueError("attacker_action is None and thus has no size")
         num_attributes = 0
         if self.client_population_metrics is not None:
             num_attributes = num_attributes + self.client_population_metrics.num_attributes()
