@@ -1,19 +1,22 @@
-from typing import Dict, Any
+from typing import Optional, Dict, Any, Union
 from csle_common.dao.system_identification.system_model import SystemModel
-from csle_common.dao.system_identification.gaussian_mixture_system_model import GaussianMixtureSystemModel
 from csle_common.dao.system_identification.system_identification_config import SystemIdentificationConfig
+from csle_common.dao.system_identification.gaussian_mixture_system_model import GaussianMixtureSystemModel
+from csle_common.dao.system_identification.empirical_system_model import EmpiricalSystemModel
+from csle_common.dao.system_identification.gp_system_model import GPSystemModel
+from csle_common.dao.system_identification.mcmc_system_model import MCMCSystemModel
+from csle_base.json_serializable import JSONSerializable
 
 
-class SystemIdentificationJobConfig:
+class SystemIdentificationJobConfig(JSONSerializable):
     """
     DTO representing a system identification job
     """
 
     def __init__(self, emulation_env_name: str, emulation_statistics_id: int,
                  progress_percentage: float, pid: int, log_file_path: str,
-                 system_identification_config: SystemIdentificationConfig,
-                 descr: str = "",
-                 system_model: SystemModel = None):
+                 system_identification_config: SystemIdentificationConfig, physical_host_ip: str,
+                 descr: str = "", system_model: Optional[SystemModel] = None):
         """
         Initializes the DTO
 
@@ -25,6 +28,7 @@ class SystemIdentificationJobConfig:
         :param descr: a description of the job
         :param system_model: fitted system model
         :param system_identification_config: the config of the system identification algorithm
+        :param physical_host_ip: the IP of the physical host where the job is running
         """
         self.emulation_env_name = emulation_env_name
         self.emulation_statistics_id = emulation_statistics_id
@@ -36,12 +40,15 @@ class SystemIdentificationJobConfig:
         self.system_identification_config = system_identification_config
         self.id = -1
         self.running = False
+        self.physical_host_ip = physical_host_ip
 
     def to_dict(self) -> Dict[str, Any]:
         """
+        Converts the object to a dict representation
+
         :return: a dict representation of the object
         """
-        d = {}
+        d: Dict[str, Any] = {}
         d["emulation_env_name"] = self.emulation_env_name
         d["pid"] = self.pid
         d["progress_percentage"] = self.progress_percentage
@@ -55,6 +62,7 @@ class SystemIdentificationJobConfig:
         d["system_identification_config"] = self.system_identification_config.to_dict()
         d["id"] = self.id
         d["running"] = self.running
+        d["physical_host_ip"] = self.physical_host_ip
         return d
 
     @staticmethod
@@ -65,13 +73,22 @@ class SystemIdentificationJobConfig:
         :param d: the dict to convert
         :return: the created instance
         """
-        system_model = None
-        system_model = GaussianMixtureSystemModel.from_dict(d["system_model"])
+        # system_model = None
+        parse_models = [GaussianMixtureSystemModel.from_dict, EmpiricalSystemModel.from_dict,
+                        GPSystemModel.from_dict, MCMCSystemModel.from_dict]
+        system_model: Union[None, SystemModel] = None
+        for parse_model in parse_models:
+            try:
+                system_model = parse_model(d['system_model'])
+                break
+            except Exception:
+                pass
         obj = SystemIdentificationJobConfig(
             emulation_env_name=d["emulation_env_name"], pid=d["pid"],
             progress_percentage=d["progress_percentage"], emulation_statistics_id=d["emulation_statistics_id"],
             descr=d["descr"], log_file_path=d["log_file_path"], system_model=system_model,
-            system_identification_config=SystemIdentificationConfig.from_dict(d["system_identification_config"])
+            system_identification_config=SystemIdentificationConfig.from_dict(d["system_identification_config"]),
+            physical_host_ip=d["physical_host_ip"]
         )
         if "id" in d:
             obj.id = d["id"]
@@ -79,28 +96,6 @@ class SystemIdentificationJobConfig:
             obj.running = d["running"]
         return obj
 
-    def to_json_str(self) -> str:
-        """
-        Converts the DTO into a json string
-
-        :return: the json string representation of the DTO
-        """
-        import json
-        json_str = json.dumps(self.to_dict(), indent=4, sort_keys=True)
-        return json_str
-
-    def to_json_file(self, json_file_path: str) -> None:
-        """
-        Saves the DTO to a json file
-
-        :param json_file_path: the json file path to save  the DTO to
-        :return: None
-        """
-        import io
-        json_str = self.to_json_str()
-        with io.open(json_file_path, 'w', encoding='utf-8') as f:
-            f.write(json_str)
-
     @staticmethod
     def from_json_file(json_file_path: str) -> "SystemIdentificationJobConfig":
         """
