@@ -1,7 +1,8 @@
 from typing import Dict, Any
+from csle_base.json_serializable import JSONSerializable
 
 
-class PlayerConfig:
+class PlayerConfig(JSONSerializable):
     """
     DTO representing the configuration of a player in a simulation environment in CSLE
     """
@@ -31,9 +32,11 @@ class PlayerConfig:
 
     def to_dict(self) -> Dict[str, Any]:
         """
+        Converts the object to a dict representation
+        
         :return: a dict representation of the object
         """
-        d = {}
+        d: Dict[str, Any] = {}
         d["name"] = self.name
         d["id"] = self.id
         d["descr"] = self.descr
@@ -44,3 +47,17 @@ class PlayerConfig:
         :return: a string representation of the object
         """
         return f"name: {self.name}, id: {self.id}, descr: {self.descr}"
+
+    @staticmethod
+    def from_json_file(json_file_path: str) -> "PlayerConfig":
+        """
+        Reads a json file and converts it to a DTO
+
+        :param json_file_path: the json file path
+        :return: the converted DTO
+        """
+        import io
+        import json
+        with io.open(json_file_path, 'r') as f:
+            json_str = f.read()
+        return PlayerConfig.from_dict(json.loads(json_str))
