@@ -10,20 +10,10 @@ from csle_common.dao.simulation_config.transition_operator_config import Transit
 from csle_common.dao.simulation_config.observation_function_config import ObservationFunctionConfig
 from csle_common.dao.simulation_config.initial_state_distribution_config import InitialStateDistributionConfig
 from csle_common.dao.simulation_config.env_parameters_config import EnvParametersConfig
-from gym_csle_stopping_game.dao.stopping_game_config import StoppingGameConfig
-from gym_csle_stopping_game.dao.stopping_game_defender_pomdp_config import StoppingGameDefenderPomdpConfig
-from gym_csle_stopping_game.dao.stopping_game_attacker_mdp_config import StoppingGameAttackerMdpConfig
-from gym_csle_intrusion_response_game.dao.intrusion_response_game_local_pomdp_defender_config \
-    import IntrusionResponseGameLocalPOMDPDefenderConfig
-from gym_csle_intrusion_response_game.dao.intrusion_response_game_local_pomdp_attacker_config \
-    import IntrusionResponseGameLocalPOMDPAttackerConfig
-from gym_csle_intrusion_response_game.dao.workflow_intrusion_response_pomdp_defender_config \
-    import WorkflowIntrusionResponsePOMDPDefenderConfig
-from gym_csle_intrusion_response_game.dao.workflow_intrusion_response_pomdp_attacker_config \
-    import WorkflowIntrusionResponsePOMDPAttackerConfig
+from csle_base.json_serializable import JSONSerializable
 
 
-class SimulationEnvConfig:
+class SimulationEnvConfig(JSONSerializable):
     """
     A DTO class representing the configuration of a simulation environment
     """
@@ -38,8 +28,7 @@ class SimulationEnvConfig:
                  observation_function_config: ObservationFunctionConfig,
                  initial_state_distribution_config: InitialStateDistributionConfig,
                  env_parameters_config: EnvParametersConfig, plot_transition_probabilities: bool = False,
-                 plot_observation_function: bool = False, plot_reward_function: bool = False
-                 ):
+                 plot_observation_function: bool = False, plot_reward_function: bool = False) -> None:
         """
         Initializes the DTO
 
@@ -92,13 +81,34 @@ class SimulationEnvConfig:
         :param d: the dict to convert
         :return: the created instance
         """
+        from gym_csle_stopping_game.dao.stopping_game_config import StoppingGameConfig
+        from gym_csle_stopping_game.dao.stopping_game_defender_pomdp_config import StoppingGameDefenderPomdpConfig
+        from gym_csle_stopping_game.dao.stopping_game_attacker_mdp_config import StoppingGameAttackerMdpConfig
+        from gym_csle_apt_game.dao.apt_game_config import AptGameConfig
+        from gym_csle_apt_game.dao.apt_game_defender_pomdp_config import AptGameDefenderPomdpConfig
+        from gym_csle_apt_game.dao.apt_game_attacker_mdp_config import AptGameAttackerMdpConfig
+        from gym_csle_intrusion_response_game.dao.intrusion_response_game_local_pomdp_defender_config \
+            import IntrusionResponseGameLocalPOMDPDefenderConfig
+        from gym_csle_intrusion_response_game.dao.intrusion_response_game_local_pomdp_attacker_config \
+            import IntrusionResponseGameLocalPOMDPAttackerConfig
+        from gym_csle_intrusion_response_game.dao.workflow_intrusion_response_pomdp_defender_config \
+            import WorkflowIntrusionResponsePOMDPDefenderConfig
+        from gym_csle_intrusion_response_game.dao.workflow_intrusion_response_pomdp_attacker_config \
+            import WorkflowIntrusionResponsePOMDPAttackerConfig
+        from csle_tolerance.dao.intrusion_recovery_pomdp_config import IntrusionRecoveryPomdpConfig
+        from csle_tolerance.dao.intrusion_response_cmdp_config import IntrusionResponseCmdpConfig
+        from gym_csle_cyborg.dao.csle_cyborg_config import CSLECyborgConfig
         input_config = None
         parse_functions = [StoppingGameConfig.from_dict, StoppingGameAttackerMdpConfig.from_dict,
                            StoppingGameDefenderPomdpConfig.from_dict,
+                           AptGameConfig.from_dict, AptGameAttackerMdpConfig.from_dict,
+                           AptGameDefenderPomdpConfig.from_dict,
                            IntrusionResponseGameLocalPOMDPDefenderConfig.from_dict,
                            IntrusionResponseGameLocalPOMDPAttackerConfig.from_dict,
                            WorkflowIntrusionResponsePOMDPDefenderConfig.from_dict,
-                           WorkflowIntrusionResponsePOMDPAttackerConfig.from_dict]
+                           WorkflowIntrusionResponsePOMDPAttackerConfig.from_dict,
+                           IntrusionRecoveryPomdpConfig.from_dict,
+                           IntrusionResponseCmdpConfig.from_dict, CSLECyborgConfig.from_dict]
         for parse_fun in parse_functions:
             try:
                 input_config = parse_fun(d["simulation_env_input_config"])
@@ -106,7 +116,7 @@ class SimulationEnvConfig:
             except Exception:
                 pass
         if input_config is None:
-            raise ValueError("Could not parse the input configuration")
+            raise ValueError(f"Could not parse the input configuration: \n{d['simulation_env_input_config']}")
         obj = SimulationEnvConfig(
             name=d["name"], descr=d["descr"],
             simulation_env_input_config=input_config,
@@ -114,7 +124,7 @@ class SimulationEnvConfig:
             state_space_config=StateSpaceConfig.from_dict(d["state_space_config"]),
             joint_action_space_config=JointActionSpaceConfig.from_dict(d["joint_action_space_config"]),
             joint_observation_space_config=JointObservationSpaceConfig.from_dict(d["joint_observation_space_config"]),
-            time_step_type=d["time_step_type"],
+            time_step_type=TimeStepType(d["time_step_type"]),
             reward_function_config=RewardFunctionConfig.from_dict(d["reward_function_config"]),
             transition_operator_config=TransitionOperatorConfig.from_dict(d["transition_operator_config"]),
             observation_function_config=ObservationFunctionConfig.from_dict(d["observation_function_config"]),
@@ -132,9 +142,11 @@ class SimulationEnvConfig:
 
     def to_dict(self) -> Dict[str, Any]:
         """
+        Converts the object to a dict representation
+
         :return: a dict representation of the object
         """
-        d = {}
+        d: Dict[str, Any] = {}
         d["name"] = self.name
         d["descr"] = self.descr
         d["simulation_env_input_config"] = self.simulation_env_input_config.to_dict()
@@ -142,7 +154,7 @@ class SimulationEnvConfig:
         d["state_space_config"] = self.state_space_config.to_dict()
         d["joint_action_space_config"] = self.joint_action_space_config.to_dict()
         d["joint_observation_space_config"] = self.joint_observation_space_config.to_dict()
-        d["time_step_type"] = self.time_step_type
+        d["time_step_type"] = self.time_step_type.value
         d["reward_function_config"] = self.reward_function_config.to_dict()
         d["transition_operator_config"] = self.transition_operator_config.to_dict()
         d["observation_function_config"] = self.observation_function_config.to_dict()
@@ -181,3 +193,17 @@ class SimulationEnvConfig:
         :return: a copy of the DTO
         """
         return self.from_dict(self.to_dict())
+
+    @staticmethod
+    def from_json_file(json_file_path: str) -> "SimulationEnvConfig":
+        """
+        Reads a json file and converts it to a DTO
+
+        :param json_file_path: the json file path
+        :return: the converted DTO
+        """
+        import io
+        import json
+        with io.open(json_file_path, 'r') as f:
+            json_str = f.read()
+        return SimulationEnvConfig.from_dict(json.loads(json_str))
