@@ -30,3 +30,15 @@ class AgentType(IntEnum):
     DYNA_SEC = 22
     BAYESIAN_OPTIMIZATION = 23
     DFSP_LOCAL = 24
+    LINEAR_PROGRAMMING_CMDP = 25
+    BAYESIAN_OPTIMIZATION_EMUKIT = 26
+    SIMULATED_ANNEALING = 27
+    CMA_ES = 28
+    NELDER_MEAD = 29
+    PARTICLE_SWARM = 30
+    PPO_CLEAN = 31
+    POMCP = 32
+    DQN_CLEAN = 33
+    C51_CLEAN = 34
+    PPG_CLEAN = 35
+    MCS = 36
