@@ -1,10 +1,11 @@
-from typing import List, Dict, Any, Optional
+from typing import List, Dict, Any
 from csle_common.dao.training.agent_type import AgentType
 from csle_common.dao.training.player_type import PlayerType
 from csle_common.dao.training.hparam import HParam
+from csle_base.json_serializable import JSONSerializable
 
 
-class ExperimentConfig:
+class ExperimentConfig(JSONSerializable):
     """
     DTO representing the configuration of an experiment
     """
@@ -36,15 +37,14 @@ class ExperimentConfig:
         self.br_log_every = br_log_every
 
     @staticmethod
-    def from_dict(d: Dict[str, Any]) -> "Optional[ExperimentConfig]":
+    def from_dict(d: Dict[str, Any]) -> "ExperimentConfig":
         """
         Converts a dict representation to an instance
 
         :param d: the dict to convert
         :return: the created instance
         """
-        if d is None:
-            return None
+
         h_d = {}
         for k, v in d["hparams"].items():
             h_d[k] = HParam.from_dict(v)
@@ -57,9 +57,11 @@ class ExperimentConfig:
 
     def to_dict(self) -> Dict[str, Any]:
         """
+        Converts the object to a dict representation
+        
         :return: a dict representation of the object
         """
-        d = {}
+        d: Dict[str, Any] = {}
         d["output_dir"] = self.output_dir
         d["title"] = self.title
         d["random_seeds"] = self.random_seeds
@@ -82,28 +84,6 @@ class ExperimentConfig:
                f"agent_type: {self.agent_type}, hparams: {self.hparams}, log_every: {self.log_every}, " \
                f"player_type: {self.player_type}, player_idx: {self.player_idx}, br_log_every: {self.br_log_every}"
 
-    def to_json_str(self) -> str:
-        """
-        Converts the DTO into a json string
-
-        :return: the json string representation of the DTO
-        """
-        import json
-        json_str = json.dumps(self.to_dict(), indent=4, sort_keys=True)
-        return json_str
-
-    def to_json_file(self, json_file_path: str) -> None:
-        """
-        Saves the DTO to a json file
-
-        :param json_file_path: the json file path to save  the DTO to
-        :return: None
-        """
-        import io
-        json_str = self.to_json_str()
-        with io.open(json_file_path, 'w', encoding='utf-8') as f:
-            f.write(json_str)
-
     @staticmethod
     def from_json_file(json_file_path: str) -> "ExperimentConfig":
         """
