@@ -2,9 +2,10 @@ from typing import Any, Dict
 from csle_common.dao.training.policy import Policy
 from csle_common.dao.training.multi_threshold_stopping_policy import MultiThresholdStoppingPolicy
 from csle_common.dao.training.ppo_policy import PPOPolicy
+from csle_base.json_serializable import JSONSerializable
 
 
-class ExperimentResult:
+class ExperimentResult(JSONSerializable):
     """
     DTO representing the results of an experiment
     """
@@ -47,9 +48,11 @@ class ExperimentResult:
 
     def to_dict(self) -> Dict[str, Any]:
         """
+        Converts the object to a dict representation
+
         :return: a dict representation of the object
         """
-        d = {}
+        d: Dict[str, Any] = {}
         d["all_metrics"] = self.all_metrics
         d2 = {}
         for k, v in self.policies.items():
@@ -65,29 +68,7 @@ class ExperimentResult:
         :return: a string representation of the object
         """
         return f"all_metrics: {self.all_metrics}, policies: {self.policies}, plot_metrics: {self.plot_metrics}, " \
-               f"avg_metrtics: {self.avg_metrics}, std metrics: {self.std_metrics}"
-
-    def to_json_str(self) -> str:
-        """
-        Converts the DTO into a json string
-
-        :return: the json string representation of the DTO
-        """
-        import json
-        json_str = json.dumps(self.to_dict(), indent=4, sort_keys=True)
-        return json_str
-
-    def to_json_file(self, json_file_path: str) -> None:
-        """
-        Saves the DTO to a json file
-
-        :param json_file_path: the json file path to save  the DTO to
-        :return: None
-        """
-        import io
-        json_str = self.to_json_str()
-        with io.open(json_file_path, 'w', encoding='utf-8') as f:
-            f.write(json_str)
+               f"avg_metrics: {self.avg_metrics}, std metrics: {self.std_metrics}"
 
     @staticmethod
     def from_json_file(json_file_path: str) -> "ExperimentResult":
