@@ -1,4 +1,4 @@
-from typing import Tuple, List
+from typing import Tuple, List, Any
 import time
 import paramiko
 import telnetlib
@@ -36,23 +36,23 @@ class ConnectionUtil:
         :param service_name: name of the service to login to
         :return: s_prime, new connection (bool)
         """
-        total_cost = 0
+        total_cost = 0.0
         target_machine = None
-        non_used_credentials = []
+        non_used_credentials: List[Credential] = []
         root = False
-        non_failed_credentials = []
+        non_failed_credentials: List[Credential] = []
+        if s.attacker_obs_state is None:
+            raise ValueError("Could not find any EmulationAttackerObservationState object")
         for m in s.attacker_obs_state.machines:
             if m.ips == a.ips:
-                target_machine = m
-                target_machine = target_machine.copy()
+                target_machine = m.copy()
                 break
-
         # Check if already logged in
         if target_machine is not None:
             alive_connections = []
             root = False
             connected = False
-            connections = []
+            connections: List[EmulationConnectionObservationState] = []
             if service_name == constants.TELNET.SERVICE_NAME:
                 connections = target_machine.telnet_connections
             elif service_name == constants.SSH.SERVICE_NAME:
@@ -99,6 +99,8 @@ class ConnectionUtil:
 
         # Check cached connections
         non_used_nor_cached_credentials = []
+        if target_machine is None:
+            raise ValueError("Target machine is None")
         for cr in non_used_credentials:
             if cr.service == constants.SSH.SERVICE_NAME:
                 for ip in target_machine.ips:
@@ -149,6 +151,8 @@ class ConnectionUtil:
         if target_machine is None or root or len(non_used_nor_cached_credentials) == 0:
             s_prime = s
             if target_machine is not None:
+                if s.attacker_obs_state is None or s_prime.attacker_obs_state is None:
+                    raise ValueError("EmulationAttackerObservationState is None.")
                 attacker_machine_observations = EnvDynamicsUtil.merge_new_obs_with_old(
                     s.attacker_obs_state.machines, [target_machine],
                     emulation_env_config=s.emulation_env_config, action=a)
@@ -173,7 +177,6 @@ class ConnectionUtil:
             if len(ssh_connections_sorted_by_root) > 0:
                 proxy_connections.append(ssh_connections_sorted_by_root[0])
 
-        connection_setup_dto = ConnectionSetupDTO()
         if service_name == constants.SSH.SERVICE_NAME:
             connection_setup_dto = ConnectionUtil._ssh_setup_connection(
                 a=a,
@@ -189,6 +192,8 @@ class ConnectionUtil:
                 a=a,
                 credentials=non_used_nor_cached_credentials,
                 proxy_connections=proxy_connections, s=s)
+        else:
+            raise ValueError(f"Service: {service_name} not recognized")
 
         s_prime = s
         if len(connection_setup_dto.non_failed_credentials) > 0:
@@ -223,6 +228,8 @@ class ConnectionUtil:
             attacker_machine_observations = EnvDynamicsUtil.merge_new_obs_with_old(
                 s.attacker_obs_state.machines, [target_machine],
                 emulation_env_config=s.emulation_env_config, action=a)
+            if s_prime.attacker_obs_state is None:
+                raise ValueError("Could not find EmulationAttackerObservationState object")
             s_prime.attacker_obs_state.machines = attacker_machine_observations
         else:
             target_machine.shell_access = False
@@ -239,21 +246,32 @@ class ConnectionUtil:
         Helper function for setting up a SSH connection
 
         :param a: the action of the connection
-        :param emulation_env_config: the emulation environment config
         :param credentials: list of credentials to try
         :param proxy_connections: list of proxy connections to try
         :param s: env state
         :return: a DTO with connection setup information
         """
-        connection_setup_dto = ConnectionSetupDTO()
         start = time.time()
+        target_connections: List[Any] = []
+        non_failed_credentials: List[Credential] = []
+        proxies: List[EmulationConnectionObservationState] = []
+        ports: List[int] = []
+        forward_ports: List[int] = []
+        interactive_shells: List[Any] = []
+        tunnel_threads: List[ForwardTunnelThread] = []
+        connected: bool = False
+        ip: str = ""
         for proxy_conn in proxy_connections:
+            if proxy_conn.ip is None:
+                raise ValueError("EmulationConnectionObservationState is None")
             if proxy_conn.ip != s.emulation_env_config.containers_config.agent_ip:
                 m = s.get_attacker_machine(proxy_conn.ip)
                 if m is None or not a.ips_match(list(m.reachable)) or m.ips_match(a.ips):
                     continue
             else:
-                if not a.ips_match(s.attacker_obs_state.agent_reachable):
+                if s.attacker_obs_state is None or s.attacker_obs_state.agent_reachable is None:
+                    raise ValueError("EmulationAttackerObservationState is None")
+                if not a.ips_match(list(s.attacker_obs_state.agent_reachable)):
                     continue
             for cr in credentials:
                 for ip in a.ips:
@@ -266,28 +284,42 @@ class ConnectionUtil:
                                                                          agent_addr)
                             target_conn = paramiko.SSHClient()
                             target_conn.set_missing_host_key_policy(paramiko.AutoAddPolicy())
+                            if target_conn is None:
+                                raise ValueError("Connection failed")
                             target_conn.connect(ip, username=cr.username, password=cr.pw, sock=relay_channel)
-                            target_conn.get_transport().set_keepalive(5)
-                            connection_setup_dto.connected = True
-                            connection_setup_dto.credentials.append(cr)
-                            connection_setup_dto.target_connections.append(target_conn)
-                            connection_setup_dto.proxies.append(proxy_conn)
-                            connection_setup_dto.ports.append(cr.port)
-                            connection_setup_dto.non_failed_credentials.append(cr)
-                            connection_setup_dto.ip = ip
+                            transport = target_conn.get_transport()
+                            if transport is not None:
+                                transport.set_keepalive(5)
+                            else:
+                                raise ValueError("Connection failed")
+                            connected = True
+                            credentials.append(cr)
+                            target_connections.append(target_conn)
+                            proxies.append(proxy_conn)
+                            non_failed_credentials.append(cr)
+                            ip = ip
+                            ports.append(cr.port)
                             break
                         except Exception as e:
                             Logger.__call__().get_logger().warning("SSH exception :{}".format(str(e)))
                             Logger.__call__().get_logger().warning("user:{}, pw:{}".format(cr.username, cr.pw))
+                            if s.attacker_obs_state is None:
+                                raise ValueError("EmulationAttackerObservationState is None")
                             Logger.__call__().get_logger().warning("Agent reachable:{}".format(
                                 s.attacker_obs_state.agent_reachable))
                             Logger.__call__().get_logger().warning("Action:{}, {}, {}".format(a.id, a.ips, a.descr))
                     else:
-                        connection_setup_dto.non_failed_credentials.append(cr)
-            if connection_setup_dto.connected:
+                        non_failed_credentials.append(cr)
+                if connected:
+                    break
+            if connected:
                 break
         end = time.time()
-        connection_setup_dto.total_time = end - start
+        connection_setup_dto = ConnectionSetupDTO(
+            connected=connected, credentials=credentials, target_connections=target_connections,
+            proxies=proxies, non_failed_credentials=non_failed_credentials, ip=ip,
+            ports=ports, forward_ports=forward_ports, interactive_shells=interactive_shells,
+            tunnel_threads=tunnel_threads, total_time=end - start)
         return connection_setup_dto
 
     @staticmethod
@@ -329,26 +361,47 @@ class ConnectionUtil:
 
     @staticmethod
     def _telnet_setup_connection(a: EmulationAttackerAction,
-                                 credentials: List[Credential], proxy_connections: List,
+                                 credentials: List[Credential],
+                                 proxy_connections: List[EmulationConnectionObservationState],
                                  s: EmulationEnvState) -> ConnectionSetupDTO:
         """
         Helper function for setting up a Telnet connection to a target machine
 
         :param a: the action of the connection
         :param credentials: list of credentials to try
-        :param proxies: proxy connections
+        :param proxy_connections: proxy connections
         :param s: env state
         :return: a DTO with the connection setup information
         """
-        connection_setup_dto = ConnectionSetupDTO()
+        target_connections: List[Any] = []
+        non_failed_credentials: List[Credential] = []
+        proxies: List[EmulationConnectionObservationState] = []
+        ports: List[int] = []
+        forward_ports: List[int] = []
+        interactive_shells: List[Any] = []
+        tunnel_threads: List[ForwardTunnelThread] = []
+        connected: bool = False
+        ip: str = ""
         start = time.time()
         for proxy_conn in proxy_connections:
             if proxy_conn.ip != s.emulation_env_config.containers_config.agent_ip:
+                if proxy_conn.ip is None:
+                    raise ValueError("EmulationConnectionObservationState is None")
                 m = s.get_attacker_machine(proxy_conn.ip)
-                if m is None or a.ips not in m.reachable or m.ips == a.ips:
+                if m is None:
+                    continue
+                if m.ips == a.ips:
+                    continue
+                no_match = True
+                for ip in a.ips:
+                    if ip in m.reachable:
+                        no_match = False
+                if no_match:
                     continue
             else:
-                if not a.ips_match(s.attacker_obs_state.agent_reachable):
+                if s.attacker_obs_state is None or s.attacker_obs_state.agent_reachable is None:
+                    raise ValueError("EmulationAttackerObservationState or agent_reachable is None")
+                if not a.ips_match(list(s.attacker_obs_state.agent_reachable)):
                     continue
             for cr in credentials:
                 for ip in a.ips:
@@ -367,32 +420,37 @@ class ConnectionUtil:
                             target_conn.read_until(constants.TELNET.PASSWORD_PROMPT, timeout=3)
                             target_conn.write((cr.pw + "\n").encode())
                             response = target_conn.read_until(constants.TELNET.PROMPT, timeout=3)
-                            response = response.decode()
-                            if constants.TELNET.INCORRECT_LOGIN not in response and response != "":
-                                connection_setup_dto.connected = True
-                                connection_setup_dto.credentials.append(cr)
-                                connection_setup_dto.target_connections.append(target_conn)
-                                connection_setup_dto.proxies.append(proxy_conn)
-                                connection_setup_dto.tunnel_threads.append(tunnel_thread)
-                                connection_setup_dto.forward_ports.append(forward_port)
-                                connection_setup_dto.ports.append(cr.port)
-                                connection_setup_dto.ip = ip
-                            connection_setup_dto.non_failed_credentials.append(cr)
+                            response_1 = response.decode()
+                            if constants.TELNET.INCORRECT_LOGIN not in response_1 and response_1 != "":
+                                connected = True
+                                credentials.append(cr)
+                                target_connections.append(target_conn)
+                                proxies.append(proxy_conn)
+                                tunnel_threads.append(tunnel_thread)
+                                forward_ports.append(forward_port)
+                                ports.append(cr.port)
+                                ip = ip
+                                non_failed_credentials.append(cr)
                             break
                         except Exception as e:
                             Logger.__call__().get_logger().warning(f"telnet exception:{str(e)}, {repr(e)}")
-                            Logger.__call__().get_logger().warning(
-                                f"Target ip in agent reachable: {s.attacker_obs_state.agent_reachable}")
-                            Logger.__call__().get_logger().warning(
-                                f"Agent reachable:{s.attacker_obs_state.agent_reachable}")
+                            if s.attacker_obs_state is not None:
+                                Logger.__call__().get_logger().warning(
+                                    f"Target ip in agent reachable: {s.attacker_obs_state.agent_reachable}")
+                                Logger.__call__().get_logger().warning(
+                                    f"Agent reachable:{s.attacker_obs_state.agent_reachable}")
                     else:
-                        connection_setup_dto.non_failed_credentials.append(cr)
-                if connection_setup_dto.connected:
+                        non_failed_credentials.append(cr)
+                if connected:
                     break
-            if connection_setup_dto.connected:
+            if connected:
                 break
         end = time.time()
-        connection_setup_dto.total_time = end - start
+        connection_setup_dto = ConnectionSetupDTO(
+            connected=connected, credentials=credentials, target_connections=target_connections,
+            proxies=proxies, non_failed_credentials=non_failed_credentials, ip=ip,
+            ports=ports, forward_ports=forward_ports, interactive_shells=interactive_shells,
+            tunnel_threads=tunnel_threads, total_time=end - start)
         return connection_setup_dto
 
     @staticmethod
@@ -435,7 +493,8 @@ class ConnectionUtil:
 
     @staticmethod
     def _ftp_setup_connection(a: EmulationAttackerAction,
-                              credentials: List[Credential], proxy_connections: List,
+                              credentials: List[Credential],
+                              proxy_connections: List[EmulationConnectionObservationState],
                               s: EmulationEnvState) -> ConnectionSetupDTO:
         """
         Helper function for setting up a FTP connection
@@ -443,18 +502,36 @@ class ConnectionUtil:
         :param a: the action of the connection
         :param credentials: list of credentials to try
         :param proxy_connections: proxy connections
-        :param env_state: env state
+        :param s: env state
         :return: a DTO with connection setup information
         """
-        connection_setup_dto = ConnectionSetupDTO()
+        target_connections: List[Any] = []
+        non_failed_credentials: List[Credential] = []
+        proxies: List[EmulationConnectionObservationState] = []
+        ports: List[int] = []
+        forward_ports: List[int] = []
+        interactive_shells: List[Any] = []
+        tunnel_threads: List[ForwardTunnelThread] = []
+        connected: bool = False
+        ip: str = ""
         start = time.time()
         for proxy_conn in proxy_connections:
-            if proxy_conn.ip != s.emulation_env_config.containers_config.agent_ip:
-                m = s.get_attacker_machine(proxy_conn.ip)
-                if m is None or a.ips not in m.reachable or m.ips == a.ips:
+            if proxy_conn.ip != s.emulation_env_config.containers_config.agent_ip and proxy_conn:
+                m = None
+                if proxy_conn.ip is not None:
+                    m = s.get_attacker_machine(proxy_conn.ip)
+                if m is None or m.ips == a.ips:
+                    continue
+                no_match = True
+                for ip in a.ips:
+                    if ip in m.reachable:
+                        no_match = False
+                if no_match:
                     continue
             else:
-                if not a.ips_match(s.attacker_obs_state.agent_reachable):
+                if s.attacker_obs_state is None or s.attacker_obs_state.agent_reachable is None:
+                    raise ValueError("EmulationAttackerObservationState or agent_reachable is None")
+                if not a.ips_match(list(s.attacker_obs_state.agent_reachable)):
                     continue
             for cr in credentials:
                 for ip in a.ips:
@@ -470,14 +547,14 @@ class ConnectionUtil:
                             target_conn.connect(host=constants.FTP.LOCALHOST, port=forward_port, timeout=5)
                             login_result = target_conn.login(cr.username, cr.pw)
                             if constants.FTP.INCORRECT_LOGIN not in login_result:
-                                connection_setup_dto.connected = True
-                                connection_setup_dto.credentials.append(cr)
-                                connection_setup_dto.target_connections.append(target_conn)
-                                connection_setup_dto.proxies.append(proxy_conn)
-                                connection_setup_dto.tunnel_threads.append(tunnel_thread)
-                                connection_setup_dto.forward_ports.append(forward_port)
-                                connection_setup_dto.ports.append(cr.port)
-                                connection_setup_dto.ip = ip
+                                connected = True
+                                credentials.append(cr)
+                                target_connections.append(target_conn)
+                                proxies.append(proxy_conn)
+                                tunnel_threads.append(tunnel_thread)
+                                forward_ports.append(forward_port)
+                                ports.append(cr.port)
+                                ip = ip
                                 # Create LFTP connection too to be able to search file system
                                 shell = proxy_conn.conn.invoke_shell()
                                 # clear output
@@ -488,23 +565,30 @@ class ConnectionUtil:
                                 # clear output
                                 if shell.recv_ready():
                                     shell.recv(constants.COMMON.DEFAULT_RECV_SIZE)
-                                connection_setup_dto.interactive_shells.append(shell)
-                                connection_setup_dto.non_failed_credentials.append(cr)
+                                interactive_shells.append(shell)
+                                non_failed_credentials.append(cr)
                                 break
                         except Exception as e:
+                            if s.attacker_obs_state is None or s.attacker_obs_state.agent_reachable is None:
+                                raise ValueError("Could not obtain EmulationAttackerObservationState")
                             Logger.__call__().get_logger().warning(f"FTP exception: {str(e)}, {repr(e)}")
                             Logger.__call__().get_logger().warning(
-                                f"Target ip in agent reacahble {a.ips_match(s.attacker_obs_state.agent_reachable)}")
+                                f"Target ip in agent reachable "
+                                f"{a.ips_match(list(s.attacker_obs_state.agent_reachable))}")
                             Logger.__call__().get_logger().warning(f"Agent reachable: "
                                                                    f"{s.attacker_obs_state.agent_reachable}")
                     else:
-                        connection_setup_dto.non_failed_credentials.append(cr)
-                if connection_setup_dto.connected:
+                        non_failed_credentials.append(cr)
+                if connected:
                     break
-            if connection_setup_dto.connected:
+            if connected:
                 break
         end = time.time()
-        connection_setup_dto.total_time = end - start
+        connection_setup_dto = ConnectionSetupDTO(
+            connected=connected, credentials=credentials, target_connections=target_connections,
+            proxies=proxies, non_failed_credentials=non_failed_credentials, ip=ip,
+            ports=ports, forward_ports=forward_ports, interactive_shells=interactive_shells,
+            tunnel_threads=tunnel_threads, total_time=end - start)
         return connection_setup_dto
 
     @staticmethod
@@ -514,7 +598,6 @@ class ConnectionUtil:
         Helper function for creating the connection DTO for FTP
 
         :param target_machine: the target machine to connect to
-        :param users: list of users that are connected
         :param i: current index
         :param connection_setup_dto: DTO with information about the connection setup
         :return: boolean, whether the connection has root privileges, cost
@@ -537,10 +620,10 @@ class ConnectionUtil:
 
         :param ip: the ip to reach
         :param s: the current state
-        :param emulation_env_config: the emulation environment configuration
         :return: a connection DTO
         """
-
+        if s.attacker_obs_state is None or s.attacker_obs_state.agent_reachable is None:
+            raise ValueError("EmulationAttackerObservationState or agent_reachable is None")
         if ip in s.attacker_obs_state.agent_reachable:
             cr = Credential(
                 username=constants.AGENT.USER, pw=constants.AGENT.PW, root=True,
@@ -551,8 +634,10 @@ class ConnectionUtil:
                 proxy=None, ip=s.emulation_env_config.containers_config.agent_ip)
             return c
         s.attacker_obs_state.sort_machines()
-
+        err_str = ""
         for m in s.attacker_obs_state.machines:
+            err_str = err_str + (f"ips: {m.ips}, logged in: {m.logged_in}, tools installed: {m.tools_installed}, "
+                                 f"reachable: {m.reachable} \n")
             if m.logged_in and m.tools_installed and m.backdoor_installed and ip in m.reachable:
 
                 # Start with ssh connections
@@ -566,7 +651,7 @@ class ConnectionUtil:
                     alive = ConnectionUtil.test_connection(c)
                     if alive:
                         return c
-        raise ValueError("No JumpHost found")
+        raise ValueError(f"No JumpHost found for ip: {ip}, topology: {err_str}")
 
     @staticmethod
     def test_connection(c: EmulationConnectionObservationState) -> bool:
@@ -578,7 +663,7 @@ class ConnectionUtil:
         """
         cmd = constants.AUXILLARY_COMMANDS.WHOAMI
         outdata, errdata, total_time = EmulationUtil.execute_ssh_cmd(cmd=cmd, conn=c.conn)
-        if outdata is not None and outdata != "":
+        if outdata is not None and outdata.decode("utf-8") != "":
             return True
         else:
             return False
@@ -591,11 +676,17 @@ class ConnectionUtil:
         :param c: the connection to reconnect
         :return: the new connection
         """
+        if c.conn is None:
+            raise ValueError("Connection failed")
         if c.proxy is None:
             c.conn = paramiko.SSHClient()
             c.conn.set_missing_host_key_policy(paramiko.AutoAddPolicy())
             c.conn.connect(c.ip, username=c.credential.username, password=c.credential.pw)
-            c.conn.get_transport().set_keepalive(5)
+            transport = c.conn.get_transport()
+            if transport is not None:
+                transport.set_keepalive(5)
+            else:
+                raise ValueError("Connection failed")
         else:
             proxy = c.proxy
             if proxy.conn.get_transport() is None or not proxy.conn.get_transport().is_active():
@@ -609,7 +700,11 @@ class ConnectionUtil:
             c.conn = paramiko.SSHClient()
             c.conn.set_missing_host_key_policy(paramiko.AutoAddPolicy())
             c.conn.connect(c.ip, username=c.credential.username, password=c.credential.pw, sock=relay_channel)
-            c.conn.get_transport().set_keepalive(5)
+            transport = c.conn.get_transport()
+            if transport is not None:
+                transport.set_keepalive(5)
+            else:
+                raise ValueError("Connection failed")
             c.proxy = proxy
         return c
 
@@ -620,14 +715,19 @@ class ConnectionUtil:
         Reconnects the given Telnet connection if it has died for some reason
 
         :param c: the connection to reconnect
+        :param forward_port: the port for port-forwarding
         :return: the new connection
         """
+        if c.proxy is None:
+            raise ValueError("Could not obtain proxy")
         if c.proxy.conn.get_transport() is None or not c.proxy.conn.get_transport().is_active():
             proxy = ConnectionUtil.reconnect_ssh(c=c.proxy)
             c.proxy = proxy
         for i in range(constants.ENV_CONSTANTS.NUM_RETRIES):
             try:
                 agent_transport = c.proxy.conn.get_transport()
+                if c.ip is None:
+                    raise ValueError("The EmulationConnectionObservationState ip is None")
                 tunnel_thread = ForwardTunnelThread(local_port=forward_port,
                                                     remote_host=c.ip, remote_port=constants.TELNET.DEFAULT_PORT,
                                                     transport=agent_transport)
@@ -638,8 +738,8 @@ class ConnectionUtil:
                 target_conn.read_until(constants.TELNET.PASSWORD_PROMPT, timeout=3)
                 target_conn.write((c.credential.pw + "\n").encode())
                 response = target_conn.read_until(constants.TELNET.PROMPT, timeout=3)
-                response = response.decode()
-                if constants.TELNET.INCORRECT_LOGIN not in response and response != "":
+                response_1 = response.decode()
+                if constants.TELNET.INCORRECT_LOGIN not in response_1 and response_1 != "":
                     c.conn = target_conn
             except Exception as e:
                 Logger.__call__().get_logger().warning(f"telnet exception:{str(e)}, {repr(e)}")
