@@ -91,7 +91,7 @@ class EmulationUtil:
 
     @staticmethod
     def _list_all_users(c: EmulationConnectionObservationState, emulation_env_config: EmulationEnvConfig,
-                        telnet: bool = False) -> List:
+                        telnet: bool = False) -> List[str]:
         """
         List all users on a machine
 
@@ -105,9 +105,8 @@ class EmulationUtil:
         for i in range(constants.ENV_CONSTANTS.ATTACKER_RETRY_FIND_USERS):
             if not telnet:
                 outdata, errdata, total_time = EmulationUtil.execute_ssh_cmd(cmd=cmd, conn=c.conn)
-                outdata = outdata.decode()
-                errdata = errdata.decode()
-                users = outdata.split("\n")
+                outdata_1 = outdata.decode()
+                users = outdata_1.split("\n")
                 users = list(filter(lambda x: x != '', users))
             else:
                 cmd = cmd + "\n"
@@ -165,7 +164,11 @@ class EmulationUtil:
             target_conn = paramiko.SSHClient()
             target_conn.set_missing_host_key_policy(paramiko.AutoAddPolicy())
             target_conn.connect(target_ip, username=user, password=pw, sock=relay_channel)
-            target_conn.get_transport().set_keepalive(5)
+            transport = target_conn.get_transport()
+            if transport is not None:
+                transport.set_keepalive(5)
+            else:
+                raise ValueError(f"Connection failed, ip: {target_ip}, user: {user}, pw: {pw}")
             connection_dto = EmulationConnectionObservationState(
                 conn=target_conn, credential=cr, root=root, service=constants.SSH.SERVICE_NAME,
                 port=constants.SSH.DEFAULT_PORT, proxy=proxy_conn, ip=target_ip)
@@ -256,7 +259,7 @@ class EmulationUtil:
         output = channel.recv(constants.COMMON.LARGE_RECV_SIZE)
         output_str = output.decode("utf-8")
         output_str = constants.NMAP.SHELL_ESCAPE.sub("", output_str)
-        return output_str
+        return str(output_str)
 
     @staticmethod
     def is_emulation_defense_action_legal(defense_action_id: int, env_config: EmulationEnvConfig,
@@ -285,8 +288,9 @@ class EmulationUtil:
         """
         if attack_action_id > len(env_state.attacker_action_config.actions) - 1:
             return False
-
         action = env_state.attacker_action_config.actions[attack_action_id]
+        if env_state.attacker_obs_state is None:
+            raise ValueError("Could not obtain EmulationAttackerObservationState")
         ip = env_state.attacker_obs_state.get_action_ips(action, emulation_env_config=env_config)
 
         logged_in_ips_str = EnvDynamicsUtil.logged_in_ips_str(emulation_env_config=env_config, s=env_state)
@@ -430,7 +434,7 @@ class EmulationUtil:
         :return: True if it is running otherwise false.
         """
         try:
-            return psutil.Process(pid).is_running()
+            return bool(psutil.Process(pid).is_running())
         except Exception:
             return False
 
