@@ -1,5 +1,5 @@
 import logging
-from typing import List
+from typing import List, Dict
 import time
 import datetime
 from confluent_kafka import Consumer, KafkaError, KafkaException, TopicPartition
@@ -10,13 +10,13 @@ from csle_ryu.dao.flow_statistic import FlowStatistic
 from csle_ryu.dao.port_statistic import PortStatistic
 import csle_collector.constants.constants as collector_constants
 import csle_common.constants.constants as constants
-from csle_collector.snort_ids_manager.snort_ids_alert_counters import SnortIdsAlertCounters
-from csle_collector.snort_ids_manager.snort_ids_rule_counters import SnortIdsRuleCounters
-from csle_collector.snort_ids_manager.snort_ids_ip_alert_counters import SnortIdsIPAlertCounters
-from csle_collector.ossec_ids_manager.ossec_ids_alert_counters import OSSECIdsAlertCounters
+from csle_collector.snort_ids_manager.dao.snort_ids_alert_counters import SnortIdsAlertCounters
+from csle_collector.snort_ids_manager.dao.snort_ids_rule_counters import SnortIdsRuleCounters
+from csle_collector.snort_ids_manager.dao.snort_ids_ip_alert_counters import SnortIdsIPAlertCounters
+from csle_collector.ossec_ids_manager.dao.ossec_ids_alert_counters import OSSECIdsAlertCounters
 from csle_collector.client_manager.client_population_metrics import ClientPopulationMetrics
-from csle_collector.docker_stats_manager.docker_stats import DockerStats
-from csle_collector.host_manager.host_metrics import HostMetrics
+from csle_collector.docker_stats_manager.dao.docker_stats import DockerStats
+from csle_collector.host_manager.dao.host_metrics import HostMetrics
 from csle_common.dao.emulation_config.emulation_env_config import EmulationEnvConfig
 from csle_common.dao.emulation_action.attacker.emulation_attacker_action import EmulationAttackerAction
 from csle_common.dao.emulation_action.defender.emulation_defender_action import EmulationDefenderAction
@@ -24,6 +24,9 @@ from csle_common.dao.emulation_config.emulation_metrics_time_series import Emula
 
 
 class ReadEmulationStatisticsUtil:
+    """
+    Utility class for reading emulation statistics
+    """
 
     @staticmethod
     def read_all(emulation_env_config: EmulationEnvConfig, logger: logging.Logger, time_window_minutes: int = 100) \
@@ -35,34 +38,34 @@ class ReadEmulationStatisticsUtil:
         :param time_window_minutes : the length of the time window in minutes to consume (now-time_windows_minutes, now)
         :return: the collected time series data
         """
-        client_metrics = []
-        agg_docker_stats = []
-        docker_host_stats = {}
-        host_metrics = {}
-        aggregated_host_metrics = []
-        defender_actions = []
-        attacker_actions = []
-        snort_ids_metrics = []
-        snort_ids_ip_metrics = {}
-        snort_ids_rule_metrics = []
-        snort_alert_metrics_per_ids = {}
-        snort_rule_metrics_per_ids = {}
-        total_snort_metrics = []
-        total_snort_rule_metrics = []
-        total_host_metrics = []
-        ossec_host_ids_metrics = {}
-        total_ossec_metrics = []
-        aggregated_ossec_metrics = []
-        openflow_flow_stats = []
-        openflow_port_stats = []
-        avg_openflow_flow_stats = []
-        avg_openflow_port_stats = []
-        openflow_flow_metrics_per_switch = {}
-        openflow_port_metrics_per_switch = {}
-        openflow_flow_avg_metrics_per_switch = {}
-        openflow_port_avg_metrics_per_switch = {}
-        agg_openflow_flow_stats = []
-        agg_openflow_flow_metrics_per_switch = {}
+        client_metrics: List[ClientPopulationMetrics] = []
+        agg_docker_stats: List[DockerStats] = []
+        docker_host_stats: Dict[str, List[DockerStats]] = {}
+        host_metrics: Dict[str, List[HostMetrics]] = {}
+        aggregated_host_metrics: List[HostMetrics] = []
+        defender_actions: List[EmulationDefenderAction] = []
+        attacker_actions: List[EmulationAttackerAction] = []
+        snort_ids_metrics: List[SnortIdsAlertCounters] = []
+        snort_ids_ip_metrics: Dict[str, List[SnortIdsIPAlertCounters]] = {}
+        snort_ids_rule_metrics: List[SnortIdsRuleCounters] = []
+        snort_alert_metrics_per_ids: Dict[str, List[SnortIdsAlertCounters]] = {}
+        snort_rule_metrics_per_ids: Dict[str, List[SnortIdsRuleCounters]] = {}
+        total_snort_metrics: List[SnortIdsAlertCounters] = []
+        total_snort_rule_metrics: List[SnortIdsRuleCounters] = []
+        total_host_metrics: List[HostMetrics] = []
+        ossec_host_ids_metrics: Dict[str, List[OSSECIdsAlertCounters]] = {}
+        total_ossec_metrics: List[OSSECIdsAlertCounters] = []
+        aggregated_ossec_metrics: List[OSSECIdsAlertCounters] = []
+        openflow_flow_stats: List[FlowStatistic] = []
+        openflow_port_stats: List[PortStatistic] = []
+        avg_openflow_flow_stats: List[AvgFlowStatistic] = []
+        avg_openflow_port_stats: List[AvgPortStatistic] = []
+        openflow_flow_metrics_per_switch: Dict[str, List[FlowStatistic]] = {}
+        openflow_port_metrics_per_switch: Dict[str, List[PortStatistic]] = {}
+        openflow_flow_avg_metrics_per_switch: Dict[str, List[AvgFlowStatistic]] = {}
+        openflow_port_avg_metrics_per_switch: Dict[str, List[AvgPortStatistic]] = {}
+        agg_openflow_flow_stats: List[AggFlowStatistic] = []
+        agg_openflow_flow_metrics_per_switch: Dict[str, List[AggFlowStatistic]] = {}
 
         num_ossec_containers = len(list(filter(lambda x: x.name in constants.CONTAINER_IMAGES.OSSEC_IDS_IMAGES,
                                                emulation_env_config.containers_config.containers)))
@@ -153,36 +156,41 @@ class ReadEmulationStatisticsUtil:
                         agg_docker_stats.append(DockerStats.from_kafka_record(record=msg.value().decode()))
                     elif topic == collector_constants.KAFKA_CONFIG.HOST_METRICS_TOPIC_NAME:
                         metrics = HostMetrics.from_kafka_record(record=msg.value().decode())
-                        c = emulation_env_config.get_container_from_ip(metrics.ip)
-                        host_metrics[c.get_full_name()].append(metrics)
-                        host_metrics_counter += 1
-                        total_host_metrics.append(metrics)
+                        c_1 = emulation_env_config.get_container_from_ip(metrics.ip)
+                        if c_1 is not None:
+                            host_metrics[c_1.get_full_name()].append(metrics)
+                            host_metrics_counter += 1
+                            total_host_metrics.append(metrics)
                     elif topic == collector_constants.KAFKA_CONFIG.OSSEC_IDS_LOG_TOPIC_NAME:
                         metrics = OSSECIdsAlertCounters.from_kafka_record(record=msg.value().decode())
-                        c = emulation_env_config.get_container_from_ip(metrics.ip)
-                        ossec_host_ids_metrics[c.get_full_name()].append(metrics)
-                        ossec_host_metrics_counter += 1
-                        total_ossec_metrics.append(metrics)
+                        c_1 = emulation_env_config.get_container_from_ip(metrics.ip)
+                        if c_1 is not None:
+                            ossec_host_ids_metrics[c_1.get_full_name()].append(metrics)
+                            ossec_host_metrics_counter += 1
+                            total_ossec_metrics.append(metrics)
                     elif topic == collector_constants.KAFKA_CONFIG.ATTACKER_ACTIONS_TOPIC_NAME:
                         attacker_actions.append(EmulationAttackerAction.from_kafka_record(record=msg.value().decode()))
                     elif topic == collector_constants.KAFKA_CONFIG.DEFENDER_ACTIONS_TOPIC_NAME:
                         defender_actions.append(EmulationDefenderAction.from_kafka_record(record=msg.value().decode()))
                     elif topic == collector_constants.KAFKA_CONFIG.DOCKER_HOST_STATS_TOPIC_NAME:
                         stats = DockerStats.from_kafka_record(record=msg.value().decode())
-                        c = emulation_env_config.get_container_from_ip(stats.ip)
-                        docker_host_stats[c.get_full_name()].append(stats)
+                        c_1 = emulation_env_config.get_container_from_ip(stats.ip)
+                        if c_1 is not None:
+                            docker_host_stats[c_1.get_full_name()].append(stats)
                     elif topic == collector_constants.KAFKA_CONFIG.SNORT_IDS_LOG_TOPIC_NAME:
                         metrics = SnortIdsAlertCounters.from_kafka_record(record=msg.value().decode())
-                        c = emulation_env_config.get_container_from_ip(metrics.ip)
-                        snort_alert_metrics_per_ids[c.get_full_name()].append(metrics)
-                        snort_metrics_counter += 1
-                        total_snort_metrics.append(metrics)
+                        c_1 = emulation_env_config.get_container_from_ip(metrics.ip)
+                        if c_1 is not None:
+                            snort_alert_metrics_per_ids[c_1.get_full_name()].append(metrics)
+                            snort_metrics_counter += 1
+                            total_snort_metrics.append(metrics)
                     elif topic == collector_constants.KAFKA_CONFIG.SNORT_IDS_RULE_LOG_TOPIC_NAME:
                         metrics = SnortIdsRuleCounters.from_kafka_record(record=msg.value().decode())
-                        c = emulation_env_config.get_container_from_ip(metrics.ip)
-                        snort_rule_metrics_per_ids[c.get_full_name()].append(metrics)
-                        snort_rule_metrics_counter += 1
-                        total_snort_rule_metrics.append(metrics)
+                        c_1 = emulation_env_config.get_container_from_ip(metrics.ip)
+                        if c_1 is not None:
+                            snort_rule_metrics_per_ids[c_1.get_full_name()].append(metrics)
+                            snort_rule_metrics_counter += 1
+                            total_snort_rule_metrics.append(metrics)
                     elif topic == collector_constants.KAFKA_CONFIG.CLIENT_POPULATION_TOPIC_NAME:
                         client_metrics.append(ClientPopulationMetrics.from_kafka_record(record=msg.value().decode()))
                     elif topic == collector_constants.KAFKA_CONFIG.OPENFLOW_FLOW_STATS_TOPIC_NAME:
@@ -222,9 +230,9 @@ class ReadEmulationStatisticsUtil:
                             agg_flow_statistics_record)
                     elif topic == collector_constants.KAFKA_CONFIG.SNORT_IDS_IP_LOG_TOPIC_NAME:
                         metrics = SnortIdsIPAlertCounters.from_kafka_record(record=msg.value().decode())
-                        c = emulation_env_config.get_container_from_ip(metrics.alert_ip)
-                        if c is not None:
-                            snort_ids_ip_metrics[c.get_full_name()].append(metrics)
+                        c_1 = emulation_env_config.get_container_from_ip(metrics.alert_ip)
+                        if c_1 is not None:
+                            snort_ids_ip_metrics[c_1.get_full_name()].append(metrics)
                     if host_metrics_counter >= len(emulation_env_config.containers_config.containers):
                         agg_host_metrics_dto = ReadEmulationStatisticsUtil.average_host_metrics(
                             host_metrics=total_host_metrics)
